-- sql
-- $Source: atc_script.sql
-- $Revision: Oct 5, 2011
-- $Author: Jim Busser, GNUmed project
-- ---------------------------
-- Description:
-- script for filling missing ATC codes (based on consumable substance names)
-- … into GNUmed ref.consumable_substance
-- … deployed as 'install-data-pack.sql' within GNUmed data packs
-- Caveats:
-- 1. a drug can be known by more than one ATC code
-- 2. accordingly it will not mean that usage of the consumable substance will match the code
-- ---------------------------
-- References / links:
-- GNUmed git repository, data packs and project
--   git://gitorious.org/gnumed/gnumed.git
--   http://wiki.gnumed.de/bin/view/Gnumed/GmManualReferenceData
--   http://www.gnumed.de/downloads/data/data-packs.conf
--   http://wiki.gnumed.de
-- FreeDiams
--   contributes (source of):
--     ATC codes for one language INN
--   download URL:
--     http://freemedforms.googlecode.com/files/freediamsfullsources-0.5.4.tgz
-- ----------------------

-- uncomment the following to run from psql (instead of from GNUmed GUI)
-- set default_transaction_read_only to off;

-----------------------------------------------------------------------------
-- ************************************************************
-- set ON_ERROR_STOP 1
-- ************************************************************
-- ---------------------------------------------------------------------------
\set ON_ERROR_STOP 1


-----------------------------------------------------------------------------
-- ************************************************************
-- create staging table
-- ************************************************************
-- -----------------------------------------------------------------------------
-- ---------------------------------------------
\unset ON_ERROR_STOP
DROP TABLE staging.atc CASCADE;
\set ON_ERROR_STOP 1


CREATE TABLE staging.atc (
    description varchar,
    atc_code varchar
);

begin;

-- -----------------------------------------------------------------------------
-- *********************
-- import staging data
-- *********************
-- -----------------------------------------------------------------------------
--
-- PostgreSQL database dump
--

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

SET search_path = staging, pg_catalog;

--
-- Data for Name: atc; Type: TABLE DATA; Schema: staging; Owner: gm-dbo
--

INSERT INTO staging.atc (description, atc_code) VALUES ('(2-benzhydryloxyethyl)diethylmethylammoniumiodid', 'A03AB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('2-(4-chlorphenoxy)-ethanol', 'D01AE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('2-amino-1-phenylethanol-derivate', 'C04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('3-oxoandrosten-4-derivate', 'G03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('4-dimethylaminophenol', 'V03AB27');
INSERT INTO staging.atc (description, atc_code) VALUES ('5-androstanon-3-derivate', 'G03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('[111in]indium-antiovariumkarzinom-antikörper', 'V09IB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[111in]indium-capromab-pendetid', 'V09IB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('[111in]indium-satumomab-pendetid', 'V09IB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[111in]indium-verbindungen', 'V09HB');
INSERT INTO staging.atc (description, atc_code) VALUES ('[111in]indium-verbindungen', 'V09IB');
INSERT INTO staging.atc (description, atc_code) VALUES ('[111in]indiumimciromab', 'V09GX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[111in]indiumoxinat-markierte zellen', 'V09HB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[111in]indiumpentetat', 'V09AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[111in]indiumpentetreotid', 'V09IB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[111in]indiumtropolonat-markierte zellen', 'V09HB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[123i]iobenguan', 'V09IX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[123i]iod-iofetamin', 'V09AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[123i]iod-ioflupan', 'V09AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[123i]iod-ioloprid', 'V09AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[123i]iod-verbindungen', 'V09AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('[123i]natrium-iodhippurat', 'V09CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[123i]natriumiodid', 'V09FX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[125i]fibrinogen', 'V09GB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[125i]iod-cc49-monoklonaler antikörper', 'V09IX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[125i]iod-humanalbumin', 'V09GB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[125i]iod-verbindungen', 'V09GB');
INSERT INTO staging.atc (description, atc_code) VALUES ('[125i]natrium-iodthalamat', 'V09CX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[127xe]xenongas', 'V09EX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[131i]iobenguan', 'V10XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[131i]iobenguan', 'V09IX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[131i]iod-humanalbumin', 'V09XA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[131i]iod-verbindungen', 'V09XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('[131i]iod-verbindungen', 'V10XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('[131i]iodcholesterol', 'V09XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[131i]iodnorcholesterol', 'V09XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[131i]natrium-iodhippurat', 'V09CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[131i]natriumiodid', 'V09FX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[131i]natriumiodid', 'V10XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[133xe]xenongas', 'V09EX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[153sm]samariumhydroxyapatit-kolloid', 'V10AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[153sm]samariumlexidronam', 'V10BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[165dy]dysprosium-kolloid', 'V10AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[169er]erbiumcitrat-kolloid', 'V10AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('[186re]rheniumetidronat', 'V10BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[186re]rheniumsulfid-kolloid', 'V10AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('[18f]fludeoxyglucose', 'V09IX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('[18f]natriumfluorid', 'V09IX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('[198au]gold-kolloid', 'V10AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('[201tl]thalliumchlorid', 'V09GX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[32p]chrom(iii)phosphat-kolloid', 'V10AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[32p]natriumphosphat', 'V10XX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[51cr]chromchromat-markierte zellen', 'V09GX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[51cr]chromedetat', 'V09CX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('[57co]cobaltcyanocobalamin', 'V09XX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[58co]cobaltcyanocobalamin', 'V09XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[59fe]eisen(iii)citrat', 'V09XX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('[67ga]galliumcitrat', 'V09HX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[75se]selenium-tauroselcholinat', 'V09DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[75se]selennorcholesterol', 'V09XX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[81mkr]kryptongas', 'V09EX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[89sr]strontiumchlorid', 'V10BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[90y]yttrium-eisen(iii)hydroxid-kolloid', 'V10AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[90y]yttrium-verbindungen', 'V10AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('[90y]yttriumcitrat-kolloid', 'V10AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[90y]yttriumsilicat-kolloid', 'V10AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium, inhalate', 'V09EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium, partikel und kolloide', 'V09DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium, partikel zur injektion', 'V09EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium, technegas', 'V09EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-anticarcinoembryoantigen-antikörper', 'V09IA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-antigranulozyten-antikörper', 'V09HA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-antimelanom-antikörper', 'V09IA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-disofenin', 'V09DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-etifenin', 'V09DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-exametazim', 'V09AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-exametazim-markierte zellen', 'V09HA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-galtifenin', 'V09DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-humanalbumin', 'V09GA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-humanimmunglobulin', 'V09HA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-lidofenin', 'V09DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-macrosalb', 'V09EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-mebrofenin', 'V09DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-mikrokolloid', 'V09DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-mikrosphären', 'V09EB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-millimikrosphären', 'V09DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-nanokolloid', 'V09DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-nanokolloid', 'V09EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-rheniumsulfid-kolloid', 'V09DB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-schwefel-kolloid', 'V09DB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-succimer', 'V09CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-sulesomab', 'V09HA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-verbindungen', 'V09CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-verbindungen', 'V09DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-verbindungen', 'V09AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-verbindungen', 'V09HA');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-verbindungen', 'V09GA');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-verbindungen', 'V09IA');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-verbindungen', 'V09BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-zinn-kolloid', 'V09DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetium-zinn-markierte zellen', 'V09GA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumapcitid', 'V09GA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumarcitumomab', 'V09IA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumbicisat', 'V09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumbutedronat', 'V09BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumdepreotid', 'V09IA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumfurifosmin', 'V09GA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumglucoheptonat', 'V09CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumgluconat', 'V09CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiummedronat', 'V09BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiummertiatid', 'V09CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumoxidronat', 'V09BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumpentetat', 'V09CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumpentetat', 'V09EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumpertechnetat', 'V09FX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumphytat', 'V09DB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumpyrophosphat', 'V09BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumsestamibi', 'V09GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumsuccimer, pentavalent', 'V09IA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumteboroxim', 'V09GA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumtetrofosmin', 'V09GA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('[99mtc]technetiumvotumumab', 'V09IA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('abacavir', 'J05AF06');
INSERT INTO staging.atc (description, atc_code) VALUES ('abarelix', 'L02BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('abatacept', 'L04AA24');
INSERT INTO staging.atc (description, atc_code) VALUES ('abciximab', 'B01AC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('abetimus', 'L04AA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('absorbierbarer gelatineschwamm', 'B02BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acadesin', 'C01EB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('acamprosat', 'N07BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('acarbose', 'A10BF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ace-hemmer und calciumkanalblocker', 'C09BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('ace-hemmer und diuretika', 'C09BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('ace-hemmer, kombinationen', 'C09B');
INSERT INTO staging.atc (description, atc_code) VALUES ('ace-hemmer, rein', 'C09AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('ace-hemmer, rein', 'C09A');
INSERT INTO staging.atc (description, atc_code) VALUES ('acebutolol', 'C07AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('acebutolol und thiazide', 'C07BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aceclidin', 'S01EB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('aceclidin, kombinationen', 'S01EB58');
INSERT INTO staging.atc (description, atc_code) VALUES ('aceclofenac', 'M01AB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('acefyllinpiperazin', 'R03DA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('acemetacin', 'M01AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('acenocoumarol', 'B01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('acepromazin', 'N05AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetarsol', 'P01CD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetarsol', 'G01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetarsol', 'A07AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetazolamid', 'S01EC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetohexamid', 'A10BB31');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetohydroxamsäure', 'G04BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetophenazin', 'N05AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetoxolon', 'A02BX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetrizoinsäure', 'V08AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylcarnitin', 'N06BX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylcholin', 'S01EB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylcystein', 'S01XA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylcystein', 'R05CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylcystein', 'V03AB23');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetyldigitoxin', 'C01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetyldigoxin', 'C01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetyldigoxin, kombinationen', 'C01AA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylglycinamidchloralhydrat', 'N05CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylleucin', 'N07CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylsäure', 'N02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylsäure', 'B01AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylsäure', 'A01AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylsäure und corticosteroide', 'M01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylsäure, kombinationen exkl. psycholeptika', 'N02BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('acetylsalicylsäure, kombinationen mit psycholeptika', 'N02BA71');
INSERT INTO staging.atc (description, atc_code) VALUES ('aciclovir', 'D06BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aciclovir', 'S01AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aciclovir', 'J05AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aciclovir, kombinationen', 'D06BB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('acipimox', 'C10AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('acitretin', 'D05BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('aclarubicin', 'L01DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('acridin-derivate', 'D08AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('acriflaviniumchlorid', 'R02AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('acrivastin', 'R06AX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('acth', 'H01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('actinomycine', 'L01DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('adalimumab', 'L04AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('adamantan-derivate', 'N04BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('adapalen', 'D10AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('additiva zu i.v.-lösungen', 'B05X');
INSERT INTO staging.atc (description, atc_code) VALUES ('adefovir dipivoxil', 'J05AF08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ademetionin', 'A16AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('adenosin', 'C01EB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('adinazolam', 'N05BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('adipiodon', 'V08AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('adrafinil', 'N06BX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('adrenalon', 'B02BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('adrenalon', 'A01AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('adrenerge und dopaminerge mittel', 'C01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('afelimomab', 'L04AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('agalsidase alfa', 'A16AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('agalsidase beta', 'A16AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('agomelatin', 'N06AX22');
INSERT INTO staging.atc (description, atc_code) VALUES ('ajmalin', 'C01BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('aknemittel', 'D10');
INSERT INTO staging.atc (description, atc_code) VALUES ('aknemittel zur systemischen anwendung', 'D10B');
INSERT INTO staging.atc (description, atc_code) VALUES ('aknemittel zur topischen anwendung', 'D10A');
INSERT INTO staging.atc (description, atc_code) VALUES ('alanylglutamin', 'B05XB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alaproclat', 'N06AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('alaun', 'S01XA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('albendazol', 'P02CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('albumin', 'B05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('albumintannat', 'A07XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('albumintannat, kombinationen', 'A07XA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('alclofenac', 'M01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('alclometason', 'S01BA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('alclometason', 'D07AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('alcuronium', 'M03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aldehyde und derivate', 'N05CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('aldesleukin', 'L03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aldesulfonnatrium', 'J04BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aldosereduktasehemmer', 'A10XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('aldosteron', 'H02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aldosteron-antagonisten', 'C03DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alefacept', 'L04AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('alemtuzumab', 'L01XC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('alendronsäure', 'M05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfa1-antitrypsin', 'B02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfacalcidol', 'A11CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfaxalon', 'N01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfentanil', 'N01AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfuzosin', 'G04CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alfuzosin und finasterid', 'G04CA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('algeldrat', 'A02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alginsäure', 'A02BX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('alglucerase', 'A16AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alimemazin', 'R06AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alimentäres system und stoffwechsel', 'A');
INSERT INTO staging.atc (description, atc_code) VALUES ('aliskiren', 'C09XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('aliskiren und hydrochlorothiazide', 'C09XA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('alitretinoin', 'L01XX22');
INSERT INTO staging.atc (description, atc_code) VALUES ('alizaprid', 'A03FA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('alkaloide, exkl. rauwolfia', 'C02KA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alkaloide, exkl. rauwolfia, in kombination mit diuretika', 'C02LK');
INSERT INTO staging.atc (description, atc_code) VALUES ('alkylierende mittel', 'L01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('alkylsulfonate', 'L01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('alle übrigen nichttherapeutischen mittel', 'V07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('alle übrigen nichttherapeutischen mittel', 'V07');
INSERT INTO staging.atc (description, atc_code) VALUES ('alle übrigen therapeutischen mittel', 'V03');
INSERT INTO staging.atc (description, atc_code) VALUES ('alle übrigen therapeutischen mittel', 'V03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('allergen-extrakte', 'V01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('allergene', 'V01');
INSERT INTO staging.atc (description, atc_code) VALUES ('allergene', 'V01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('allergie-tests', 'V04CL');
INSERT INTO staging.atc (description, atc_code) VALUES ('allgemeinanästhetika', 'N01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('allgemeine diätetika', 'V06');
INSERT INTO staging.atc (description, atc_code) VALUES ('allobarbital', 'N05CA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('allopurinol', 'M04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('allopurinol, kombinationen', 'M04AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('allylestrenol', 'G03DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('almagat', 'A02AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('almasilat', 'A02AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('alminoprofen', 'M01AE16');
INSERT INTO staging.atc (description, atc_code) VALUES ('almitrin', 'R07AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('almotriptan', 'N02CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('alogliptin', 'A10BH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aloglutamol', 'A02AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('alosetron', 'A03AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aloxiprin', 'B01AC15');
INSERT INTO staging.atc (description, atc_code) VALUES ('aloxiprin', 'N02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha- und beta-adrenorezeptor-agonisten', 'R03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha- und beta-adrenorezeptor-agonisten', 'R03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha- und beta-adrenorezeptor-antagonisten', 'C07AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha- und beta-adrenorezeptor-antagonisten und andere diuretika', 'C07CG');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha- und beta-adrenorezeptor-antagonisten und thiazide', 'C07BG');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha-adrenorezeptor-antagonisten', 'C02CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha-adrenorezeptor-antagonisten', 'G04CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha-adrenorezeptor-antagonisten und diuretika', 'C02LE');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha-glukosidasehemmer', 'A10BF');
INSERT INTO staging.atc (description, atc_code) VALUES ('alpha-liponsäure (thioctsäure)', 'A16AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alprazolam', 'N05BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('alprenolol', 'C07AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alprostadil', 'C01EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alprostadil', 'G04BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('alprostadil', 'G04BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('alsactid', 'V04CH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('alteplase', 'B01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('alteplase', 'S01XA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('altizid und kalium sparende mittel', 'C03EA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('altretamin', 'L01XX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium-haltige mittel', 'D08AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium-haltige verbindungen', 'A02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminium-haltige zubereitungen', 'C05AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminiumacetattartrat', 'S02AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminiumacetoacetat', 'A02AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminiumchlorid', 'D10AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminiumclofibrat', 'C10AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminiumglycinat', 'A02AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminiumhydroxid', 'A02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminiumhydroxychlorid', 'D09AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminiumhydroxychlorid', 'M05BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminiumnicotinat', 'C10AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminiumoxid', 'D10AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aluminiumphosphat', 'A02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('alverin', 'A03AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('alverin, kombinationen', 'A03AX58');
INSERT INTO staging.atc (description, atc_code) VALUES ('alvimopan', 'A06AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('amantadin', 'N04BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ambazon', 'R02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ambenonium', 'N07AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('ambroxol', 'R05CB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ambutonium und psycholeptika', 'A03CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('amcinonid', 'D07AC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('amfepramon', 'A08AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('amfetamin', 'N06BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amfetaminil', 'N06BA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('amide', 'N01BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('amidotrizoesäure', 'V08AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amifampridin', 'N07XX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('amifostin', 'V03AF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('amikacin', 'D06AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('amikacin', 'S01AA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('amikacin', 'J01GB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('amilorid', 'C03DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amineptin', 'N06AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('amino(diphenylhydantoin)valeriansäure', 'N03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminoacridin', 'D08AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminoalkylether', 'R06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminobenzoesäure', 'D02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminobuttersäure', 'N03AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminocapronsäure', 'B02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminochinoline', 'P01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminoglutethimid', 'L02BG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminoglykosid-antibiotika', 'J01G');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminohippursäure', 'V04CH30');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminolevulinsäure', 'L01XD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminomethylbenzoesäure', 'B02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminophenazon', 'N02BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminophenazon, kombinationen exkl. psycholeptika', 'N02BB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminophenazon, kombinationen mit psycholeptika', 'N02BB73');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminophyllin', 'R03DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminophyllin und sympathomimetika', 'R03DB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminophyllin, kombinationen', 'R03DA55');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosalicylsäure', 'J04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosalicylsäure und derivate', 'J04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosalicylsäure und ähnliche mittel', 'A07EC');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosäuren', 'B05XB');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosäuren', 'B02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosäuren', 'B05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosäuren und derivate', 'A16AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosäuren, inkl. kombination mit polypeptiden', 'V06DD');
INSERT INTO staging.atc (description, atc_code) VALUES ('aminosäuren/kohlenhydrate/mineralstoffe/vitamine, kombinationen', 'V06DE');
INSERT INTO staging.atc (description, atc_code) VALUES ('amiodaron', 'C01BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amisulprid', 'N05AL05');
INSERT INTO staging.atc (description, atc_code) VALUES ('amitriptylin', 'N06AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('amitriptylin und psycholeptika', 'N06CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amlexanox', 'R03DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amlexanox', 'A01AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('amlodipin', 'C08CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ammoniumchlorid', 'B05XA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ammoniumchlorid', 'G04BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ammoniumeisen(iii)citrat', 'V08CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('amobarbital', 'N05CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('amodiaquin', 'P01BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('amorolfin', 'D01AE16');
INSERT INTO staging.atc (description, atc_code) VALUES ('amoxapin', 'N06AA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('amoxicillin', 'J01CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('amoxicillin und enzym-inhibitoren', 'J01CR02');
INSERT INTO staging.atc (description, atc_code) VALUES ('amphenicole', 'J01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('amphenicole', 'J01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('amphotericin b', 'G01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('amphotericin b', 'A01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('amphotericin b', 'A07AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('amphotericin b', 'J02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ampicillin', 'J01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ampicillin', 'S01AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('ampicillin und enzym-inhibitoren', 'J01CR01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ampicillin, kombinationen', 'J01CA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('amprenavir', 'J05AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('amrinon', 'C01CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amsacrin', 'L01XX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('amylnitrit', 'V03AB22');
INSERT INTO staging.atc (description, atc_code) VALUES ('anabole steroide', 'A14A');
INSERT INTO staging.atc (description, atc_code) VALUES ('anabolika zur systemischen anwendung', 'A14');
INSERT INTO staging.atc (description, atc_code) VALUES ('anagrelid', 'L01XX35');
INSERT INTO staging.atc (description, atc_code) VALUES ('anakinra', 'L04AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('analgetika', 'N02');
INSERT INTO staging.atc (description, atc_code) VALUES ('analgetika und anästhetika', 'S02DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('anastrozol', 'L02BG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ancestim', 'L03AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('ancrod', 'B01AD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere additiva zu i.v.-lösungen', 'B05XX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere aknemittel zur systemischen anwendung', 'D10BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere aknemittel zur topischen anwendung', 'D10AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere alkylierende mittel', 'L01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere allgemeinanästhetika', 'N01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere aminoglykoside', 'J01GB');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere anabolika', 'A14B');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere analgetika und antipyretika', 'N02BG');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere analgetika und antipyretika', 'N02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antiallergika', 'S01GX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antianämika', 'B03XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antianämika', 'B03X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antibiotika', 'J01XX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antibiotika', 'J01X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antibiotika zur topischen anwendung', 'D06AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antidementiva', 'N06DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antidepressiva', 'N06AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antidiabetika', 'A10X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antidiabetika, exkl. insuline', 'A10BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antidiarrhoika', 'A07XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antidiarrhoika', 'A07X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antiemetika', 'A04AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antiepileptika', 'N03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antihistaminika zur systemischen anwendung', 'R06AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antihypertonika', 'C02K');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antihypertonika', 'C02KX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antihypertonika und diuretika', 'C02LX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antiinfektiva', 'S01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antiinfektiva und antiseptika', 'G01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antimykotika zur systemischen anwendung', 'J02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antimykotika zur topischen anwendung', 'D01AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antineoplastische mittel', 'L01X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antineoplastische mittel', 'L01XX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antiphlogistika/antirheumatika in kombination mit anderen mitteln', 'M01BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antipruriginosa', 'D04AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antipsoriatika zur systemischen anwendung', 'D05BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antipsoriatika zur topischen anwendung', 'D05AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antipsychotika', 'N05AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antiseptika und desinfektionsmittel', 'D08AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antithrombotische mittel', 'B01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antitussiva', 'R05DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antitussiva und expektoranzien', 'R05FB');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere antivirale mittel', 'J05AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere anxiolytika', 'N05BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere bakterielle impfstoffe', 'J07AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere bandwurmmittel', 'P02DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere bei herzerkrankungen eingesetzte vasodilatatoren', 'C01DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere beta-lactam-antibiotika', 'J01D');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere blutprodukte', 'B05AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere cefalosporine', 'J01DI');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere chemotherapeutika', 'D06BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere chinolone', 'J01MB');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere chirurgische hilfsmittel', 'S01KX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere dermatika', 'D11A');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere dermatika', 'D11AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere dermatika', 'D11');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere diagnostika', 'V04C');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere diagnostika', 'V04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere diätetika', 'V06D');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere diätetika-kombinationen', 'V06DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere dopaminerge mittel', 'N04BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere emollientia und hautschutzmittel', 'D02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere entzündungshemmende radiotherapeutika', 'V10AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere gichtmittel', 'M04AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere glaukommittel', 'S01EX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere gynäkologika', 'G02C');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere gynäkologika', 'G02CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere gynäkologika', 'G02');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere hals- und rachentherapeutika', 'R02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere herzglykoside', 'C01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere herzmittel', 'C01E');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere herzmittel', 'C01EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere herzmittel, kombinationen', 'C01EX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere high-ceiling-diuretika', 'C03CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere hormonantagonisten und verwandte mittel', 'L02BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere hormone', 'L02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere hypnotika und sedativa', 'N05CM');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere hypophysenvorderlappenhormone und analoga', 'H01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere hämatologika', 'B06');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere hämatologika', 'B06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere hämorrhoidenmittel, kombinationen', 'C05AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere hämprodukte', 'B06AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere immunglobuline', 'J06BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere immunstimulanzien', 'L03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere immunsuppressiva', 'L04AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere impfstoffe', 'J07X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere inhalative mittel bei obstruktiven atemwegserkrankungen', 'R03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere inhalative mittel bei obstruktiven atemwegserkrankungen', 'R03BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere insektizide und repellenzien', 'P03BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere intestinale adsorbenzien', 'A07BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere intestinale antiinfektiva', 'A07AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere kalium sparende mittel', 'C03DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere kapillarstabilisierende mittel', 'C05CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere kardiostimulanzien', 'C01CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere klasse-i-antiarrhythmika', 'C01BG');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere kombinationspräparate gegen erkältungskrankheiten', 'R05X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere kontrastmittel für die magnetresonanztomographie', 'V08CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere laxanzien', 'A06AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere lokalanästhetika', 'N01BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere low-ceiling-diuretika', 'C03BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere malariamittel', 'P01BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere meningokokken monovalent, gereinigtes polysaccharid-antigen', 'J07AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere meningokokken polyvalent, gereinigtes polysaccharid-antigen', 'J07AH05');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere migränemittel', 'N02CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mineralstoff-haltige zubereitungen', 'A12CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mineralstoffe', 'A12C');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel bei benigner prostatahyperplasie', 'G04CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel bei funktionellen störungen des darms', 'A03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel bei obstruktiven atemwegserkrankungen zur systemischen anwendung', 'R03D');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel bei obstruktiven atemwegserkrankungen zur systemischen anwendung', 'R03DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel bei peptischem ulkus und gastroesophagealer refluxkrankheit', 'A02BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel bei säure bedingten erkrankungen', 'A02X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel für das alimentäre system und den stoffwechsel', 'A16');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel für das alimentäre system und den stoffwechsel', 'A16A');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel für das nervensystem', 'N07XX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel für das nervensystem', 'N07');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel für das nervensystem', 'N07X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel für den respirationstrakt', 'R07');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel für den respirationstrakt', 'R07AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel für den respirationstrakt', 'R07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel gegen amöbiasis und andere protozoen-erkrankungen', 'P01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel gegen ektoparasiten, inkl. antiscabiosa', 'P03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel gegen leishmaniasis und trypanosomiasis', 'P01CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel gegen störungen des muskel- und skelettsystems', 'M09');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel gegen störungen des muskel- und skelettsystems', 'M09A');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel gegen störungen des muskel- und skelettsystems', 'M09AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel mit einfluss auf die knochenstruktur und die mineralisation', 'M05BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel mit wirkung auf das renin-angiotensin-system', 'C09X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel zur behandlung der tuberkulose', 'J04AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel zur behandlung von hämorrhoiden und analfissuren zur topischen anwendung', 'C05AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel zur gallentherapie', 'A05AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel zur oralen lokalbehandlung', 'A01AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere mittel, die den lipidstoffwechsel beeinflussen', 'C10AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere muskelrelaxanzien, peripher wirkende mittel', 'M03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere nebenschilddrüsen-antagonisten', 'H05BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere nematodenmittel', 'P02CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere nichtselektive calciumkanalblocker', 'C08EX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere nichtsteroidale antiphlogistika und antirheumatika', 'M01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere nichttherapeutische hilfsmittel', 'V07AY');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere ophthalmika', 'S01X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere ophthalmika', 'S01XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere ophthalmologische diagnostika', 'S01JX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere ophthalmologische und otologische zubereitungen', 'S03D');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere opioide', 'N02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere otologika', 'S02D');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere parasympathomimetika', 'N07AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere periphere vasodilatatoren', 'C04AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere pflanzliche alkaloide und natürliche mittel', 'L01CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere plasmaproteinfraktionen', 'B05AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere psychostimulanzien und nootropika', 'N06BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere quartäre ammonium-verbindungen', 'M03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere radiodiagnostika', 'V09X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere radiodiagnostika für das kardiovaskuläre system', 'V09GX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere radiodiagnostika für das leber- und retikuloendothelialsystem', 'V09DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere radiodiagnostika für das nierensystem', 'V09CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere radiodiagnostika für das zentrale nervensystem', 'V09AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere radiodiagnostika für den respirationstrakt', 'V09EX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere radiodiagnostika zur erkennung von entzündungen und infektionen', 'V09HX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere radiodiagnostika zur tumorerkennung', 'V09IX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere radiotherapeutika', 'V10X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere rhinologika', 'R01AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere selektive calciumkanalblocker mit vorwiegender gefässwirkung', 'C08CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere sexualhormone und modulatoren des genitalsystems', 'G03X');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere sklerosierende mittel', 'C05BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere spasmolytika in kombination mit analgetika', 'A03DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere spasmolytika in kombination mit psycholeptika', 'A03CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere spezifische antirheumatika', 'M01CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere spüllösungen', 'B05CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere systemische hämostatika', 'B02BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere therapeutische mittel', 'V03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere thyreostatika', 'H03BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere topische mittel gegen gelenk- und muskelschmerzen', 'M02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere trematodenmittel', 'P02BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere urologika', 'G04BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere urologika, inkl. spasmolytika', 'G04B');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere virale impfstoffe', 'J07BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere vitaminpräparate, kombinationen', 'A11J');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere vitaminpräparate, rein', 'A11HA');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere vitaminpräparate, rein', 'A11H');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere wehen fördernde mittel', 'G02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere wundbehandlungsmittel', 'D03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere zentral wirkende mittel', 'M03BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere zytotoxische antibiotika', 'L01DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('andere östrogene', 'G03CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgen, gestagen und estrogen in kombination', 'G03EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgene', 'G03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgene und estrogene', 'G03EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgene und weibliche sexualhormone in kombination', 'G03E');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgene und weibliche sexualhormone in kombination mit anderen mitteln', 'G03EK');
INSERT INTO staging.atc (description, atc_code) VALUES ('androgene zur topischen anwendung', 'D11AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('androstan-derivate', 'A14AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('androstanolon', 'G03BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('androstanolon', 'A14AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('anecortav', 'S01LA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('anetholtrithion', 'A16AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensin-ii-antagonisten und diuretika', 'C09DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensin-ii-antagonisten, andere kombinationen', 'C09DX');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensin-ii-antagonisten, kombinationen', 'C09D');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensin-ii-antagonisten, rein', 'C09C');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensin-ii-antagonisten, rein', 'C09CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('angiotensinamid', 'C01CX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('anileridin', 'N01AH05');
INSERT INTO staging.atc (description, atc_code) VALUES ('anilide', 'N02BE');
INSERT INTO staging.atc (description, atc_code) VALUES ('aniracetam', 'N06BX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('anistreplase', 'B01AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('antacida', 'A02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antacida mit karminativa', 'A02AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('antacida mit natriumbicarbonat', 'A02AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('antacida mit spasmolytika', 'A02AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('antacida, andere kombinationen', 'A02AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('antazolin', 'R01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('antazolin', 'R06AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('anthelmintika', 'P02');
INSERT INTO staging.atc (description, atc_code) VALUES ('anthracen-derivate', 'D05AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('anthracycline und verwandte substanzen', 'L01DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('anthrax-antigen', 'J07AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-d(rh)-immunglobulin', 'J06BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('anti-wachstumshormone', 'H01CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiadiposita, exkl. diätetika', 'A08');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiadiposita, exkl. diätetika', 'A08A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiadrenerge mittel, ganglienblocker', 'C02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiadrenerge mittel, peripher wirkend', 'C02C');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiadrenerge mittel, zentral wirkend', 'C02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiallergika, exkl. corticosteroide', 'R01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiallergika, exkl. corticosteroide', 'A07EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiallergika, exkl. corticosteroide', 'R03BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiandrogene', 'L02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiandrogene', 'G03H');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiandrogene und estrogene', 'G03HB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiandrogene, rein', 'G03HA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antianämika', 'B03');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiarrhythmika, klasse i und iii', 'C01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiarrhythmika, klasse ia', 'C01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiarrhythmika, klasse ib', 'C01BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiarrhythmika, klasse ic', 'C01BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiarrhythmika, klasse iii', 'C01BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika', 'A07AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika', 'G01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika', 'R02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika', 'J04AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika', 'C05AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika', 'D01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika', 'J02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika', 'S01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika in kombination mit anderen mitteln', 'S01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika und chemotherapeutika zur dermatologischen anwendung', 'D06');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika und chemotherapeutika, kombinationen', 'D06C');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika und corticosteroide', 'G01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika zur systemischen anwendung', 'J01');
INSERT INTO staging.atc (description, atc_code) VALUES ('antibiotika zur topischen anwendung', 'D06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticholinergika', 'S01FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticholinergika', 'R03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticholinergika', 'N04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('anticorticosteroide', 'H02CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidementiva', 'N06D');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidepressiva', 'N06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidepressiva in kombination mit psycholeptika', 'N06CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidiabetika', 'A10');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidiabetika, exkl. insuline', 'A10B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidiarrhoika und intestinale antiphlogistika/antiinfektiva', 'A07');
INSERT INTO staging.atc (description, atc_code) VALUES ('antidote', 'V03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiemetika und mittel gegen übelkeit', 'A04');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiemetika und mittel gegen übelkeit', 'A04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiepileptika', 'N03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiepileptika', 'N03');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiestrogene', 'L02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antifibrinolytika', 'B02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antigestagene', 'G03XB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antigonadotropine und ähnliche mittel', 'G03XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihidrotika', 'D11AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihistaminika zur systemischen anwendung', 'R06');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihistaminika zur systemischen anwendung', 'R06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihistaminika zur topischen anwendung', 'D04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihypertonika', 'C02');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihypertonika und diuretika in kombination', 'C02L');
INSERT INTO staging.atc (description, atc_code) VALUES ('antihämorrhagika', 'B02');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva', 'B05CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva', 'S02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva', 'S01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva', 'S03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva', 'S03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva', 'S02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva und antiseptika zur oralen lokalbehandlung', 'A01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva und antiseptika, exkl. kombinationen mit corticosteroiden', 'G01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva zur behandlung der akne', 'D10AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva zur systemischen anwendung', 'J');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva, kombinationen', 'S03AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva, kombinationen', 'S02AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiinfektiva/antiseptika in kombination mit corticosteroiden', 'G01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antilymphozytäres immunglobulin (pferd)', 'L04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimetabolite', 'L01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimon-haltige verbindungen', 'P01CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimonpentasulfid', 'R05CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimykotika zur dermatologischen anwendung', 'D01');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimykotika zur systemischen anwendung', 'D01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimykotika zur systemischen anwendung', 'D01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimykotika zur systemischen anwendung', 'J02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimykotika zur systemischen anwendung', 'J02');
INSERT INTO staging.atc (description, atc_code) VALUES ('antimykotika zur topischen anwendung', 'D01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antineoplastische mittel', 'L01');
INSERT INTO staging.atc (description, atc_code) VALUES ('antineoplastische und immunmodulierende mittel', 'L');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiparasitäre mittel, insektizide und repellenzien', 'P');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiparkinsonmittel', 'N04');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiphlogistika', 'S01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiphlogistika und antiinfektiva in kombination', 'S01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiphlogistika und antirheumatika', 'M01');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiphlogistika zur vaginalen anwendung', 'G02CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiphlogistika/antirheumatika in kombination', 'M01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiphlogistika/antirheumatika in kombination mit corticosteroiden', 'M01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipruriginosa, inkl.  antihistaminika, anästhetika etc.', 'D04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipruriginosa, inkl. antihistaminika, anästhetika etc.', 'D04');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipsoriatika', 'D05');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipsoriatika zur systemischen anwendung', 'D05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipsoriatika zur topischen anwendung', 'D05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antipsychotika', 'N05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiseptika', 'R02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiseptika und corticosteroide', 'G01BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiseptika und desinfektionsmittel', 'D08');
INSERT INTO staging.atc (description, atc_code) VALUES ('antiseptika und desinfektionsmittel', 'D08A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antithrombin iii', 'B01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('antithrombotische mittel', 'B01');
INSERT INTO staging.atc (description, atc_code) VALUES ('antithrombotische mittel', 'B01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('antithymozytäres immunglobulin (kaninchen)', 'L04AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('antitussiva und expektoranzien', 'R05FB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('antitussiva und expektoranzien, kombinationen', 'R05F');
INSERT INTO staging.atc (description, atc_code) VALUES ('antitussiva und mukolytika', 'R05FB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('antitussiva, exkl. kombinationen mit expektoranzien', 'R05D');
INSERT INTO staging.atc (description, atc_code) VALUES ('antivarikosa', 'C05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('antivertiginosa', 'N07C');
INSERT INTO staging.atc (description, atc_code) VALUES ('antivertiginosa', 'N07CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('antivirale mittel', 'D06BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('antivirale mittel', 'S01AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('antivirale mittel zur systemischen anwendung', 'J05');
INSERT INTO staging.atc (description, atc_code) VALUES ('anxiolytika', 'N05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('anästhetika', 'N01');
INSERT INTO staging.atc (description, atc_code) VALUES ('apomorphin', 'N04BC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('apomorphin', 'G04BE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('appetit stimulierende mittel', 'A15');
INSERT INTO staging.atc (description, atc_code) VALUES ('apraclonidin', 'S01EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aprepitantit, fosaprepitant', 'A04AD12');
INSERT INTO staging.atc (description, atc_code) VALUES ('aprindin', 'C01BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aprobarbital', 'N05CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('apronal', 'N05CM12');
INSERT INTO staging.atc (description, atc_code) VALUES ('aprotinin', 'B02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('arbutamin', 'C01CA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('argatroban', 'B01AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('argininglutamat', 'A05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('argininhydrochlorid', 'B05XB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('argipressin', 'H01BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('aripiprazol', 'N05AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('arsen-haltige verbindungen', 'P01AR');
INSERT INTO staging.atc (description, atc_code) VALUES ('arsen-haltige verbindungen', 'P01CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('arsen-haltige verbindungen', 'G01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('arsentrioxid', 'L01XX27');
INSERT INTO staging.atc (description, atc_code) VALUES ('arsthinol', 'P01AR01');
INSERT INTO staging.atc (description, atc_code) VALUES ('artemether', 'P01BE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('artemether, kombinationen', 'P01BE52');
INSERT INTO staging.atc (description, atc_code) VALUES ('artemisinin', 'P01BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('artemisinin und derivate', 'P01BE');
INSERT INTO staging.atc (description, atc_code) VALUES ('artemotil', 'P01BE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('artenimol', 'P01BE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('artesunat', 'P01BE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('articain', 'N01BB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('articain, kombinationen', 'N01BB58');
INSERT INTO staging.atc (description, atc_code) VALUES ('aryloxyessigsäure-derivate', 'C03CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbinsäure', 'G01AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbinsäure', 'S01XA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbinsäure (vitamin c)', 'A11GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbinsäure (vitamin c) und calcium', 'A11GB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbinsäure (vitamin c), inkl. kombinationen', 'A11G');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbinsäure (vitamin c), kombinationen', 'A11GB');
INSERT INTO staging.atc (description, atc_code) VALUES ('ascorbinsäure (vitamin c), rein', 'A11GA');
INSERT INTO staging.atc (description, atc_code) VALUES ('asenapin', 'N05AH05');
INSERT INTO staging.atc (description, atc_code) VALUES ('asparaginase', 'L01XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('astemizol', 'R06AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('atazanavir', 'J05AE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('atemstimulanzien', 'R07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('atenolol', 'C07AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('atenolol und andere antihypertonika', 'C07FB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('atenolol und andere diuretika', 'C07CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('atenolol und andere diuretika, kombinationen', 'C07CB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('atenolol und thiazide', 'C07BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('atenolol, thiazide und andere diuretika', 'C07DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('atomoxetin', 'N06BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('atorvastatin', 'C10AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('atorvastatin und amlodipin', 'C10BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('atosiban', 'G02CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('atovaquon', 'P01AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('atracurium', 'M03AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('atropin', 'S01FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('atropin', 'A03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('atropin und psycholeptika', 'A03CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('attapulgit', 'A07BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('attapulgit, kombinationen', 'A07BC54');
INSERT INTO staging.atc (description, atc_code) VALUES ('auf serotonin-rezeptoren wirkende mittel', 'A03AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('auranofin', 'M01CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('aurothioglucose', 'M01CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('aurotioprol', 'M01CB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('avermektine', 'P02CF');
INSERT INTO staging.atc (description, atc_code) VALUES ('azanidazol', 'P01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('azanidazol', 'G01AF13');
INSERT INTO staging.atc (description, atc_code) VALUES ('azapetin', 'C04AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('azapropazon', 'M01AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('azaspirodecandion-derivate', 'N05BE');
INSERT INTO staging.atc (description, atc_code) VALUES ('azatadin', 'R06AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('azathioprin', 'L04AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('azelainsäure', 'D10AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('azelastin', 'R06AX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('azelastin', 'R01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('azelastin', 'S01GX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('azidamfenicol', 'S01AA25');
INSERT INTO staging.atc (description, atc_code) VALUES ('azidocillin', 'J01CE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('azithromycin', 'J01FA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('azithromycin', 'S01AA26');
INSERT INTO staging.atc (description, atc_code) VALUES ('azlocillin', 'J01CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('aztreonam', 'J01DF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacampicillin', 'J01CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacitracin', 'D06AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacitracin', 'J01XX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('bacitracin', 'R02AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('baclofen', 'M03BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bakterielle impfstoffe', 'J07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('bakterielle und virale impfstoffe, kombiniert', 'J07CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('bakterielle und virale impfstoffe, kombiniert', 'J07C');
INSERT INTO staging.atc (description, atc_code) VALUES ('baldrian', 'N05CM09');
INSERT INTO staging.atc (description, atc_code) VALUES ('balsalazid', 'A07EC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('bambuterol', 'R03CC12');
INSERT INTO staging.atc (description, atc_code) VALUES ('bamethan', 'C04AA31');
INSERT INTO staging.atc (description, atc_code) VALUES ('bamifyllin', 'R03DA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('bamipin', 'D04AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('bamipin', 'R06AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bandwurmmittel', 'P02D');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbexaclon', 'N03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbital', 'N05CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturate in kombination mit anderen mitteln', 'N05CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturate in kombination mit anderen mitteln', 'N01AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturate und derivate', 'N03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturate, kombinationen', 'N05CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturate, rein', 'N05CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('barbiturate, rein', 'N01AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('bariumsulfat mit suspensionsmittel', 'V08BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bariumsulfat ohne suspensionsmittel', 'V08BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bariumsulfat-haltige röntgenkontrastmittel', 'V08BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('barnidipin', 'C08CA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('basiliximab', 'L04AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('batroxobin', 'B02BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('baumpollen', 'V01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bazedoxifen', 'G03XC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bcg-impfstoff', 'L03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('becaplermin', 'A01AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('becaplermin', 'D03AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclamid', 'N03AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclometason', 'A07EA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclometason', 'R01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclometason', 'R03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclometason', 'D07AC15');
INSERT INTO staging.atc (description, atc_code) VALUES ('beclometason und antibiotika', 'D07CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('befunolol', 'S01ED06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bei herzerkrankungen eingesetzte vasodilatatoren', 'C01D');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna und derivate in kombination mit analgetika', 'A03DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna und derivate in kombination mit psycholeptika', 'A03CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna und derivate, rein', 'A03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna-alkaloide, halbsynthetisch, quartäre ammonium-verbindungen', 'A03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna-alkaloide, tertiäre amine', 'A03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna-gesamtalkaloide', 'A03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('belladonna-gesamtalkaloide und psycholeptika', 'A03CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bemegrid', 'R07AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bemiparin', 'B01AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('benazepril', 'C09AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('benazepril und diuretika', 'C09BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bencyclan', 'C04AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('bendamustin', 'L01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('bendazac', 'M02AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('bendazac', 'S01BC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bendroflumethiazid', 'C03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bendroflumethiazid und kalium', 'C03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bendroflumethiazid und kalium sparende mittel', 'C03EA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('benfluorex', 'A10BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bengalrosa-natrium', 'S01JA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('benidipin', 'C08CA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('benorilat', 'N02BA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('benoxaprofen', 'M01AE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('benperidol', 'N05AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('benproperin', 'R05DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bentiromid', 'V04CK03');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzalkonium', 'D09AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzalkonium', 'D08AJ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzalkonium', 'R02AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzamide', 'N05AL');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzatropin', 'N04AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzbromaron', 'M04AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzethonium', 'R02AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzethoniumchlorid', 'D08AJ08');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzethoniumchlorid, kombinationen', 'D08AJ58');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzilon', 'A03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzimidazol-derivate', 'P02CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('benziodaron', 'C01DX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('benziodaron, kombinationen', 'C01DX54');
INSERT INTO staging.atc (description, atc_code) VALUES ('benznidazol', 'P01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzocain', 'R02AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzocain', 'D04AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzocain', 'C05AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzocain', 'N01BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzoctamin', 'N05BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzodiazepin-derivate', 'N03AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzodiazepin-derivate', 'N05CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzodiazepin-derivate', 'N05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzodiazepin-verwandte mittel', 'N05CF');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzododecinium', 'D09AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzomorphan-derivate', 'N02AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzonatat', 'R05DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzothiazepin-derivate', 'C08DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzoxoniumchlorid', 'D08AJ05');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzoxoniumchlorid', 'A01AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzoylperoxid', 'D10AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzoylperoxid, kombinationen', 'D10AE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzydamin', 'A01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzydamin', 'M01AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzydamin', 'G02CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzydamin', 'M02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzylbenzoat', 'P03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzylpenicillin', 'J01CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzylpenicillin', 'S01AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzylpenicillin-benzathin', 'J01CE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzylpenicillin-procain', 'J01CE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('benzylthiouracil', 'H03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bephenium', 'P02CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bepridil', 'C08EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('beraprost', 'B01AC19');
INSERT INTO staging.atc (description, atc_code) VALUES ('bergapten', 'D05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten', 'S01ED');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten', 'C07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten und andere antihypertonika', 'C07F');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten und andere diuretika', 'C07C');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten und thiazide', 'C07B');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten und vasodilatatoren', 'C07E');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten*', 'C07');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, nichtselektiv', 'C07AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, nichtselektiv, thiazide und andere diuretika', 'C07DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, nichtselektiv, und andere antihypertonika', 'C07FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, nichtselektiv, und andere diuretika', 'C07CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, nichtselektiv, und thiazide', 'C07BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, nichtselektiv, und vasodilatatoren', 'C07EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, selektiv', 'C07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, selektiv, thiazide und andere diuretika', 'C07DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, selektiv, und andere antihypertonika', 'C07FB');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, selektiv, und andere diuretika', 'C07CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, selektiv, und thiazide', 'C07BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, selektiv, und vasodilatatoren', 'C07EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-adrenorezeptor-antagonisten, thiazide und andere diuretika', 'C07D');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-lactamase-inhibitoren', 'J01CG');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-lactamase-resistente penicilline', 'J01CF');
INSERT INTO staging.atc (description, atc_code) VALUES ('beta-lactamase-sensitive penicilline', 'J01CE');
INSERT INTO staging.atc (description, atc_code) VALUES ('betacaroten', 'D02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betacaroten', 'A11CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('betahistin', 'N07CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betain', 'A16AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('betainhydrochlorid', 'A09AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('betalactam-antibiotika, penicilline', 'J01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason', 'R03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason', 'C05AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason', 'S02BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason', 'S01CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason', 'S01BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason', 'D07XC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason', 'A07EA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason', 'S03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason', 'H02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason', 'D07AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason', 'R01AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason und antibiotika', 'D07CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason und antiinfektiva', 'S01CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason und antiinfektiva', 'S03CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason und antiseptika', 'D07BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betamethason und mydriatika', 'S01BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('betanidin', 'C02CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('betaxolol', 'C07AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('betaxolol', 'S01ED02');
INSERT INTO staging.atc (description, atc_code) VALUES ('betaxolol, kombinationen', 'S01ED52');
INSERT INTO staging.atc (description, atc_code) VALUES ('betazol', 'V04CG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bethanechol', 'N07AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bevacizumab', 'L01XC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bevantolol', 'C07AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bevantolol und thiazide', 'C07BB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bevonium', 'A03AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('bevonium und analgetika', 'A03DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bevonium und psycholeptika', 'A03CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bexaroten', 'L01XX25');
INSERT INTO staging.atc (description, atc_code) VALUES ('bezafibrat', 'C10AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bezitramid', 'N02AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('biapenem', 'J01DH05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bibenzoniumbromid', 'R05DB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('bibrocathol', 'S01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bicalutamid', 'L02BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bietaserpin', 'C02AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bietaserpin und diuretika', 'C02LA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bietaserpin, kombinationen', 'C02AA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('bifemelan', 'N06AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('bifonazol', 'D01AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('bifonazol, kombinationen', 'D01AC60');
INSERT INTO staging.atc (description, atc_code) VALUES ('biguanide', 'P01BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('biguanide', 'A10BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('biguanide und amidine', 'D08AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('bimatoprost', 'S01EE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bioallethrin', 'P03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bioallethrin, kombinationen', 'P03AC52');
INSERT INTO staging.atc (description, atc_code) VALUES ('bioflavonoide', 'C05CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('biotin', 'A11HA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('biperiden', 'N04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('biphenylol', 'D08AE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisacodyl', 'A06AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisacodyl', 'A06AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisacodyl, kombinationen', 'A06AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('bismut-haltige zubereitungen', 'A07BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('bismutpräparate, kombinationen', 'C05AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bismutsubcitrat', 'A02BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bismutsubnitrat', 'A02BX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisoprolol', 'C07AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisoprolol und thiazide', 'C07BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisoprolol, kombinationen', 'C07AB57');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisoxatin', 'A06AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisphosphonate', 'M05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisphosphonate, kombinationen', 'M05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('bisquartäre ammonium-verbindungen', 'C02BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('bithionol', 'D10AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bithionol', 'P02BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bitolterol', 'R03AC17');
INSERT INTO staging.atc (description, atc_code) VALUES ('bituminosulfonate', 'D10AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('bivalirudin', 'B01AE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('bleomycin', 'L01DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('blut und blut bildende organe', 'B');
INSERT INTO staging.atc (description, atc_code) VALUES ('blut und verwandte produkte', 'B05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('blut-tests, hilfsmittel', 'V07AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('blutersatzmittel und perfusionslösungen', 'B05');
INSERT INTO staging.atc (description, atc_code) VALUES ('blutersatzmittel und plasmaproteinfraktionen', 'B05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('blutgerinnungsfaktoren', 'B02BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('blutplasma', 'B05AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bluttransfusionen, hilfsstoffe', 'V07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('blüten', 'V01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('bopindolol', 'C07AA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('bopindolol und andere diuretika', 'C07CA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('bornaprin', 'N04AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('borsäure', 'S02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('borsäure-haltige mittel', 'D08AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('bortezomib', 'L01XX32');
INSERT INTO staging.atc (description, atc_code) VALUES ('bosentan', 'C02KX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('botulinumtoxin', 'M03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('botulismus-antitoxin', 'J06AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('bretyliumtosilat', 'C01BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('brimonidin', 'S01EA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('brinase', 'B01AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('brinzolamid', 'S01EC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('brodimoprim', 'J01EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromazepam', 'N05BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromazin', 'R06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromchlorsalicylanilid', 'D01AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromelaine', 'B06AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromfenac', 'S01BC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromhexin', 'R05CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromide', 'N05CM11');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromisoval', 'N05CM03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromocriptin', 'N04BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromocriptin', 'G02CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromoprid', 'A03FA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromperidol', 'N05AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('brompheniramin', 'R06AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('brompheniramin, kombinationen', 'R06AB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('bromsulfalein', 'V04CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('brotizolam', 'N05CD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('broxychinolin', 'A07AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('broxychinolin', 'G01AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('broxychinolin', 'P01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('brucella-antigen', 'J07AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('brucellose-impfstoffe', 'J07AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('bucetin', 'N02BE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('bucetin, kombinationen exkl. psycholeptika', 'N02BE54');
INSERT INTO staging.atc (description, atc_code) VALUES ('bucetin, kombinationen mit psycholeptika', 'N02BE74');
INSERT INTO staging.atc (description, atc_code) VALUES ('bucillamin', 'M01CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bucladesin', 'C01CE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('buclizin', 'R06AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('buclizin, kombinationen', 'R06AE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('budesonid', 'R03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('budesonid', 'A07EA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('budesonid', 'R01AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('budesonid', 'D07AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('budipin', 'N04BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bufexamac', 'M01AB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('bufexamac', 'M02AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('buflomedil', 'C04AX20');
INSERT INTO staging.atc (description, atc_code) VALUES ('buformin', 'A10BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('bufyllin', 'R03DA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('bumadizon', 'M01AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('bumetanid', 'C03CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bumetanid und kalium', 'C03CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bumetanid und kalium sparende mittel', 'C03EB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bunaftin', 'C01BD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('buphenin', 'C04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('buphenin', 'G02CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('bupivacain', 'N01BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('bupivacain, kombinationen', 'N01BB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('bupranolol', 'C07AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('buprenorphin', 'N07BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('buprenorphin', 'N02AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('buprenorphin, kombinationen', 'N07BC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('bupropion', 'N06AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('buserelin', 'L02AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('buspiron', 'N05BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('busulfan', 'L01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('butalamin', 'C04AX23');
INSERT INTO staging.atc (description, atc_code) VALUES ('butamirat', 'R05DB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('butanilicain', 'N01BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('butaperazin', 'N05AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('butenafin', 'D01AE23');
INSERT INTO staging.atc (description, atc_code) VALUES ('butizid und kalium sparende mittel', 'C03EA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('butobarbital', 'N05CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('butoconazol', 'G01AF15');
INSERT INTO staging.atc (description, atc_code) VALUES ('butorphanol', 'N02AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('butriptylin', 'N06AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('butylpyrazolidine', 'M01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('butylscopolamin', 'A03BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('butylscopolamin und analgetika', 'A03DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('butyrophenon-derivate', 'N05AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('c1-inhibitor', 'B02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cabergolin', 'N04BC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cabergolin', 'G02CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cadexomer-iod', 'D03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cadmium-haltige verbindungen', 'D11AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cadralazin', 'C02DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cafedrin', 'C01CA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcifediol', 'A11CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcineurin-inhibitoren', 'L04AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcipotriol', 'D05AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcipotriol, kombinationen', 'D05AX52');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcitonin (lachs, synthetisch)', 'H05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcitonin (mensch, synthetisch)', 'H05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcitonin (schwein, natürlich)', 'H05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcitonin-haltige zubereitungen', 'H05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcitriol', 'D05AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcitriol', 'A11CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium', 'A12A');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium', 'A12AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium (verschiedene salze in kombination)', 'A12AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium carbimid', 'N07BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium, kombinationen mit anderen mitteln', 'A12AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium-haltige verbindungen', 'A07XA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calcium-haltige verbindungen', 'A02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumacetat, wasserfrei', 'A12AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumalginat', 'B02BC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumaminosalicylat', 'J04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumcarbonat', 'A12AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumcarbonat', 'A02AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumchlorid', 'B05XA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumchlorid', 'A12AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumchlorid', 'G04BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumcitratlysin-komplex', 'A12AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumdobesilat', 'C05BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumdobesilat, kombinationen', 'C05BX51');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumfolinat', 'V03AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumglubionat', 'A12AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumglucoheptonat', 'A12AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumgluconat', 'D11AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumgluconat*', 'A12AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumglycerylphosphat', 'A12AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumhexaminthiocyanat', 'R01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumhomöostase', 'H05');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumiopodat', 'V08AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumkanalblocker', 'C08');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumkanalblocker und diuretika', 'C08GA');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumkanalblocker und diuretika', 'C08G');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumlactat', 'A12AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumlactogluconat', 'A12AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumlaevulat', 'A12AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumlevofolinat', 'V03AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumpangamat', 'A12AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumpantothenat', 'D03AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumpantothenat', 'A11HA31');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumphosphat', 'A12AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('calciumsilikat', 'A02AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('camazepam', 'N05BA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('camostat', 'B02AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('campher', 'C01EB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('camylofin', 'A03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('camylofin und analgetika', 'A03DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('canakinumab', 'L04AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('candesartan', 'C09CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('candesartan und diuretika', 'C09DA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('candicidin', 'G01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('canrenon', 'C03DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('capecitabin', 'L01BC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('capreomycin', 'J04AB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('capsaicin', 'N01BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('capsicum-haltige zubereitungen und ähnliche mittel', 'M02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('captodiam', 'N05BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('captopril', 'C09AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('captopril und diuretika', 'C09BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbachol', 'N07AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbachol', 'S01EB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbamate', 'N05BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbamazepin', 'N03AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbaminsäureester', 'M03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbapeneme', 'J01DH');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbasalat calcium', 'B01AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbasalat calcium', 'N02BA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbasalat calcium, kombinationen exkl. psycholeptika', 'N02BA65');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbazochrom', 'B02BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbenicillin', 'J01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbenoxolon', 'A02BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbenoxolon, kombinationen exkl. psycholeptika', 'A02BX51');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbenoxolon, kombinationen mit psycholeptika', 'A02BX71');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbetocin', 'H01BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbimazol', 'H03BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbinoxamin', 'R06AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('carboanhydrasehemmer', 'S01EC');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbocistein', 'R05CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbocromen', 'C01DX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('carboplatin', 'L01XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('carboprost', 'G02AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('carboquon', 'L01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('carboxamid-derivate', 'N03AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbromal', 'N05CM04');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbutamid', 'A10BB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbuterol', 'R03AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('carbuterol', 'R03CC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('carfecillin', 'G01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('carglumsäure', 'A16AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('carindacillin', 'J01CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('carisbamat', 'N03AX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('carisoprodol', 'M03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('carisoprodol, kombinationen exkl. psycholeptika', 'M03BA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('carisoprodol, kombinationen mit psycholeptika', 'M03BA72');
INSERT INTO staging.atc (description, atc_code) VALUES ('carmofur', 'L01BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('carmustin', 'L01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('caroverin', 'A03AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('carteolol', 'S01ED05');
INSERT INTO staging.atc (description, atc_code) VALUES ('carteolol', 'C07AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('carvedilol', 'C07AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cascara', 'A06AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cascara, kombinationen', 'A06AB57');
INSERT INTO staging.atc (description, atc_code) VALUES ('casopitant', 'A04AD13');
INSERT INTO staging.atc (description, atc_code) VALUES ('caspofungin', 'J02AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cathin', 'A08AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('catumaxomab', 'L01XC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefacetril', 'J01DB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefaclor', 'J01DC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefadroxil', 'J01DB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefalexin', 'J01DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefaloridin', 'J01DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefalosporine, dritte generation', 'J01DD');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefalosporine, erste generation', 'J01DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefalosporine, vierte generation', 'J01DE');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefalosporine, zweite generation', 'J01DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefalotin', 'J01DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefamandol', 'J01DC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefapirin', 'J01DB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefatrizin', 'J01DB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefazedon', 'J01DB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefazolin', 'J01DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefcapen', 'J01DD17');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefdinir', 'J01DD15');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefditoren', 'J01DD16');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefepim', 'J01DE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefetamet', 'J01DD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefixim', 'J01DD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefmenoxim', 'J01DD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefmetazol', 'J01DC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefodizim', 'J01DD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefonicid', 'J01DC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefoperazon', 'J01DD12');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefoperazon, kombinationen', 'J01DD62');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceforanid', 'J01DC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefotaxim', 'J01DD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefotetan', 'J01DC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefotiam', 'J01DC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefoxitin', 'J01DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefozopran', 'J01DE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefpiramid', 'J01DD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefpirom', 'J01DE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefpodoxim', 'J01DD13');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefprozil', 'J01DC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefradin', 'J01DB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefroxadin', 'J01DB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefsulodin', 'J01DD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftazidim', 'J01DD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftezol', 'J01DB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftibuten', 'J01DD14');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftizoxim', 'J01DD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftobiprol-medocaril', 'J01DI01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftriaxon', 'J01DD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceftriaxon, kombinationen', 'J01DD54');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefuroxim', 'J01DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cefuroxim, kombination mit anderen antibiotika', 'J01RA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('celecoxib', 'L01XX33');
INSERT INTO staging.atc (description, atc_code) VALUES ('celecoxib', 'M01AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('celiprolol', 'C07AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceratonia', 'A07XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceriumoxalat', 'A04AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cerivastatin', 'C10AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('certolizumab-pegol', 'L04AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ceruletid', 'V04CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetiedil', 'C04AX26');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetirizin', 'R06AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetrimid', 'D08AJ04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetrimid', 'D11AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetrimonium', 'R02AA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetrimonium', 'D08AJ02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetrorelix', 'H01CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetuximab', 'L01XC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetylpyridinium', 'R02AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetylpyridinium', 'B05CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetylpyridinium', 'D09AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cetylpyridinium', 'D08AJ03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cevimelin', 'N07AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chemikalien und reagenzien zur analyse', 'V07AZ');
INSERT INTO staging.atc (description, atc_code) VALUES ('chemotherapeutika zur topischen anwendung', 'D06B');
INSERT INTO staging.atc (description, atc_code) VALUES ('chenodeoxycholsäure', 'A05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinidin', 'C01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinidin, kombinationen exkl. psycholeptika', 'C01BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinidin, kombinationen mit psycholeptika', 'C01BA71');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinin', 'P01BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinin und derivate', 'M09AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinin, kombinationen mit psycholeptika', 'M09AA72');
INSERT INTO staging.atc (description, atc_code) VALUES ('chiniofon', 'P01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinisocain', 'D04AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinolin-derivate', 'D08AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinolin-derivate', 'G01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinolin-derivate und corticosteroide', 'G01BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinolin-derivate und verwandte substanzen', 'P02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinoline', 'M01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinolon-vasodilatatoren', 'C01DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('chinolone', 'J01M');
INSERT INTO staging.atc (description, atc_code) VALUES ('chirurgische hilfsmittel', 'S01K');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlor-haltige mittel', 'P03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloralhydrat', 'N05CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloralodol', 'N05CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorambucil', 'L01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'J01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'S03AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'D10AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'S02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'D06AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'S01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloramphenicol', 'G01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorbenzoxamin', 'A03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorbutanol', 'A04AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorbutanol, kombinationen', 'A04AD54');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorcyclizin', 'R06AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlordiazepoxid', 'N05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidin', 'A01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidin', 'S02AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidin', 'B05CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidin', 'D09AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidin', 'D08AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidin', 'S01AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidin', 'G04BX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidin', 'S03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidin', 'R02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorhexidin, kombinationen', 'D08AC52');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormadinon', 'G03DB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormadinon und estrogen', 'G03FB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormadinon und estrogen', 'G03AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormethin', 'L01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormezanon', 'M03BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormezanon, kombinationen exkl. psycholeptika', 'M03BB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormezanon, kombinationen mit psycholeptika', 'M03BB72');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlormidazol', 'D01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroform', 'N01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroprocain', 'N01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloropyramin', 'D04AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloropyramin', 'R06AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloropyramin, kombinationen', 'R06AC53');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroquin', 'P01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorothiazid', 'C03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorothiazid und kalium', 'C03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorothiazid, kombinationen', 'C03AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorotrianisen', 'G03CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('chloroxylenol', 'D08AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorphenamin', 'R06AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorphenamin, kombinationen', 'R06AB54');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorphenesin', 'D01AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorphenoxamin', 'D04AA34');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorphenoxamin', 'R06AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorphenoxamin, kombinationen', 'R06AA56');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorprednison und antiinfektiva', 'S01CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorproethazin', 'N05AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorpromazin', 'N05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorpropamid', 'A10BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorprothixen', 'N05AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorquinaldol', 'D08AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorquinaldol', 'G01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorquinaldol', 'P01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorquinaldol', 'R02AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortalidon', 'C03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortalidon und kalium', 'C03BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortalidon und kalium sparende mittel', 'C03EA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortetracyclin', 'D06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortetracyclin', 'A01AB21');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortetracyclin', 'J01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlortetracyclin', 'S01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorzoxazon', 'M03BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorzoxazon, kombinationen exkl. psycholeptika', 'M03BB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('chlorzoxazon, kombinationen mit psycholeptika', 'M03BB73');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholera, inaktiviert, ganze zelle', 'J07AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholera, kombinationen mit typhus-impfstoff, inaktiviert, ganze zelle', 'J07AE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholera, lebend abgeschwächt', 'J07AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholera-impfstoffe', 'J07AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholin-derivate', 'M03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholinalfoscerat', 'N07AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholinester', 'N07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholinesterase', 'V03AB29');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholinesterasehemmer', 'N07AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholinesterasehemmer', 'N06DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholinsalicylat', 'N02BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholintheophyllinat', 'R03DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholintheophyllinat und sympathomimetika', 'R03DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cholsäure', 'A05AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('chondroitinsulfat', 'M01AX25');
INSERT INTO staging.atc (description, atc_code) VALUES ('chondroitinsulfat b', 'B01AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chondroitinsulfat-eisen(iii)-komplex', 'B03AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('choriongonadotrophin', 'G03GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('choriongonadotropin alfa', 'G03GA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('chymopapain', 'M09AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('chymotrypsin', 'B06AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('chymotrypsin', 'S01KX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cibenzolin', 'C01BG07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclesonid', 'R03BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cicletanin', 'C03BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclobendazol', 'P02CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclonicat', 'C04AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclonium und analgetika', 'A03DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclopirox', 'D01AE14');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclopirox', 'G01AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclosporin', 'L04AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciclosporin', 'S01XA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('cidofovir', 'J05AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('cilazapril', 'C09AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cilazapril und diuretika', 'C09BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cilnidipin', 'C08CA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('cilostazol', 'B01AC22');
INSERT INTO staging.atc (description, atc_code) VALUES ('cimetidin', 'A02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cimetidin, kombinationen', 'A02BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('cimetropiumbromid', 'A03BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinacalcet', 'H05BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinchocain', 'D04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinchocain', 'C05AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinchocain', 'S01HA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinchocain', 'N01BB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinchophen', 'M04AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinepazet', 'C01DX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinepazid', 'C04AX27');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinnarizin', 'N07CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinnarizin, kombinationen', 'N07CA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinolazepam', 'N05CD13');
INSERT INTO staging.atc (description, atc_code) VALUES ('cinoxacin', 'J01MB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciprofibrat', 'C10AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciprofloxacin', 'S01AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciprofloxacin', 'S03AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ciprofloxacin', 'J01MA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cisaprid', 'A03FA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cisatracurium', 'M03AC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('cisplatin', 'L01XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('citalopram', 'N06AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('citicolin', 'N06BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('citiolon', 'A05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cladribin', 'L01BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clarithromycin', 'J01FA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cleboprid', 'A03FA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('clefamid', 'P01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clemastin', 'D04AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('clemastin', 'R06AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clemastin, kombinationen', 'R06AA54');
INSERT INTO staging.atc (description, atc_code) VALUES ('clenbuterol', 'R03AC14');
INSERT INTO staging.atc (description, atc_code) VALUES ('clenbuterol', 'R03CC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('clevudine', 'J05AF12');
INSERT INTO staging.atc (description, atc_code) VALUES ('clidinium und psycholeptika', 'A03CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clindamycin', 'G01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('clindamycin', 'D10AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clindamycin', 'J01FF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol', 'S02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol', 'D08AH30');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol', 'D09AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol', 'G01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol', 'P01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clioquinol, kombinationen', 'P01AA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobazam', 'N05BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobenzorex', 'A08AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobetasol', 'D07AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobetasol und antibiotika', 'D07CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobetason', 'S01BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobetason', 'D07AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobetason und antiinfektiva', 'S01CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('clobutinol', 'R05DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('clocortolon', 'D07AB21');
INSERT INTO staging.atc (description, atc_code) VALUES ('clodantoin', 'G01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clodronsäure', 'M05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofazimin', 'J04BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofedanol', 'R05DB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofenamid', 'C03BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofenamid und kalium', 'C03BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofenotan', 'P03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofenotan, kombinationen', 'P03AB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofezon', 'M01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofezon', 'M02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofibrat', 'C10AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofibrid', 'C10AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('clofoctol', 'J01XX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomethiazol', 'N05CM02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomethiazol, kombinationen', 'N05CX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clometocillin', 'J01CE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomifen', 'G03GB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomipramin', 'N06AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clomocyclin', 'J01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonazepam', 'N03AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonidin', 'N02CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonidin', 'C02AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonidin', 'S01EA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonidin und diuretika', 'C02LC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clonidin und diuretika, kombinationen mit anderen mitteln', 'C02LC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('clopamid', 'C03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('clopamid und kalium', 'C03BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('clopenthixol', 'N05AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloperastin', 'R05DB21');
INSERT INTO staging.atc (description, atc_code) VALUES ('clopidogrel', 'B01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloprednol', 'H02AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloranolol', 'C07AA27');
INSERT INTO staging.atc (description, atc_code) VALUES ('clorexolon', 'C03BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('clorexolon, kombinationen mit psycholeptika', 'C03BA82');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloricromen', 'B01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloridarol', 'C01DX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('clorindion', 'B01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('clostridiopeptidase', 'D03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('clostridiopeptidase, kombinationen', 'D03BA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('clotiapin', 'N05AH06');
INSERT INTO staging.atc (description, atc_code) VALUES ('clotiazepam', 'N05BA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('clotrimazol', 'A01AB18');
INSERT INTO staging.atc (description, atc_code) VALUES ('clotrimazol', 'D01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('clotrimazol', 'G01AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloxacillin', 'J01CF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cloxazolam', 'N05BA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('clozapin', 'N05AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cobamamid', 'B03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cocain', 'S02DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cocain', 'S01HA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cocain', 'R02AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cocain', 'N01BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('codein', 'R05DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('codein, kombinationen exkl. psycholeptika', 'N02AA59');
INSERT INTO staging.atc (description, atc_code) VALUES ('codein, kombinationen mit psycholeptika', 'N02AA79');
INSERT INTO staging.atc (description, atc_code) VALUES ('coffein', 'N06BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('coffein und natriumbenzoat', 'V04CG30');
INSERT INTO staging.atc (description, atc_code) VALUES ('colchicin', 'M04AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('colchicin-derivate', 'L01CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('colecalciferol', 'A11CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('colesevelam', 'C10AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('colestipol', 'C10AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('colestyramin', 'C10AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('colextran', 'C10AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('colfoscerilpalmitat', 'R07AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('colistin', 'A07AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('colistin', 'J01XB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('corifollitropin alpha', 'G03GA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticoliberin', 'V04CD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroid-derivate', 'N02CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide', 'S02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide', 'R01AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide', 'C05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide', 'S02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide', 'S03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide', 'S03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide mit lokaler wirkung', 'A07EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide und antiinfektiva in kombination', 'S03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide und antiinfektiva in kombination', 'S02C');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide und antiinfektiva in kombination', 'S01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide und antiinfektiva in kombination', 'S03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide und antiinfektiva in kombination', 'S02CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide und mydriatika in kombination', 'S01BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide zur oralen lokalbehandlung', 'A01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide zur systemischen anwendung', 'H02');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide zur systemischen anwendung, kombinationen', 'H02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide zur systemischen anwendung, kombinationen', 'H02BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide zur systemischen anwendung, rein', 'H02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, andere kombinationen', 'D07X');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, dermatologische zubereitungen', 'D07');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, kombinationen mit antibiotika', 'D07C');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, kombinationen mit antiseptika', 'D07B');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, kombinationen zur behandlung der akne', 'D10AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, mittelstark wirksam (gruppe ii)', 'D07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, mittelstark wirksam, andere kombinationen', 'D07XB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, mittelstark wirksam, kombinationen mit antibiotika', 'D07CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, mittelstark wirksam, kombinationen mit antiseptika', 'D07BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, rein', 'S01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, rein', 'D07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, schwach wirksam (gruppe i)', 'D07AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, schwach wirksam, andere kombinationen', 'D07XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, schwach wirksam, kombinationen mit antibiotika', 'D07CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, schwach wirksam, kombinationen mit antiseptika', 'D07BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, sehr stark wirksam (gruppe iv)', 'D07AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, sehr stark wirksam, andere kombinationen', 'D07XD');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, sehr stark wirksam, kombinationen mit antibiotika', 'D07CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, sehr stark wirksam, kombinationen mit antiseptika', 'D07BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, stark wirksam (gruppe iii)', 'D07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, stark wirksam, andere kombinationen', 'D07XC');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, stark wirksam, kombinationen mit antibiotika', 'D07CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide, stark wirksam, kombinationen mit antiseptika', 'D07BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticosteroide/antiinfektiva/mydriatika in kombination', 'S01CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('corticotropin', 'H01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cortison', 'H02AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cortison', 'S01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cortivazol', 'H02AB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('coxibe', 'M01AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('crataegus-glykoside', 'C01EB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('creatinolfosfat', 'C01EB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('crilanomer', 'D03AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicinsäure', 'R03BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicinsäure', 'A07EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicinsäure', 'D11AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicinsäure', 'R01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicinsäure', 'S01GX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicinsäure, kombinationen', 'S01GX51');
INSERT INTO staging.atc (description, atc_code) VALUES ('cromoglicinsäure, kombinationen', 'R01AC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('crospovidon', 'A07BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('curare-alkaloide', 'M03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyamemazin', 'N05AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyanocobalamin', 'B03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyanocobalamin, kombinationen', 'B03BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyanocobalamin-tannin-komplex', 'B03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclandelat', 'C04AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclische amine', 'J05AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclizin', 'R06AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclizin, kombinationen', 'R06AE53');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclobarbital', 'N05CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclobenzaprin', 'M03BX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclobutyrol', 'A05AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclofenil', 'G03GB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cycloguanilembonat', 'P01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclopentamin', 'R01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclopenthiazid', 'C03AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclopenthiazid und kalium', 'C03AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclopenthiazid und kalium sparende mittel', 'C03EA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclopentolat', 'S01FA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclophosphamid', 'L01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cycloserin', 'J04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclothiazid', 'C03AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyclothiazid und kalium', 'C03AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyfluthrin', 'P03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cymarin', 'C01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('cypermethrin', 'P03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyproheptadin', 'R06AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyproteron', 'G03HA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cyproteron und estrogen', 'G03HB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytarabin', 'L01BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('cytomegalievirus-immunglobulin', 'J06BB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dabigatran', 'B01AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('dacarbazin', 'L01AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('daclizumab', 'L04AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dactinomycin', 'L01DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dalbavancin', 'J01XA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dalteparin', 'B01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('danaparoid', 'B01AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('danazol', 'G03XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dantrolen', 'M03CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dantrolen und derivate', 'M03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('dantron', 'A06AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dantron, inkl. kombinationen', 'A06AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dantron, kombinationen', 'A06AB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('dapiprazol', 'S01EX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dapson', 'J04BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('daptomycin', 'J01XX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('darbepoetin alfa', 'B03XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('darifenacin', 'G04BD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('darunavir', 'J05AE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('dasatinib', 'L01XE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('daunorubicin', 'L01DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('deanol', 'N06BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('debrisoquin', 'C02CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('decamethrin', 'P03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('deferasirox', 'V03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('deferipron', 'V03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('deferoxamin', 'V03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('defibrotid', 'B01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('deflazacort', 'H02AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('dehydroemetin', 'P01AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dekongestiva und andere rhinologika zur topischen anwendung', 'R01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('dekongestiva und antiallergika', 'S01G');
INSERT INTO staging.atc (description, atc_code) VALUES ('delapril', 'C09AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('delapril und diuretika', 'C09BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('delapril und manidipin', 'C09BB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('delavirdin', 'J05AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('demecarium', 'S01EB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('demeclocyclin', 'J01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('demeclocyclin', 'D06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('demecolcin', 'L01CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('demegeston', 'G03DB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('demoxytocin', 'H01BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('denileukin diftitox', 'L01XX29');
INSERT INTO staging.atc (description, atc_code) VALUES ('denosumab', 'M05BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('deptropin', 'R06AX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('dequalinium', 'R02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dequalinium', 'G01AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dequalinium', 'D08AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dermatika', 'D');
INSERT INTO staging.atc (description, atc_code) VALUES ('desaspidin', 'P02DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('deserpidin', 'C02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('deserpidin und diuretika', 'C02LA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('desfluran', 'N01AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('desipramin', 'N06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('desirudin', 'B01AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('deslanosid', 'C01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('desloratadin', 'R06AX27');
INSERT INTO staging.atc (description, atc_code) VALUES ('desmopressin', 'H01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('desogestrel', 'G03AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('desogestrel und estrogen', 'G03FB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('desogestrel und estrogen', 'G03AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('desogestrel und estrogen', 'G03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('desonid', 'D07AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('desonid', 'S01BA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('desonid und antiseptika', 'D07BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('desoximetason', 'D07XC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('desoximetason', 'D07AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('desoxycorton', 'H02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('desoxyribonuclease', 'B06AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('desvenlafaxin', 'N06AX23');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason', 'D07XB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason', 'H02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason', 'R01AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason', 'S03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason', 'S02BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason', 'S01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason', 'S01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason', 'A01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason', 'D10AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason', 'C05AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason', 'D07AB19');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason und antibiotika', 'D07CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason und antiinfektiva', 'S01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason und antiinfektiva', 'S03CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason und antiinfektiva', 'S02CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamethason, kombinationen', 'R01AD53');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexamfetamin', 'N06BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexbrompheniramin', 'R06AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexbrompheniramin, kombinationen', 'R06AB56');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexchlorpheniramin', 'R06AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexchlorpheniramin, kombinationen', 'R06AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexetimid', 'N04AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexfenfluramin', 'A08AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexibuprofen', 'M01AE14');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexketoprofen', 'M01AE17');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexpanthenol', 'A11HA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexpanthenol', 'D03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexpanthenol', 'S01XA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('dexrazoxan', 'V03AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextran', 'B05AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextranomer', 'D03AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextriferron', 'B03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextriferron', 'B03AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextriferron', 'B03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextromethorphan', 'R05DA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextromoramid', 'N02AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextropropoxyphen', 'N02AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextropropoxyphen, kombinationen exkl. psycholeptika', 'N02AC54');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextropropoxyphen, kombinationen mit psycholeptika', 'N02AC74');
INSERT INTO staging.atc (description, atc_code) VALUES ('dextrothyroxin', 'C10AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dezocin', 'N02AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('diabetes-tests', 'V04CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('diacerein', 'M01AX21');
INSERT INTO staging.atc (description, atc_code) VALUES ('diagnostika', 'V04');
INSERT INTO staging.atc (description, atc_code) VALUES ('diagnostika', 'S01J');
INSERT INTO staging.atc (description, atc_code) VALUES ('diaminopyrimidine', 'P01BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('diamorphin', 'N02AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('diastase', 'A09AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diazepam', 'N05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diazepine, oxazepine und thiazepine', 'N05AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('diazoxid', 'V03AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diazoxid', 'C02DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibekacin', 'J01GB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibenzepin', 'N06AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibenzo-bicyclo-octadien-derivate', 'N05BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibotermin alfa', 'M05BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibrompropamidin', 'D08AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibrompropamidin', 'S01AX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibromtyrosin', 'H03BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibunat', 'R05DB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibutylphthalat', 'P03BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dibutylsuccinat', 'P03BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dichloracetamid-derivate', 'P01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('dichloralphenazon', 'N05CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dichlorbenzylalkohol', 'R02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dichlorophen', 'P02DX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dickflüssiges paraffin', 'A06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dickflüssiges paraffin, kombinationen', 'A06AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac', 'M02AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac', 'M01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac', 'S01BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac und antiinfektiva', 'S01CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenac, kombinationen', 'M01AB55');
INSERT INTO staging.atc (description, atc_code) VALUES ('diclofenamid', 'S01EC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dicloxacillin', 'J01CF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dicoumarol', 'B01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dicycloverin', 'A03AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('didanosin', 'J05AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('didecyldimethylammoniumchlorid', 'D08AJ06');
INSERT INTO staging.atc (description, atc_code) VALUES ('dienestrol', 'G03CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dienestrol', 'G03CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dienogest und estrogen', 'G03FA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethylcarbamazin', 'P02CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethylether', 'N01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethylstilbestrol', 'G03CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethylstilbestrol', 'L02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethylstilbestrol', 'G03CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diethyltoluamid', 'P03BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('difemerin', 'A03AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('difenoxin', 'A07DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('difenpiramid', 'M01AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('difetarson', 'P01AR02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diflorason', 'D07AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('diflucortolon', 'D07AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('diflucortolon', 'D07XC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('diflucortolon und antiseptika', 'D07BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('diflunisal', 'N02BA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('difluprednat', 'D07AC19');
INSERT INTO staging.atc (description, atc_code) VALUES ('digestiva, inkl. enzyme', 'A09');
INSERT INTO staging.atc (description, atc_code) VALUES ('digestiva, inkl. enzyme', 'A09A');
INSERT INTO staging.atc (description, atc_code) VALUES ('digitalis-antitoxin', 'V03AB24');
INSERT INTO staging.atc (description, atc_code) VALUES ('digitalisblätter', 'C01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('digitalisglykoside', 'C01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('digitoxin', 'C01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('digoxin', 'C01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihexyverin', 'A03AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydralazin', 'C02DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydralazin und diuretika', 'C02LG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydralazin und diuretika, kombinationen mit anderen mitteln', 'C02LG51');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydrocodein', 'N02AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydrocodein, kombinationen', 'N02AA58');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroergocristin', 'C04AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroergocristin, kombinationen', 'C04AE54');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroergocryptinmesilat', 'N04BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroergotamin', 'N02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroergotamin, kombinationen', 'N02CA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydropyridin-derivate', 'C08CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydrostreptomycin', 'S01AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydrotachysterol', 'A11CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dihydroxyaluminiumnatriumcarbonat (carbaldrat)', 'A02AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('diiodhydroxychinolin', 'G01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diiodhydroxypropan', 'D08AG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('diiodtyrosin', 'H03BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diisopromin', 'A03AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dikaliumclorazepat', 'N05BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dilazep', 'C01DX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('diloxanid', 'P01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diltiazem', 'C08DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimazol', 'D01AE17');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimeflin', 'R07AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimemorfan', 'R05DA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimercaprol', 'V03AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimetacrin', 'N06AA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethylaminopropionylphenothiazin', 'A03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethylcarbat', 'P03BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethylphthalat', 'P03BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethylsulfoxid', 'G04BX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethylsulfoxid', 'M02AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimethyltubocurarin', 'M03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimetinden', 'D04AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimetinden', 'R06AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimetofrin', 'C01CA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('dimetotiazin', 'N02CX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('dinatrium-1-glycerinphosphat', 'B05XA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('dinogest und estrogen', 'G03AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dinoprost', 'G02AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dinoproston', 'G02AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diodon', 'V08AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('diosmectit', 'A07BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('diosmin', 'C05CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('diosmin, kombinationen', 'C05CA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipeptidylpeptidase-4-(dpp-4)-inhibitoren', 'A10BH');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphemanil', 'A03AB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphemanil und psycholeptika', 'A03CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenadion', 'B01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenhydramin', 'D04AA32');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenhydramin', 'R06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenhydramin, kombinationen', 'R06AA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenhydraminmethylbromid', 'D04AA33');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenoxylat', 'A07DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenylbutylpiperidin-derivate', 'N05AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenylmethan-derivate', 'N05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenylpropylamin-derivate', 'N02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenylpyralin', 'R06AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphenylpyralin, kombinationen', 'R06AA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtherie-antitoxin', 'J06AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtherie-haemophilus-influenzae b-pertussis-poliomyelitis-tetanus', 'J07CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtherie-haemophilus-influenzae b-pertussis-poliomyelitis-tetanus-hepatitis b', 'J07CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtherie-hepatitis b-pertussis-tetanus', 'J07CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtherie-hepatitis b-tetanus', 'J07CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtherie-immunglobulin', 'J06BB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtherie-impfstoffe', 'J07AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtherie-pertussis-poliomyelitis-tetanus', 'J07CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtherie-poliomyelitis-tetanus', 'J07CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtherie-röteln-tetanus', 'J07CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('diphtherie-toxoid', 'J07AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipiperonylaminoethanol, kombinationen', 'N05CX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipivefrin', 'S01EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('diprophyllin', 'R03DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diprophyllin und sympathomimetika', 'R03DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diprophyllin, kombinationen', 'R03DA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipyridamol', 'B01AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipyrocetyl', 'N02BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipyrocetyl und corticosteroide', 'M01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipyrocetyl, kombinationen exkl. psycholeptika', 'N02BA59');
INSERT INTO staging.atc (description, atc_code) VALUES ('dipyrocetyl, kombinationen mit psycholeptika', 'N02BA79');
INSERT INTO staging.atc (description, atc_code) VALUES ('direkt wirkende antivirale mittel', 'J05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('direkte thrombininhibitoren', 'B01AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('dirithromycin', 'J01FA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('disopyramid', 'C01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('distickstoffmonoxid', 'N01AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('distigmin', 'N07AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('disulfiram', 'P03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('disulfiram', 'N07BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('disulfiram, kombinationen', 'P03AA54');
INSERT INTO staging.atc (description, atc_code) VALUES ('ditazol', 'B01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dithranol', 'D05AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dithranol, kombinationen', 'D05AC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('diuretika', 'C03');
INSERT INTO staging.atc (description, atc_code) VALUES ('diuretika und kalium sparende mittel in kombination', 'C03E');
INSERT INTO staging.atc (description, atc_code) VALUES ('dixanthogen', 'P03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dixyrazin', 'N05AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('diätetika ohne phenylalanin', 'V06CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('diätetika zur behandlung der adipositas', 'V06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('dobutamin', 'C01CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('docetaxel', 'L01CD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('docosanol', 'D06BB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('docusat-natrium', 'A06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('docusat-natrium, inkl. kombinationen', 'A06AG10');
INSERT INTO staging.atc (description, atc_code) VALUES ('dodecloniumbromid, kombinationen', 'D08AJ59');
INSERT INTO staging.atc (description, atc_code) VALUES ('dofetilid', 'C01BD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dolasetron', 'A04AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('domiodol', 'R05CB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('domiphen', 'A01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('domperidon', 'A03FA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('donepezil', 'N06DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopa und dopa-derivate', 'N04BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopamin', 'C01CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopamin-agonisten', 'N04BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopaminerge mittel', 'N04B');
INSERT INTO staging.atc (description, atc_code) VALUES ('dopexamin', 'C01CA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('doripenem', 'J01DH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dornase alfa (desoxyribonuclease)', 'R05CB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('dorzolamid', 'S01EC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('dosulepin', 'N06AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxacuriumchlorid', 'M03AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxapram', 'R07AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxazosin', 'C02CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxefazepam', 'N05CD12');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxepin', 'N06AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxercalciferol', 'H05BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxofyllin', 'R03DA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxorubicin', 'L01DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxycyclin', 'J01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxycyclin', 'A01AB22');
INSERT INTO staging.atc (description, atc_code) VALUES ('doxylamin', 'R06AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('dronabinol', 'A04AD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('dronedarone', 'C01BD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('droperidol', 'N05AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('droperidol', 'N01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dropropizin', 'R05DB19');
INSERT INTO staging.atc (description, atc_code) VALUES ('drospirenon und estrogen', 'G03FA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('drotaverin', 'A03AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('drotrecogin alfa (aktiviert)', 'B01AD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('droxicam', 'M01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('droxypropin', 'R05DB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('duloxetin', 'N06AX21');
INSERT INTO staging.atc (description, atc_code) VALUES ('dutasterid', 'G04CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dyclonin', 'N01BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('dyclonin', 'R02AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('dydrogesteron', 'G03DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('dydrogesteron und estrogen', 'G03FB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('dydrogesteron und estrogen', 'G03FA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('ebastin', 'R06AX22');
INSERT INTO staging.atc (description, atc_code) VALUES ('econazol', 'G01AF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('econazol', 'D01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ecothiopat', 'S01EB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eculizumab', 'L04AA25');
INSERT INTO staging.atc (description, atc_code) VALUES ('edetate', 'V03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('edoxudin', 'D06BB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('edrecolomab', 'L01XC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('edrecolomab', 'L03AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('efalizumab', 'L04AA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('efaproxiral', 'L01XD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('efavirenz', 'J05AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eflornithin', 'P01CX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eflornithin', 'D11AX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('efloxat', 'C01DX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('eibischwurzel', 'R05CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('einfache salzkombinationen', 'A02AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('einfache salzkombinationen und karminativa', 'A02AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen dreiwertig, orale zubereitungen', 'B03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen dreiwertig, parenterale zubereitungen', 'B03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen in anderen kombinationen', 'B03AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen in kombination mit folsäure', 'B03AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen und multivitamine', 'B03AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen zweiwertig, orale zubereitungen', 'B03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)ascorbat', 'B03AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)aspartat', 'B03AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)carbonat', 'B03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)chlorid', 'B03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)fumarat', 'B03AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)fumarat', 'B03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)gluconat', 'B03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)glycinsulfat', 'B03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)iodat', 'B03AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)succinat', 'B03AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)sulfat', 'B03AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)sulfat', 'B03AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(ii)tartrat', 'B03AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(iii)-natrium-citrat', 'B03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(iii)-natrium-gluconat-komplex', 'B03AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(iii)acetyltransferrin', 'B03AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(iii)citrat', 'B03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(iii)hexacyanoferrat(ii)', 'V03AB31');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(iii)hydroxid', 'B03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(iii)oxid-dextran-komplex', 'B03AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(iii)oxid-saccharose-komplex', 'B03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(iii)oxid-saccharose-komplex', 'B03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(iii)proteinsuccinylat', 'B03AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(iii)sorbit-gluconsäure-komplex', 'B03AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen(iii)sorbit-zitronensäure-komplex', 'B03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen, multivitamine und folsäure', 'B03AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen, multivitamine und mineralstoffe', 'B03AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen, vitamin b12 und folsäure', 'B03AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen-aminosäure-komplex', 'B03AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen-chelatbildner', 'V03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisen-haltige zubereitungen', 'B03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('eisenoxid, nanopartikel', 'V08CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('elcatonin', 'H05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('elektrolyte', 'B05BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('elektrolyte in kombination mit anderen mitteln', 'B05XA31');
INSERT INTO staging.atc (description, atc_code) VALUES ('elektrolyte mit kohlenhydraten', 'A07C');
INSERT INTO staging.atc (description, atc_code) VALUES ('elektrolyte mit kohlenhydraten', 'B05BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('elektrolyte zur oralen rehydrierung', 'A07CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('elektrolytlösungen', 'B05XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('eletriptan', 'N02CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('eltrombopag', 'B02BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('emedastin', 'S01GX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('emepronium', 'G04BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('emepronium und psycholeptika', 'A03CA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('emepronium, kombinationen', 'N05CX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('emergency verhütungsmittel nehmen', 'G03AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('emetin', 'P01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('emetin, kombinationen', 'P01AX52');
INSERT INTO staging.atc (description, atc_code) VALUES ('emollientia und hautschutzmittel', 'D02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('emollientia und hautschutzmittel', 'D02');
INSERT INTO staging.atc (description, atc_code) VALUES ('emser salz', 'R02AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('emtricitabin', 'J05AF09');
INSERT INTO staging.atc (description, atc_code) VALUES ('emylcamat', 'N05BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('enalapril', 'C09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('enalapril und diuretika', 'C09BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('enalapril und lercanidipin', 'C09BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('encainid', 'C01BC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('encephalitis, japanische, inaktiviert, ganzes virus', 'J07BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('encephalitis-impfstoffe', 'J07BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('endokrine therapie', 'L02');
INSERT INTO staging.atc (description, atc_code) VALUES ('endralazin', 'C02DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('enfluran', 'N01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('enfuvirtid', 'J05AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('enoxacin', 'J01MA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('enoxaparin', 'B01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('enoximon', 'C01CE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('enoxolon', 'D03AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('enprostil', 'A02BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('entacapon', 'N04BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('entecavir', 'J05AF10');
INSERT INTO staging.atc (description, atc_code) VALUES ('entgiftungsmittel für die behandlung mit zytostatika', 'V03AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('entzündungs- und infektionserkennung', 'V09H');
INSERT INTO staging.atc (description, atc_code) VALUES ('entzündungshemmende mittel', 'V10A');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzym- und säure-haltige zubereitungen, kombinationen', 'A09AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzym-haltige zubereitungen', 'A09AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzym-inhibitoren', 'L02BG');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzyme', 'B06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzyme', 'D03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzyme', 'B01AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzyme', 'C04AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzyme', 'A16AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('enzyme', 'M09AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('eosin', 'D08AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('epanolol', 'C07AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('eperison', 'M03BX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('ephedrin', 'R03CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ephedrin', 'S01FB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ephedrin', 'R01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ephedrin', 'R01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ephedrin, kombinationen', 'A08AA56');
INSERT INTO staging.atc (description, atc_code) VALUES ('epicillin', 'J01CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('epimestrol', 'G03GB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinastin', 'S01GX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinastin', 'R06AX24');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrin', 'R03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrin', 'A01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrin', 'B02BC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrin', 'R01AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrin', 'C01CA24');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrin', 'S01EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrin und andere mittel bei obstruktiven atemwegserkrankungen', 'R03AK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('epinephrin, kombinationen', 'S01EA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('epirubicin', 'L01DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('epitizid und kalium sparende mittel', 'C03EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('eplerenon', 'C03DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('epomediol', 'A05BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('epoprostenol', 'B01AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('epoxide', 'L01AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('eprazinon', 'R05CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('eprosartan', 'C09CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eprosartan und diuretika', 'C09DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eprozinol', 'R03DX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('eptacog alfa (aktiviert)', 'B02BD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('eptifibatid', 'B01AC16');
INSERT INTO staging.atc (description, atc_code) VALUES ('eptotermin alfa', 'M05BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('erdostein', 'R05CB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergocalciferol', 'A11CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergoloidmesylat', 'C04AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergoloidmesylat, kombinationen', 'C04AE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergometrin', 'G02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergotamin', 'N02CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergotamin, kombinationen exkl. psycholeptika', 'N02CA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('ergotamin, kombinationen mit psycholeptika', 'N02CA72');
INSERT INTO staging.atc (description, atc_code) VALUES ('erlotinib', 'L01XE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ertapenem', 'J01DH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythrityltetranitrat', 'C01DA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythrityltetranitrat, kombinationen', 'C01DA63');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythromycin', 'J01FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythromycin', 'D10AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythromycin', 'S01AA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythromycin, kombinationen', 'D10AF52');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythropoietin', 'B03XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('erythrozyten', 'B05AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('escitalopram', 'N06AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('esketamin', 'N01AX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('esmolol', 'C07AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('esomeprazol', 'A02BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('esomeprazol, amoxicillin und clarithromycin', 'A02BD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('essigsäure', 'G01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('essigsäure', 'S02AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('essigsäure-derivate und verwandte substanzen', 'M01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('estazolam', 'N05CD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ester der aminobenzoesäure', 'N01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('ester der benzoesäure', 'N01BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('estradiol', 'G03CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('estradiol, kombinationen', 'G03CA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('estramustin', 'L01XX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('estren-derivate', 'A14AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('estren-derivate', 'G03DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('estriol', 'G03CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('estriol', 'G03CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('estrogene', 'L02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('estrogene', 'G03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('estrogene, kombinationen mit anderen mitteln', 'G03CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('estron', 'G03CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('estron', 'G03CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('etacrynsäure', 'C03CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etafenon', 'C01DX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('etallobarbital', 'N05CA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('etamiphyllin', 'R03DA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etamiphyllin und sympathomimetika', 'R03DB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etamivan', 'R07AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('etamsylat', 'B02BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etanautin', 'N04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etanercept', 'L04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethacridinlactat', 'D08AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethacridinlactat', 'B05CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethadion', 'N03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethambutol', 'J04AK02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethambutol und isoniazid', 'J04AM03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethanol', 'V03AB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethanol', 'D08AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethanol', 'V03AZ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethchlorvynol', 'N05CM08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethenzamid', 'N02BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethenzamid, kombinationen exkl. psycholeptika', 'N02BA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethenzamid, kombinationen mit psycholeptika', 'N02BA77');
INSERT INTO staging.atc (description, atc_code) VALUES ('ether', 'N01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('ether, chemisch den antihistaminika verwandt', 'N04AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('ether, chemisch den antihistaminika verwandt', 'M03BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethinylestradiol', 'L02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethinylestradiol', 'G03CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethionamid', 'J04AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethisteron', 'G03DC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethisteron und estrogen', 'G03FA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethosuximid', 'N03AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethosuximid, kombinationen', 'N03AD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethotoin', 'N03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethulose', 'A06AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylbiscoumacetat', 'B01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylchlorid', 'N01BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylenimine', 'L01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylester iodierter fettsäuren', 'V08AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylestrenol', 'A14AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylhydroxybenzoat', 'D01AE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylloflazepat', 'N05BA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylmorphin', 'R05DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ethylmorphin', 'S01XA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etidocain', 'N01BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('etidocain, kombinationen', 'N01BB57');
INSERT INTO staging.atc (description, atc_code) VALUES ('etidronsäure', 'M05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etidronsäure und calcium, sequenzialpräparate', 'M05BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etifoxin', 'N05BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('etilamfetamin', 'A08AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etilefrin', 'C01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etilefrin, kombinationen', 'C01CA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('etilevodopa und decarboxylasehemmer', 'N04BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etizolam', 'N05BA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('etodolac', 'M01AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('etofamid', 'P01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('etofenamat', 'M02AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etofibrat', 'C10AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('etofyllinnicotinat', 'C04AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('etoglucid', 'L01AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etohexadiol', 'P03BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etomidate', 'N01AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('etonogestrel', 'G03AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('etoperidon', 'N06AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('etoposid', 'L01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etoricoxib', 'M01AH05');
INSERT INTO staging.atc (description, atc_code) VALUES ('etozolin', 'C03CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etretinat', 'D05BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etybenzatropin', 'N04AC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('etynodiol', 'G03DC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('etynodiol und estrogen', 'G03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('etynodiol und estrogen', 'G03FA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('euflavin', 'D08AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('everlolimus', 'L01XE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('everolimus', 'L04AA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('exanitid', 'A10BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('exemestan', 'L02BG06');
INSERT INTO staging.atc (description, atc_code) VALUES ('expektoranzien', 'R05CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('expektoranzien, exkl. kombinationen mit antitussiva', 'R05C');
INSERT INTO staging.atc (description, atc_code) VALUES ('ezetimib', 'C10AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('faktor-viii-inhibitor-bypass-aktivität', 'B02BD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('famciclovir', 'S01AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('famciclovir', 'J05AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('famotidin', 'A02BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('famotidin, kombinationen', 'A02BA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('farbstoffe', 'S01JA');
INSERT INTO staging.atc (description, atc_code) VALUES ('fasudil', 'C04AX32');
INSERT INTO staging.atc (description, atc_code) VALUES ('fazadiniumbromid', 'M03AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('febarbamat', 'M03BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('febuxostat', 'M04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('federn', 'V01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fedrilat', 'R05DB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('felbamat', 'N03AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('felbinac', 'M02AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('felodipin', 'C08CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenamate', 'M01AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenbendazol', 'P02CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenbufen', 'M01AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fencamfamin', 'N06BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fendilin', 'C08EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenfluramin', 'A08AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenofibrat', 'C10AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoldopam', 'C01CA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoprofen', 'M01AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoterol', 'G02CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoterol', 'R03AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoterol', 'R03CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoterol und andere mittel bei obstruktiven atemwegserkrankungen', 'R03AK03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoverin', 'A03AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenoxazolin', 'R01AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenozolon', 'N06BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenpipran', 'A03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenpiverinium', 'A03AB21');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenquizon', 'C03BA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenspirid', 'R03DX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenspirid', 'R03BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentanyl', 'N02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentanyl', 'N01AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentanyl, kombinationen', 'N01AH51');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentiazac', 'M02AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentiazac', 'M01AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenticonazol', 'D01AC12');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenticonazol', 'G01AF12');
INSERT INTO staging.atc (description, atc_code) VALUES ('fentonium', 'A03BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fenyramidol', 'M03BX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('feprazon', 'M02AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('feprazon', 'M01AX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('feprazon, kombinationen', 'M01AX68');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferristen', 'V08CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fertilitäts-tests', 'V04CM');
INSERT INTO staging.atc (description, atc_code) VALUES ('ferumoxsil', 'V08CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fesoterodin', 'G04BD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('fett-emulsionen', 'B05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fettabsorptions-tests', 'V04CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('fette/kohlenhydrate/proteine/mineralstoffe/vitamine, kombinationen', 'V06DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('fettsäure-derivate', 'N03AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('fexofenadin', 'R06AX26');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrate', 'C10AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrinogen, human', 'B02BC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrinogen, human', 'B02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrinogene', 'B02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrinolysin', 'B01AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fibrinolysin und desoxyribonuclease', 'B06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('filgrastim', 'L03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('finasterid', 'G04CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('finasterid', 'D11AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('fipexid', 'N06BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('flavoxat', 'G04BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('flecainid', 'C01BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fleroxacin', 'J01MA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('floctafenin', 'N02BG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('flosequinan', 'C01DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluanison', 'N05AD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('flubendazol', 'P02CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluclorolon', 'D07AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('flucloxacillin', 'J01CF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluconazol', 'D01AC15');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluconazol', 'J02AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flucytosin', 'D01AE21');
INSERT INTO staging.atc (description, atc_code) VALUES ('flucytosin', 'J02AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludarabin', 'L01BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludiazepam', 'N05BA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludrocortison', 'H02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludrocortison und antiinfektiva', 'S03CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludrocortison und antiinfektiva', 'S02CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludrocortison und antiinfektiva', 'S01CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludroxycortid', 'D07AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fludroxycortid und antibiotika', 'D07CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flufenaminsäure', 'M01AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumazenil', 'V03AB25');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumedroxon', 'N02CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumequin', 'J01MB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumetason', 'D07XB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumetason', 'D07AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumetason und antibiotika', 'D07CB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumetason und antiinfektiva', 'S02CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('flumetason und antiseptika', 'D07BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunarizin', 'N07CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunisolid', 'R03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunisolid', 'R01AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunitrazepam', 'N05CD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunoxaprofen', 'G02CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('flunoxaprofen', 'M01AE15');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolon acetonid', 'S02BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolonacetonid', 'D07AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolonacetonid', 'C05AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolonacetonid und antibiotika', 'D07CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolonacetonid und antiinfektiva', 'S01CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolonacetonid und antiinfektiva', 'S02CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinolonacetonid und antiseptika', 'D07BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinonid', 'D07AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinonid', 'C05AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocinonid und antibiotika', 'D07CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortin', 'D07AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortolon', 'C05AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortolon', 'D07AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortolon', 'H02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortolon und antibiotika', 'D07CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortolon und antiinfektiva', 'S01CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluocortolon und antiseptika', 'D07BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorchinolone', 'J01MA');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorescein', 'S01JA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorescein, kombinationen', 'S01JA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorid', 'A12CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluormethylcholin (18f)', 'V09IX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorocarbon-blutersatzmittel', 'B05AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholon', 'D07AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholon', 'D10AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholon', 'C05AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholon', 'S01BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholon', 'S01CB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholon', 'D07XB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholon und antibiotika', 'D07CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholon und antiinfektiva', 'S01CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorometholon und mydriatika', 'S01BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorouracil', 'L01BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluorouracil, kombinationen', 'L01BC52');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluostigmin', 'S01EB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluoxetin', 'N06AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluoxymesteron', 'G03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flupentixol', 'N05AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluperolon', 'D07AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluphenazin', 'N05AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('flupirtin', 'N02BG07');
INSERT INTO staging.atc (description, atc_code) VALUES ('flupredniden', 'D07XB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('flupredniden', 'D07AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('flupredniden und antibiotika', 'D07CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('flurazepam', 'N05CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flurbiprofen', 'M02AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('flurbiprofen', 'S01BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('flurbiprofen', 'M01AE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('flurithromycin', 'J01FA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluspirilen', 'N05AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('flutamid', 'L02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluticason', 'D07AC17');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluticason', 'R01AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluticason', 'R03BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('flutrimazol', 'G01AF18');
INSERT INTO staging.atc (description, atc_code) VALUES ('flutrimazol', 'D01AC16');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluvastatin', 'C10AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fluvoxamin', 'N06AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('flüssige pflaster', 'D02AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('follitropin alfa', 'G03GA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('follitropin beta', 'G03GA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('folsäure', 'B03BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('folsäure und derivate', 'B03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('folsäure, kombinationen', 'B03BB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('folsäure-analoga', 'L01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('fomepizol', 'V03AB34');
INSERT INTO staging.atc (description, atc_code) VALUES ('fomivirsen', 'S01AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('fondaparinux', 'B01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('formestan', 'L02BG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('formocortal', 'S01BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('formoterol', 'R03AC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('formoterol und andere mittel bei obstruktiven atemwegserkrankungen', 'R03AK07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosamprenavir', 'J05AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('foscarnet', 'J05AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosfestrol', 'L02AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosfocreatin', 'C01EB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosfomycin', 'J01XX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosfonet', 'J05AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosinopril', 'C09AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosinopril und diuretika', 'C09BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('fosphenytoin', 'N03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('fotemustin', 'L01AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('framycetin', 'R01AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('framycetin', 'S01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('framycetin', 'D09AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('freediams-interaktionsklassen', 'ZXX');
INSERT INTO staging.atc (description, atc_code) VALUES ('freediams-spezifische codes', 'Z');
INSERT INTO staging.atc (description, atc_code) VALUES ('freediams: interagierende stoffe', 'Z00');
INSERT INTO staging.atc (description, atc_code) VALUES ('frovatriptan', 'N02CC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fructose', 'V06DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fructose-1,6-diphosphat', 'C01EB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('fsme, inaktiviert, ganzes virus', 'J07BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fsme-immunglobulin', 'J06BB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('fulvestrant', 'L02BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fumarsäure', 'D05AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fumarsäure-derivate, kombinationen', 'D05BX51');
INSERT INTO staging.atc (description, atc_code) VALUES ('furazolidon', 'G01AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('furosemid', 'C03CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('furosemid und kalium', 'C03CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('furosemid und kalium sparende mittel', 'C03EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fusafungin', 'R02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('fusidinsäure', 'D06AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('fusidinsäure', 'S01AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('fusidinsäure', 'D09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('fusidinsäure', 'J01XC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('g-strophanthin', 'C01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gabapentin', 'N03AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadobensäure', 'V08CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadobutrol', 'V08CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadodiamid', 'V08CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadopentetsäure', 'V08CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadoteridol', 'V08CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadotersäure', 'V08CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gadoversetamid', 'V08CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('galactose', 'V04CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('galactose-mikropartikel', 'V08DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('galantamin', 'N06DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('gallamin', 'M03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gallen- und lebertherapie', 'A05');
INSERT INTO staging.atc (description, atc_code) VALUES ('gallenfluss-tests', 'V04CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('gallensäure bindende mittel', 'C10AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('gallensäure-haltige zubereitungen', 'A05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('gallentherapie', 'A05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('gallopamil', 'C08DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gamolensäure', 'D11AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gamolensäure, kombinationen', 'D11AX52');
INSERT INTO staging.atc (description, atc_code) VALUES ('ganciclovir', 'J05AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ganciclovir', 'S01AD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('ganglioside und gangliosid-derivate', 'N07XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('ganirelix', 'H01CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gasbrand-serum', 'J06AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('gatifloxacin', 'J01MA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('gedocarnil', 'N05BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gefarnat', 'A02BX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('gefarnat, kombinationen mit psycholeptika', 'A02BX77');
INSERT INTO staging.atc (description, atc_code) VALUES ('gefitinib', 'L01XE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gelatine-haltige mittel', 'B05AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('gelbfieber, lebend abgeschwächt', 'J07BL01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gelbfieber-impfstoffe', 'J07BL');
INSERT INTO staging.atc (description, atc_code) VALUES ('gemcitabin', 'L01BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('gemeprost', 'G02AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('gemfibrozil', 'C10AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('gemifloxacin', 'J01MA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('gemtuzumab', 'L01XC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin', 'S03AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin', 'S01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin', 'S02AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin', 'D06AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('gentamicin', 'J01GB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('gepefrin', 'C01CA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('gepiron', 'N06AX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('gerinnungsfaktor ix', 'B02BD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('gerinnungsfaktor vii', 'B02BD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('gerinnungsfaktor viii', 'B02BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gerinnungsfaktor xiii', 'B02BD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('gerinnungsfaktoren ix, ii, vii und x in kombination', 'B02BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestagene', 'L02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestagene', 'G03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestagene', 'G03D');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestagene und estrogene in kombination', 'G03F');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestagene und estrogene, fixe kombinationen', 'G03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestagene und estrogene, fixe kombinationen', 'G03FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestagene und estrogene, sequenzialpräparate', 'G03FB');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestagene und estrogene, sequenzialpräparate', 'G03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestoden und estrogen', 'G03AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestoden und estrogen', 'G03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestonoron', 'G03DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestonoron', 'L02AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('gestrinon', 'G03XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('gewebekleber', 'V03AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('gichtmittel', 'M04');
INSERT INTO staging.atc (description, atc_code) VALUES ('gichtmittel', 'M04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('gichtmittel ohne effekt auf den harnsäuremetabolismus', 'M04AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('ginkgo biloba', 'N06DX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ginkgo biloba', 'N06BX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('gitoformat', 'C01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('glafenin', 'N02BG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('glatirameracetat', 'L03AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('glaukommittel und miotika', 'S01E');
INSERT INTO staging.atc (description, atc_code) VALUES ('gleitmittel, emollientia', 'A06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('glibenclamid', 'A10BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glibornurid', 'A10BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('gliclazid', 'A10BB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('glimepirid', 'A10BB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('glipizid', 'A10BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('gliquidon', 'A10BB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('glisoxepid', 'A10BB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucagon', 'H04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucocorticoide', 'R03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucocorticoide', 'H02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucosamin', 'M01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucose', 'B05CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucose', 'V06DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucose', 'V04CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('glucose, kombinationen', 'C05BB56');
INSERT INTO staging.atc (description, atc_code) VALUES ('glukosaminoglycanpolysulfat', 'M01AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('glutamin', 'A16AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('glutaminsäurehydrochlorid', 'A09AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glutathion', 'V03AB32');
INSERT INTO staging.atc (description, atc_code) VALUES ('glutethimid', 'N05CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycerol', 'A06AG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycerol', 'A06AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycerol-trinitrat', 'C05AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('glyceroltrinitrat', 'C01DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('glyceroltrinitrat, kombinationen', 'C01DA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycin', 'B05CX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycobiarsol', 'P01AR03');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycobiarsol, kombinationen', 'P01AR53');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycopeptid-antibiotika', 'J01XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycopyrronium', 'A03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('glycopyrronium und psycholeptika', 'A03CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('glykogenolytische hormone', 'H04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('glykogenolytische hormone', 'H04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('glymidin', 'A10BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gold-verbindungen', 'M01CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('golimumab', 'L04AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadorelin', 'V04CM01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadorelin', 'H01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadotropin-releasing-hormon-analoga', 'L02AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadotropin-releasing-hormon-antagonisten', 'H01CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadotropin-releasing-hormone', 'H01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadotropine', 'G03GA');
INSERT INTO staging.atc (description, atc_code) VALUES ('gonadotropine und andere ovulationsauslöser', 'G03G');
INSERT INTO staging.atc (description, atc_code) VALUES ('goserelin', 'L02AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('gramicidin', 'R02AB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('granisetron', 'A04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('grepafloxacin', 'J01MA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('griseofulvin', 'D01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('griseofulvin', 'D01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('gräserpollen', 'V01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('guacetisal', 'N02BA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('guaifenesin', 'R05CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('guajacolsulfonat', 'R05CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('guajazulen', 'S01XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanazodin', 'C02CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanethidin', 'C02CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanethidin', 'S01EX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanethidin und diuretika', 'C02LF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanfacin', 'C02AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanidin-derivate', 'C02DG');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanidin-derivate', 'C02CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanidin-derivate und diuretika', 'C02LF');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanoclor', 'C02CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanoxabenz', 'C02CC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('guanoxan', 'C02CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('guar-mehl', 'A10BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('gusperimus', 'L04AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('gynäkologische antiinfektiva und antiseptika', 'G01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hachimycin', 'D01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hachimycin', 'J02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hachimycin', 'G01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('haemophilus influenzae b und hepatitis b', 'J07CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('haemophilus influenzae b und poliomyelitis', 'J07CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('haemophilus influenzae b, gereinigtes antigen konjugiert', 'J07AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('haemophilus influenzae b, kombinationen mit pertussis und toxoiden', 'J07AG52');
INSERT INTO staging.atc (description, atc_code) VALUES ('haemophilus influenzae b, kombinationen mit toxoiden', 'J07AG51');
INSERT INTO staging.atc (description, atc_code) VALUES ('haemophilus-influenza-b-impfstoffe', 'J07AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('halazepam', 'N05BA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('halcinonid', 'D07AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('halofantrin', 'P01BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('halogenierte kohlenwasserstoffe', 'N01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('halometason', 'D07AC12');
INSERT INTO staging.atc (description, atc_code) VALUES ('haloperidol', 'N05AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('haloprogin', 'D01AE11');
INSERT INTO staging.atc (description, atc_code) VALUES ('halothan', 'N01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hals- und rachentherapeutika', 'R02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hals- und rachentherapeutika', 'R02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('harn ansäuernde mittel', 'G04BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('harnkonkrement lösende mittel', 'G04BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('harnstoff', 'B05BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('harnstoff', 'D02AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('harnstoff, kombinationen', 'D02AE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('harnstoff-haltige mittel', 'D02AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('hausstaub', 'V01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('helium', 'V03AN03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hematin', 'B06AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparin', 'S01XA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparin', 'B01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparin', 'C05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparin, kombinationen', 'C05BA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparin, kombinationen', 'B01AB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparine oder heparinoide zur topischen anwendung', 'C05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparingruppe', 'B01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparinoid, kombinationen', 'C05BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('heparinoide', 'C05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis a, inaktiviert, ganzes virus', 'J07BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis b, gereinigtes antigen', 'J07BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis-a-immunglobulin', 'J06BB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis-b-immunglobulin', 'J06BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hepatitis-impfstoffe', 'J07BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('heptabarbital', 'N05CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('heptaminol', 'C01DX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('herzglykoside', 'C01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('herztherapie', 'C01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hetacillin', 'J01CA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexachlorophen', 'D08AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexafluronium', 'M03AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexamidin', 'R02AA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexamidin', 'R01AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexamidin', 'S03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexamidin', 'D08AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexamidin', 'S01AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexapropymate', 'N05CM10');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexetidin', 'A01AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexobarbital', 'N05CA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexobarbital', 'N01AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexobendin', 'C01DX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexocyclium', 'A03AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexoprenalin', 'R03AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexoprenalin', 'R03CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hexylresorcinol', 'R02AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('hidrosmin', 'C05CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('high-ceiling-diuretika', 'C03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('high-ceiling-diuretika und kalium sparende diuretika', 'C03EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('histamin-h2-rezeptorantagonisten', 'A02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('histaminphosphat', 'V04CG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('histapyrrodin', 'R06AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('histapyrrodin, kombinationen', 'R06AC52');
INSERT INTO staging.atc (description, atc_code) VALUES ('histrelin', 'H01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hmg-coa-reductase-inhibitoren, andere kombinationen', 'C10BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('hmg-coa-reduktasehemmer', 'C10AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('homatropin', 'S01FA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hormonantagonisten und verwandte mittel', 'L02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('hormone und verwandte mittel', 'L02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('hormonelle kontrazeptiva zur systemischen anwendung', 'G03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('humanalbumin-mikrosphären', 'V08DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('humanes menopausales gonadotrophin', 'G03GA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('husten- und erkältungspräparate', 'R05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyaluronidase', 'B06AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyaluronsäure', 'S01KA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyaluronsäure', 'M09AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyaluronsäure', 'D03AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyaluronsäure, kombinationen', 'S01KA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydantoin-derivate', 'N03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydralazin', 'C02DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydralazin und diuretika', 'C02LG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrazide', 'J04AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrazinophthalazin-derivate', 'C02DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrazinophthalazin-derivate und diuretika', 'C02LG');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochinin', 'M09AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochinon', 'D11AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochlorothiazid', 'C03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochlorothiazid und kalium', 'C03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochlorothiazid und kalium sparende mittel', 'C03EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrochlorothiazid, kombinationen', 'C03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocodon', 'R05DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison', 'S01CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison', 'A01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison', 'A07EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison', 'D07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison', 'D07XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison', 'C05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison', 'S02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison', 'H02AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison', 'S01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison und antibiotika', 'D07CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison und antiinfektiva', 'S03CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison und antiinfektiva', 'S01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison und antiinfektiva', 'S02CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison und antiseptika', 'D07BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison und mydriatika', 'S01BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortison, kombinationen', 'R01AD60');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisonaceponat', 'D07AC16');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisonbuteprat', 'D07AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisonbutyrat', 'D07AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrocortisonbutyrat und antiseptika', 'D07BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroflumethiazid', 'C03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroflumethiazid und kalium', 'C03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroflumethiazid, kombinationen', 'C03AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrogenperoxid', 'S02AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydromorphon', 'N02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydromorphon mit spasmolytika', 'N02AG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydrotalcit', 'A02AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxocobalamin', 'V03AB33');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxocobalamin', 'B03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxocobalamin, kombinationen', 'B03BA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxybuttersäure', 'N01AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxycarbamid', 'L01XX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxychinolin-derivate', 'P01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxychloroquin', 'P01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyethylpromethazin', 'R06AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyethylpromethazin, kombinationen', 'R06AD55');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyethylstärke', 'B05AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxylapatit-keramik', 'V03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxylaptit-keramik', 'V03AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyprogesteron', 'G03DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyprogesteron und estrogen', 'G03FA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyzin', 'N05BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hydroxyzin, kombinationen', 'N05BB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('hymecromon', 'A05AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyoscyamin', 'A03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('hyoscyamin und psycholeptika', 'A03CB31');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypertone lösungen', 'B05DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypnotika und sedativa', 'N05C');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypnotika und sedativa in kombination, exkl. barbiturate', 'N05CX');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypophysen- und hypothalamushormone und analoga', 'H01');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypophysenfunktions-tests', 'V04CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypophysenhinterlappenhormone', 'H01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypophysenvorderlappenhormone und analoga', 'H01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypothalamushormone', 'H01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('hypromellose', 'S01KA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('hämodialysekonzentrate', 'B05ZA');
INSERT INTO staging.atc (description, atc_code) VALUES ('hämodialysekonzentrate und hämofiltrate', 'B05Z');
INSERT INTO staging.atc (description, atc_code) VALUES ('hämofiltrate', 'B05ZB');
INSERT INTO staging.atc (description, atc_code) VALUES ('hämoglobin crosfumaril', 'B05AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('hämoglobin glutamer (rind)', 'B05AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('hämoglobin raffimer', 'B05AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('i.v.-lösungen', 'B05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibacitabin', 'D06BB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibandronsäure', 'M05BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibopamin', 'S01FB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibopamin', 'C01CA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibritumomab tiuxetan', 'L01XC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibritumomab tiuxetan (90y)', 'V10XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibudilast', 'R03DX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibudilast', 'R03DC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibuprofen', 'M02AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibuprofen', 'G02CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibuprofen', 'M01AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibuprofen', 'C01EB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibuprofen, kombinationen', 'M01AE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibuproxam', 'M01AE13');
INSERT INTO staging.atc (description, atc_code) VALUES ('ibutilid', 'C01BD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('icatibant', 'C01EB19');
INSERT INTO staging.atc (description, atc_code) VALUES ('iclaprim', 'J01EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('idanpramin', 'A03AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('idarubicin', 'L01DB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('idebenon', 'N06BX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('idoxuridin', 'J05AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('idoxuridin', 'S01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('idoxuridin', 'D06BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ifenprodil', 'C04AX28');
INSERT INTO staging.atc (description, atc_code) VALUES ('ifosfamid', 'L01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('iloprost', 'B01AC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('imatinib', 'L01XE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidapril', 'C09AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazol- und triazol-derivate', 'D01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazol-derivate', 'G01AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazol-derivate', 'A07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazol-derivate', 'J02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazol-derivate', 'J01XD');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazol-derivate und corticosteroide', 'G01BF');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazolin-derivate', 'C04AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazolin-rezeptoragonisten', 'C02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazolin-rezeptoragonisten in kombination mit diuretika', 'C02LC');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazolsalicylat', 'N02BA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('imidazothiazol-derivate', 'P02CE');
INSERT INTO staging.atc (description, atc_code) VALUES ('imiglucerase', 'A16AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('imipenem und enzym-inhibitoren', 'J01DH51');
INSERT INTO staging.atc (description, atc_code) VALUES ('imipramin', 'N06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('imipraminoxid', 'N06AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('imiquimod', 'D06BB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunglobuline', 'J06B');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunglobuline, normal human', 'J06BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunglobuline, normal human, zur extravasalen anwendung', 'J06BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunglobuline, normal human, zur intravasalen anwendung', 'J06BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunocyanin', 'L03AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunsera', 'J06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunsera', 'J06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunsera und immunglobuline', 'J06');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunstimulanzien', 'L03');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunstimulanzien', 'L03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunsuppressiva', 'L04');
INSERT INTO staging.atc (description, atc_code) VALUES ('immunsuppressiva', 'L04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('imolamin', 'C01DX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('impfstoffe', 'J07');
INSERT INTO staging.atc (description, atc_code) VALUES ('indacaterol', 'R03AC18');
INSERT INTO staging.atc (description, atc_code) VALUES ('indapamid', 'C03BA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('indifferente zubereitungen', 'S02DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('indigokarmin', 'V04CH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('indinavir', 'J05AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('indobufen', 'B01AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('indol-derivate', 'N05AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('indometacin', 'M01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('indometacin', 'M02AA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('indometacin', 'S01BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('indometacin', 'C01EB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('indometacin, kombinationen', 'M01AB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('indoprofen', 'M01AE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('indoramin', 'C02CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('infliximab', 'L04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('influenza, gereinigtes antigen', 'J07BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('influenza, inaktiviert, ganzes virus', 'J07BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('influenza-impfstoffe', 'J07BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('inhalative sympathomimetika', 'R03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('inkontinenz-artikel', 'V07AN');
INSERT INTO staging.atc (description, atc_code) VALUES ('inosin', 'S01XA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('inosin', 'D06BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('inosin', 'G01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('inosin pranobex', 'J05AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('inositol', 'A11HA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('inositolnicotinat', 'C04AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('insekten', 'V01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('insektizide und repellenzien', 'P03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (human)', 'A10AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (human)', 'A10AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (human)', 'A10AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (human)', 'A10AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (human)', 'A10AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (rind)', 'A10AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (rind)', 'A10AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (rind)', 'A10AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (rind)', 'A10AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (schwein)', 'A10AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (schwein)', 'A10AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (schwein)', 'A10AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin (schwein)', 'A10AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin aspart', 'A10AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin aspart', 'A10AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin detemir', 'A10AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin glargin', 'A10AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin glulisin', 'A10AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin lispro', 'A10AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin lispro', 'A10AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin lispro', 'A10AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('insulin und analoga zur inhalation', 'A10AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('insuline und analoga', 'A10A');
INSERT INTO staging.atc (description, atc_code) VALUES ('insuline und analoga zur injektion, intermediär wirkend', 'A10AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('insuline und analoga zur injektion, intermediär wirkend kombiniert mit schnell wirkend', 'A10AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('insuline und analoga zur injektion, lang wirkend', 'A10AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('insuline und analoga zur injektion, schnell wirkend', 'A10AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon', 'S01AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon alfa, natürlich', 'L03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon alfa-2a', 'L03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon alfa-2b', 'L03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon alfa-n1', 'L03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon alfacon-1', 'L03AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon beta, natürlich', 'L03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon beta-1a', 'L03AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon beta-1b', 'L03AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferon gamma', 'L03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('interferone', 'L03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('interleukin-inhibitoren', 'L04AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('interleukine', 'L03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('intestinale adsorbenzien', 'A07B');
INSERT INTO staging.atc (description, atc_code) VALUES ('intestinale antiinfektiva', 'A07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('intestinale antiphlogistika', 'A07E');
INSERT INTO staging.atc (description, atc_code) VALUES ('intrauterine kontrazeptiva', 'G02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('intravaginale kontrazeptiva', 'G02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('inulin und andere polyfructosane', 'V04CH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('invertzucker', 'C05BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iobenzaminsäure', 'V08AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('iobitridol', 'V08AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('iocarminsäure', 'V08AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('iocetaminsäure', 'V08AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('iod', 'D08AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iod (124i) 2beta-carbomethoxy-3beta-(4 iodophenyl)-tropan', 'V09AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iod-haltige mittel', 'D08AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodamid', 'V08AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodixanol', 'V08AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodoctylphenoxypolyglycolether', 'D08AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodoheparinat', 'S01XA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodoxaminsäure', 'V08AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodtherapie', 'H03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('iodtherapie', 'H03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('iofendylat', 'V08AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ioglicinsäure', 'V08AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ioglycaminsäure', 'V08AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('iohexol', 'V08AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('iomeprol', 'V08AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('iopamidol', 'V08AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('iopansäure', 'V08AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('iopentol', 'V08AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('iopromid', 'V08AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('iopydol', 'V08AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('iotalaminsäure', 'V08AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('iotrolan', 'V08AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('iotroxinsäure', 'V08AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ioversol', 'V08AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ioxaglinsäure', 'V08AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ioxilan', 'V08AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('ioxitalaminsäure', 'V08AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ipecacuanha', 'R05CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ipecacuanha', 'V03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ipratropiumbromid', 'R01AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ipratropiumbromid', 'R03BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iprazochrom', 'N02CX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ipriflavon', 'M05BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('iprindol', 'N06AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('iproclozid', 'N06AF06');
INSERT INTO staging.atc (description, atc_code) VALUES ('iproniazid', 'N06AF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('irbesartan', 'C09CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('irbesartan und diuretika', 'C09DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('irinotecan', 'L01XX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('isepamicin', 'J01GB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoaminil', 'R05DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('isobromindion', 'M04AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('isocarboxazid', 'N06AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoconazol', 'D01AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoconazol', 'G01AF07');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoetarin', 'R03AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoetarin', 'R03CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('isofluran', 'N01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('isomethepten', 'A03AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoniazid', 'J04AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoniazid, kombinationen', 'J04AC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoprenalin', 'R03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoprenalin', 'R03CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoprenalin', 'C01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoprenalin und andere mittel bei obstruktiven atemwegserkrankungen', 'R03AK02');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoprenalin, kombinationen', 'R03CB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('isopropamid', 'A03AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('isopropamid und psycholeptika', 'A03CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('isopropanol', 'D08AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('isosorbid-dinitrat', 'C05AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('isosorbiddinitrat', 'C01DA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('isosorbiddinitrat, kombinationen', 'C01DA58');
INSERT INTO staging.atc (description, atc_code) VALUES ('isosorbidmononitrat', 'C01DA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('isothipendyl', 'R06AD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('isothipendyl', 'D04AA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('isotone lösungen', 'B05DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('isotretinoin', 'D10AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('isotretinoin', 'D10BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('isotretinoin, kombinationen', 'D10AD54');
INSERT INTO staging.atc (description, atc_code) VALUES ('isoxsuprin', 'C04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ispaghula (flohsamen)', 'A06AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ispaghula, kombinationen', 'A06AC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('isradipin', 'C08CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('itraconazol', 'J02AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('itramintosilat', 'C01DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('itramintosilat, kombinationen', 'C01DX51');
INSERT INTO staging.atc (description, atc_code) VALUES ('ivabradin', 'C01EB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('ivermectin', 'P02CF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('josamycin', 'J01FA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('kalium', 'A12B');
INSERT INTO staging.atc (description, atc_code) VALUES ('kalium', 'A12BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('kalium sparende mittel', 'C03D');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumcanrenoat', 'C03DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumchlorid', 'B05XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumchlorid', 'A12BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumchlorid, kombinationen', 'A12BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumcitrat', 'A12BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumgluconat', 'A12BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumhydrogencarbonat', 'A12BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumhydrogentartrat', 'A12BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumiodid', 'R05CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumiodid', 'V03AB21');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumiodid', 'S01XA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumlactat', 'B05XA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumperchlorat', 'H03BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumpermanganat', 'D08AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumpermanganat', 'V03AB18');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumphosphat, inkl. kombinationen mit anderen kaliumsalzen', 'B05XA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumpolysulfid', 'P03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaliumsalicylat', 'N02BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('kallidinogenase', 'C04AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('kanamycin', 'A07AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('kanamycin', 'S01AA24');
INSERT INTO staging.atc (description, atc_code) VALUES ('kanamycin', 'J01GB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('kaolin', 'A07BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('kapillarstabilisierende mittel', 'C05C');
INSERT INTO staging.atc (description, atc_code) VALUES ('kardioplege lösungen', 'B05XA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('kardiostimulanzien, exkl. herzglykoside', 'C01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('kardiovaskuläres system', 'V09G');
INSERT INTO staging.atc (description, atc_code) VALUES ('kardiovaskuläres system', 'C');
INSERT INTO staging.atc (description, atc_code) VALUES ('kationenaustauscherharze', 'V04CG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('kebuzon', 'M01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketamin', 'N01AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketanserin', 'C02KD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketazolam', 'N05BA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketobemidon', 'N02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketobemidon mit spasmolytika', 'N02AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketoconazol', 'D01AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketoconazol', 'G01AF11');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketoconazol', 'J02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketoprofen', 'M02AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketoprofen', 'M01AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketoprofen, kombinationen', 'M01AE53');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketorolac', 'M01AB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketorolac', 'S01BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketotifen', 'S01GX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ketotifen', 'R06AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('klysmen', 'A06AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('knochenmorphogene proteine', 'M05BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('kohle-haltige zubereitungen', 'A07BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('kohlendioxid', 'V03AN02');
INSERT INTO staging.atc (description, atc_code) VALUES ('kohlendioxid freisetzende mittel', 'A06AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('kohlenhydrate', 'B05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('kohlenhydrate', 'V06DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('kohlenhydrate/proteine/mineralstoffe/vitamine, kombinationen', 'V06DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('kollagen', 'B02BC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('kollagen', 'G04BX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('kollagen, kombinationen', 'D11AX57');
INSERT INTO staging.atc (description, atc_code) VALUES ('kollagenase', 'D03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('koloniestimulierende faktoren', 'L03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'A10AB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'A10AC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'S02DA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'J01CA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'D01AE20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'C01CA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'J05AR');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'A01AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'A06AG20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'A07BC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'A12BA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'N01BB20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'A11CC20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'A02AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'B02BC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'B05CX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'J01EB20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'J01EC20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'D06AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'A02AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'A02AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'B05BA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'R01AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'B01AC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'D01AC20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'J01CE30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'D01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'J07BC20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'J01ED20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'J06BB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'R05DA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'B05CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'G04BE30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'A10AD30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'A10AE30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'R05CB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'S01HA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'R05DB20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'B05CB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'R07AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen', 'R05CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen mit oralen antidiabetika', 'A10BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen mittelstark wirksamer corticosteroide', 'D07XB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen mittelstark wirksamer corticosteroide', 'D07AB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen und komplexe von aluminium-, calcium- und magnesium-haltigen verbindungen', 'A02AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von antibiotika', 'J01RA');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von antibiotika', 'J01R');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von antibiotika', 'S01AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von antihistaminika', 'R06AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von antihypertensiven wirkstoffen aus atc-gruppe c02', 'C02N');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von antineoplastischen mitteln', 'L01XY');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von barbituraten', 'N05CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von elektrolyten', 'B05XA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von imidazol-derivaten', 'G01AF20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von levothyroxin und liothyronin', 'H03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von mitteln zur behandlung der tuberkulose', 'J04AM');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von penicillinen', 'J01CR50');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von penicillinen, inkl. beta-lactamase-inhibitoren', 'J01CR');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von rauwolfia-alkaloiden', 'C02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von rauwolfia-alkaloiden und diuretika inkl. andere kombinationen', 'C02LA50');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von rauwolfia-alkaloiden, kombinationen', 'C02AA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von sulfonamiden', 'G01AE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von sulfonamiden und trimethoprim, inkl. derivate', 'J01EE');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von sympathomimetika', 'R03AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von tetracyclinen', 'J01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von vitaminen', 'A11JA');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen von xanthinen', 'R03DA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kombinationen zur eradikation von helicobacter pylori', 'A02BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('konjugierte estrogene', 'G03CA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('kontaktlaxanzien', 'A06AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('kontaktlaxanzien in kombination', 'A06AB20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kontaktlaxanzien in kombination mit belladonna-alkaloiden', 'A06AB30');
INSERT INTO staging.atc (description, atc_code) VALUES ('kontrastmittel', 'V08');
INSERT INTO staging.atc (description, atc_code) VALUES ('kontrastmittel für die magnetresonanztomographie', 'V08C');
INSERT INTO staging.atc (description, atc_code) VALUES ('kontrazeptiva zur lokalen anwendung', 'G02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('kosmetika', 'V07AT');
INSERT INTO staging.atc (description, atc_code) VALUES ('kreosot', 'R05CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('kuhpocken-immunglobulin', 'J06BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('kupferoleat', 'P03AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('kupfersulfat', 'V03AB20');
INSERT INTO staging.atc (description, atc_code) VALUES ('kupferusnat', 'G01AX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('kurz wirkende sulfonamide', 'J01EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('künstliche tränen und andere indifferente mittel', 'S01XA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('labetalol', 'C07AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('labetalol und andere diuretika', 'C07CG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('labetalol und thiazide', 'C07BG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lacidipin', 'C08CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('lacosamid', 'N03AX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactitol', 'A06AD12');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactobacillus-ferment', 'G01AX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactulose', 'A06AD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('lactulose, kombinationen', 'A06AD61');
INSERT INTO staging.atc (description, atc_code) VALUES ('lafutidin', 'A02BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('lamivudin', 'J05AF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('lamotrigin', 'N03AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('lanatosid c', 'C01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('lang wirkende sulfonamide', 'J01ED');
INSERT INTO staging.atc (description, atc_code) VALUES ('lanreotid', 'H01CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lansoprazol', 'A02BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lansoprazol, amoxicillin und clarithromycin', 'A02BD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lansoprazol, amoxicillin und metronidazol', 'A02BD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lansoprazol, tetracyclin und metronidazol', 'A02BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lanthan(iii)-carbonat', 'V03AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lapatinib', 'L01XE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('laronidase', 'A16AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('latamoxef', 'J01DD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('latanoprost', 'S01EE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('laurylsulfat, inkl. kombinationen', 'A06AG11');
INSERT INTO staging.atc (description, atc_code) VALUES ('laxanzien', 'A06');
INSERT INTO staging.atc (description, atc_code) VALUES ('laxanzien', 'A06A');
INSERT INTO staging.atc (description, atc_code) VALUES ('leber- und retikuloendothelialsystem', 'V09D');
INSERT INTO staging.atc (description, atc_code) VALUES ('leberfunktions-tests', 'V04CE');
INSERT INTO staging.atc (description, atc_code) VALUES ('lebertherapie', 'A05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('lebertherapie, lipotrope substanzen', 'A05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('lebertransalben', 'D03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('leflunomid', 'L04AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('leinsamen', 'A06AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('leinsamen, kombinationen', 'A06AC55');
INSERT INTO staging.atc (description, atc_code) VALUES ('lenalidomid', 'L04AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('lenograstim', 'L03AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('lentinan', 'L03AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lepirudin', 'B01AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lercanidipin', 'C08CA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('letostein', 'R05CB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('letrozol', 'L02BG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('leukotrienrezeptor-antagonisten', 'R03DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('leuprorelin', 'L02AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('levacetylmethadol', 'N07BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levamisol', 'P02CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('levetiracetam', 'N03AX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('levobunolol', 'S01ED03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levobupivacain', 'N01BB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('levocabastin', 'R01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('levocabastin', 'S01GX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('levocarnitin', 'A16AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('levocetirizin', 'R06AE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('levodopa', 'N04BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('levodopa und decarboxylasehemmer', 'N04BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('levodopa, decarboxylasehemmer und comt-hemmer', 'N04BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levodropropizin', 'R05DB27');
INSERT INTO staging.atc (description, atc_code) VALUES ('levofloxacin', 'S01AX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('levofloxacin', 'J01MA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('levomepromazin', 'N05AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel', 'G03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel', 'G03AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel und estrogen', 'G03FB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel und estrogen', 'G03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel und estrogen', 'G03FA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('levonorgestrel und estrogen', 'G03AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('levosimendan', 'C01CX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('levosulpirid', 'N05AL07');
INSERT INTO staging.atc (description, atc_code) VALUES ('levothyroxin-natrium', 'H03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('levoverbenon', 'R05CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocain', 'C05AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocain', 'D04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocain', 'S01HA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocain', 'R02AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocain', 'S02DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocain', 'C01BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocain', 'N01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidocain, kombinationen', 'N01BB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('lidoflazin', 'C08EX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lincomycin', 'J01FF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lincosamide', 'J01FF');
INSERT INTO staging.atc (description, atc_code) VALUES ('lindan', 'P03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('linezolid', 'J01XX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('linopirdin', 'N06BX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('linsidomin', 'C01DX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('liothyronin-natrium', 'H03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lipidsenker', 'C10B');
INSERT INTO staging.atc (description, atc_code) VALUES ('liraglutid', 'A10BX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lisinopril', 'C09AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lisinopril und amlodipin', 'C09BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lisinopril und diuretika', 'C09BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lisurid', 'G02CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lisurid', 'N02CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lithium', 'N05AN');
INSERT INTO staging.atc (description, atc_code) VALUES ('lithium', 'N05AN01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lithiumsuccinat', 'D11AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('lodoxamid', 'S01GX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('lofepramin', 'N06AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lofexidin', 'N07BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('lokalanästhetika', 'S01H');
INSERT INTO staging.atc (description, atc_code) VALUES ('lokalanästhetika', 'N01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('lokalanästhetika', 'R02AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('lokalanästhetika', 'S01HA');
INSERT INTO staging.atc (description, atc_code) VALUES ('lokalanästhetika', 'D04AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('lokalanästhetika', 'C05AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('lokale hämostatika', 'B02BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('lomefloxacin', 'S01AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('lomefloxacin', 'J01MA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lomustin', 'L01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lonazolac', 'M01AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('lonidamin', 'L01XX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('loperamid', 'A07DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('loperamid, kombinationen', 'A07DA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('loperamidoxid', 'A07DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('lopinavir', 'J05AE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('loprazolam', 'N05CD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('loracarbef', 'J01DC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('lorajmin', 'C01BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('loratadin', 'R06AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('lorazepam', 'N05BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('lorazepam, kombinationen', 'N05BA56');
INSERT INTO staging.atc (description, atc_code) VALUES ('lorcainid', 'C01BC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lormetazepam', 'N05CD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('lornoxicam', 'M01AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('losartan', 'C09CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('losartan und diuretika', 'C09DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lovastatin', 'C10AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lovastatin und nikotinsäure', 'C10BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('low-ceiling-diuretika und kalium sparende mittel', 'C03EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('low-ceiling-diuretika, exkl. thiazide', 'C03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('low-ceiling-diuretika, thiazide', 'C03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('loxapin', 'N05AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('lumiracoxib', 'M01AH06');
INSERT INTO staging.atc (description, atc_code) VALUES ('lutropin alfa', 'G03GA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lymecyclin', 'J01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('lynestrenol', 'G03DC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lynestrenol', 'G03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lynestrenol und estrogen', 'G03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lynestrenol und estrogen', 'G03FB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lynestrenol und estrogen', 'G03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lynestrenol und estrogen', 'G03FA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lypressin', 'H01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lysin', 'B05XB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('lysozym', 'D06BB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('lysozym', 'J05AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('lösungen mit wirkung auf den elektrolythaushalt', 'B05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('lösungen zur parenteralen ernährung', 'B05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('lösungen zur peritonealdialyse', 'B05D');
INSERT INTO staging.atc (description, atc_code) VALUES ('lösungs- und verdünnungsmittel, inkl. spüllösungen', 'V07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('macrogol', 'A06AD15');
INSERT INTO staging.atc (description, atc_code) VALUES ('macrogol, kombinationen', 'A06AD65');
INSERT INTO staging.atc (description, atc_code) VALUES ('mafenid', 'D06BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('magaldrat', 'A02AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('magaldrat und karminativa', 'A02AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('magensäuresekretions-tests', 'V04CG');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium', 'A12CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium (verschiedene salze in kombination)', 'A12CC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesium-haltige verbindungen', 'A02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumaspartat', 'A12CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumcarbonat', 'A06AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumcarbonat', 'A02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumchlorid', 'A12CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumchlorid', 'B05XA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumcitrat', 'A06AD19');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumcitrat', 'A12CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumcitrat', 'B05CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumgluconat', 'A12CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumhydroxid', 'G04BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumhydroxid', 'A02AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumlactat', 'A12CC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumlevulinat', 'A12CC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumorotat', 'A12CC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumoxid', 'A02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumoxid', 'A06AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumoxid', 'A12CC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumperoxid', 'A06AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumperoxid', 'A02AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumphosphat', 'B05XA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumpidolat', 'A12CC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumpyridoxal-5-phosphatglutamat', 'C10AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumsilikat', 'A02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumsulfat', 'B05XA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumsulfat', 'A12CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumsulfat', 'D11AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumsulfat', 'A06AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('magnesiumsulfat', 'V04CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('makrolide', 'J01FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('makrolide, lincosamide und streptogramine', 'J01F');
INSERT INTO staging.atc (description, atc_code) VALUES ('malariamittel', 'P01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('malathion', 'P03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mandelsäure', 'B05CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mandelsäure', 'J01XX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mangafodipir', 'V08CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('manidipin', 'C08CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('mannitol', 'A06AD16');
INSERT INTO staging.atc (description, atc_code) VALUES ('mannitol', 'B05CX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mannitol', 'B05BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mannosulfan', 'L01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mao-hemmer', 'C02KC');
INSERT INTO staging.atc (description, atc_code) VALUES ('mao-hemmer und diuretika', 'C02LL');
INSERT INTO staging.atc (description, atc_code) VALUES ('maprotilin', 'N06AA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('maraviroc', 'J05AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('maribavir', 'J05AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('masern, kombinationen mit mumps und röteln, lebend abgeschwächt', 'J07BD52');
INSERT INTO staging.atc (description, atc_code) VALUES ('masern, kombinationen mit mumps, lebend abgeschwächt', 'J07BD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('masern, kombinationen mit röteln, lebend abgeschwächt', 'J07BD53');
INSERT INTO staging.atc (description, atc_code) VALUES ('masern, lebend abgeschwächt', 'J07BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('masern-immunglobulin', 'J06BB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('masern-impfstoffe', 'J07BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('masoprocol', 'L01XX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('mazaticol', 'N04AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('mazindol', 'A08AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebendazol', 'P02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebendazol, kombinationen', 'P02CA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebeverin', 'A03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebhydrolin', 'R06AX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebutamat', 'N05BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebutizid', 'C03AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('mebutizid und kalium sparende mittel', 'C03EA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mecamylamin', 'C02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mecasermin', 'H01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mecillinam', 'J01CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('meclocyclin', 'D10AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('meclofenaminsäure', 'M02AA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('meclofenaminsäure', 'M01AG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('meclofenoxat', 'N06BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('meclozin', 'R06AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('meclozin, kombinationen', 'R06AE55');
INSERT INTO staging.atc (description, atc_code) VALUES ('medazepam', 'N05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('medifoxamin', 'N06AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('medizinische gase', 'V03AN');
INSERT INTO staging.atc (description, atc_code) VALUES ('medizinische haarwaschmittel', 'D11AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('medizinische kohle', 'A07BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('medizinische kohle, kombinationen', 'A07BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('medizinische verbände', 'D09A');
INSERT INTO staging.atc (description, atc_code) VALUES ('medizinische verbände', 'D09');
INSERT INTO staging.atc (description, atc_code) VALUES ('medizinische verbände mit antiinfektiva', 'D09AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('medrogeston', 'G03DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('medrogeston und estrogen', 'G03FB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesteron', 'G03AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesteron', 'L02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesteron', 'G03DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesteron und estrogen', 'G03FA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesteron und estrogen', 'G03AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('medroxyprogesteron und estrogen', 'G03FB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('medryson', 'S01BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('mefenaminsäure', 'M01AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mefenorex', 'A08AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('mefloquin', 'P01BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mefrusid', 'C03BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mefrusid und kalium', 'C03BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol', 'L02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol', 'G03DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol', 'G03AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol und estrogen', 'G03FB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol und estrogen', 'G03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol und estrogen', 'G03FA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('megestrol und estrogen', 'G03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('megluminantimonat', 'P01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('meglutol', 'C10AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('meladrazin', 'G04BD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('melagatran', 'B01AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('melanom-impfstoff', 'L03AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('melarsoprol', 'P01CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('melatonin', 'N05CH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('melatonin-rezeptor-antagonisten', 'N05CH');
INSERT INTO staging.atc (description, atc_code) VALUES ('melevodopa', 'N04BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('melevodopa und decarboxylasehemmer', 'N04BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('melitracen', 'N06AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('melitracen und psycholeptika', 'N06CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('meloxicam', 'M01AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('melperon', 'N05AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('melphalan', 'L01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('memantin', 'N06DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('menadion', 'B02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningokokken-impfstoffe', 'J07AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningokokkus a, gereinigtes polysaccharid-antigen', 'J07AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningokokkus b, äusseres-membranvesikel-antigen', 'J07AH06');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningokokkus bivalent, gereinigtes polysaccharid-antigen', 'J07AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningokokkus c, gereinigtes polysaccharid-antigen, konjugiert', 'J07AH07');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningokokkus tetravalent, gereinigtes polysaccharid-antigen', 'J07AH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('meningokokkus tetravalent, gereinigtes polysaccharid-antigen, konjugiert', 'J07AH08');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepacrin', 'P01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepartricin', 'D01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepartricin', 'G01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepartricin', 'G04CX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepartricin', 'A01AB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepenzolat', 'A03AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('mephenesin', 'M03BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mephenoxalon', 'N05BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mephentermin', 'C01CA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('mephenytoin', 'N03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mephenytoin, kombinationen', 'N03AB54');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepindolol', 'C07AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepivacain', 'N01BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepivacain, kombinationen', 'N01BB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepixanox', 'R07AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepolizumab', 'L04AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('meprednison', 'H02AB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('meprobamat', 'N05BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('meprobamat, kombinationen', 'N05BC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('meprobamat, kombinationen', 'N05CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('meprotixol', 'R05DB22');
INSERT INTO staging.atc (description, atc_code) VALUES ('meptazinol', 'N02AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepyramin', 'R06AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mepyramin', 'D04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mequinol', 'D11AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mequitazin', 'R06AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('merbromin', 'D08AK04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercaptamin', 'A16AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mercaptopurin', 'L01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('meropenem', 'J01DH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mersalyl', 'C03BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesalazin', 'A07EC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesna', 'V03AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesna', 'R05CB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesoridazin', 'N05AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesterolon', 'G03BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesulfen', 'D10AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesulfen', 'P03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mesuximid', 'N03AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('metabutethamin', 'N01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metacyclin', 'J01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('metahexamid', 'A10BB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('metallisches quecksilber', 'D08AK05');
INSERT INTO staging.atc (description, atc_code) VALUES ('metamfetamin', 'N06BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('metamizol-natrium', 'N02BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metamizol-natrium, kombinationen exkl. psycholeptika', 'N02BB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('metamizol-natrium, kombinationen mit psycholeptika', 'N02BB72');
INSERT INTO staging.atc (description, atc_code) VALUES ('metampicillin', 'J01CA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('metandienon', 'D11AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metandienon', 'A14AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('metaraminol', 'C01CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('metenolon', 'A14AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('metergolin', 'G02CB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('metformin', 'A10BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metformin und rosiglitazon', 'A10BD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('metformin und sulfonamide', 'A10BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methadon', 'N07BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methadon, kombinationen exkl. psycholeptika', 'N02AC52');
INSERT INTO staging.atc (description, atc_code) VALUES ('methallenestril', 'G03CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methallenestril', 'G03CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methanolchinoline', 'P01BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('methanthelinium', 'A03AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('methapyrilen', 'R06AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('methaqualon', 'N05CM01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methaqualon, kombinationen', 'N05CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metharbital', 'N03AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('methazolamid', 'S01EC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('methdilazin', 'R06AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methenamin', 'J01XX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('methiodal', 'V08AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('methionin', 'V03AB26');
INSERT INTO staging.atc (description, atc_code) VALUES ('methiosulfoniumchlorid', 'A02BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methocarbamol', 'M03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methocarbamol, kombinationen exkl. psycholeptika', 'M03BA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('methocarbamol, kombinationen mit psycholeptika', 'M03BA73');
INSERT INTO staging.atc (description, atc_code) VALUES ('methohexital', 'N05CA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('methohexital', 'N01AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoserpidin', 'C02AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoserpidin und diuretika', 'C02LA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methotrexat', 'L04AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methotrexat', 'L01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoxamin', 'C01CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoxsalen', 'D05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoxsalen', 'D05AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoxyfluran', 'N02BG09');
INSERT INTO staging.atc (description, atc_code) VALUES ('methoxyphenamin', 'R03CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylaminolevulinat', 'L01XD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylatropin', 'A03BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylcellulose', 'A06AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylclothiazid', 'C03AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylclothiazid und kalium', 'C03AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyldopa', 'C02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyldopa (linksdrehend)', 'C02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyldopa (linksdrehend) und diuretika', 'C02LB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyldopa (racemisch)', 'C02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyldopa und diuretika in kombination', 'C02LB');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylergometrin', 'G02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylergometrin und oxytocin', 'G02AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylestrenolon', 'G03DC31');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylhomatropin und psycholeptika', 'A03CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylhydrazine', 'L01XB');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylnaltrexon bromid', 'A06AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylnortestosteron und estrogen', 'G03FA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylpentynol', 'N05CM15');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylpentynol, kombinationen', 'N05CX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylphenidat', 'N06BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylphenobarbital', 'N03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolon', 'H02AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolon', 'D10AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolon', 'D07AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolon und antibiotika', 'D07CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolon und antiinfektiva', 'S01CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolon, kombinationen', 'H02BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylprednisolonaceponat', 'D07AC14');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylpropylpropanedioldinitrat', 'C01DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylpropylpropanedioldinitrat, kombinationen', 'C01DA54');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylrosanilin', 'G01AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylrosanilin', 'D01AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylscopolamin', 'A03BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylscopolamin', 'S01FA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylscopolamin und psycholeptika', 'A03CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyltestosteron', 'G03EK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyltestosteron', 'G03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyltestosteron und estrogen', 'G03EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylthioniniumchlorid', 'V04CG05');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylthioniniumchlorid', 'V03AB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('methylthiouracil', 'H03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('methyprylon', 'N05CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('methysergid', 'N02CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('meticillin', 'J01CF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('meticran', 'C03BA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('metildigoxin', 'C01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('metipranolol', 'S01ED04');
INSERT INTO staging.atc (description, atc_code) VALUES ('metipranolol und thiazide, kombinationen', 'C07BA68');
INSERT INTO staging.atc (description, atc_code) VALUES ('metipranolol, kombinationen', 'S01ED54');
INSERT INTO staging.atc (description, atc_code) VALUES ('metirosin', 'C02KB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metisazon', 'J05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metixen', 'N04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('metizolin', 'R01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoclopramid', 'A03FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metolazon', 'C03BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('metolazon und kalium sparende mittel', 'C03EA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('metopimazin', 'A04AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol', 'C07AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol und andere antihypertonika', 'C07FB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol und andere diuretika', 'C07CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol und thiazide', 'C07BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol und thiazide, kombinationen', 'C07BB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('metoprolol, kombinationspackungen', 'C07AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('metrifonat', 'P02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metrizamid', 'V08AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metrizoesäure', 'V08AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('metronidazol', 'G01AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metronidazol', 'J01XD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metronidazol', 'P01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metronidazol', 'D06BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('metronidazol', 'A01AB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('metyrapon', 'V04CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mexiletin', 'C01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mezlocillin', 'J01CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('mianserin', 'N06AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mibefradil', 'C08CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('micafungin', 'J02AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazol', 'S02AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazol', 'J02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazol', 'D01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazol', 'A07AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazol', 'A01AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazol', 'G01AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('miconazol, kombinationen', 'D01AC52');
INSERT INTO staging.atc (description, atc_code) VALUES ('micronomicin', 'S01AA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('midazolam', 'N05CD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('midecamycin', 'J01FA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('midodrin', 'C01CA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('mifepriston', 'G03XB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('miglitol', 'A10BF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('miglustat', 'A16AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('migränemittel', 'N02C');
INSERT INTO staging.atc (description, atc_code) VALUES ('mikrobielle antidiarrhoika', 'A07FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('mikrobielle antidiarrhoika', 'A07F');
INSERT INTO staging.atc (description, atc_code) VALUES ('milchersatzstoffe', 'V06DF');
INSERT INTO staging.atc (description, atc_code) VALUES ('milchsäure', 'G01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('milchsäurebildner', 'A07FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('milchsäurebildner, kombinationen', 'A07FA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('milnacipran', 'N06AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('milrinon', 'C01CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('miltefosin', 'L01XX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('milzbrand-impfstoffe', 'J07AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('minaprin', 'N06AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('mineralocorticoide', 'H02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('mineralsalze in kombination', 'A06AD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('mineralstoffe', 'A12');
INSERT INTO staging.atc (description, atc_code) VALUES ('minocyclin', 'A01AB23');
INSERT INTO staging.atc (description, atc_code) VALUES ('minocyclin', 'J01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('minoxidil', 'D11AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('minoxidil', 'C02DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('miocamycin', 'J01FA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('mirtazapin', 'N06AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('misoprostol', 'A02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitiglinid', 'A10BX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitobronitol', 'L01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitoguazon', 'L01XX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitomycin', 'L01DC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitotan', 'L01XX23');
INSERT INTO staging.atc (description, atc_code) VALUES ('mitoxantron', 'L01DB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel bei benigner prostatahyperplasie', 'G04C');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel bei erektiler dysfunktion', 'G04BE');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel bei funktionellen gastrointestinalen störungen', 'A03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel bei funktionellen störungen des darms', 'A03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel bei obstruktiven atemwegserkrankungen', 'R03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel bei peptischem ulkus und gastroesophagealer refluxkrankheit', 'A02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel bei säure bedingten erkrankungen', 'A02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel gegen amöben und andere protozoen-erkrankungen', 'P01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel gegen ektoparasiten, inkl. antiscabiosa', 'P03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel gegen ektoparasiten, inkl. antiscabiosa, insektizide und repellenzien', 'P03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel gegen leishmaniasis und trypanosomiasis', 'P01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel gegen mykobakterien', 'J04');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel gegen protozoen-erkrankungen', 'P01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel mit einfluss auf die knochenstruktur und die mineralisation', 'M05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel mit wirkung auf das renin-angiotensin-system', 'C09');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel mit wirkung auf die arterielle gefässmuskulatur', 'C02D');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur behandlung der alkoholabhängigkeit', 'N07BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur behandlung der hyperkaliämie und hyperphosphatämie', 'V03AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur behandlung der hyperkalzämie', 'V03AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur behandlung der hypoglykämie', 'V03AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur behandlung der lepra', 'J04B');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur behandlung der lepra', 'J04BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur behandlung der nikotinabhängigkeit', 'N07BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur behandlung der opiatabhängigkeit', 'N07BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur behandlung der tuberkulose', 'J04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur behandlung von hämorrhoiden und analfissuren zur topischen anwendung', 'C05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur behandlung von knochenerkrankungen', 'M05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur behandlung von suchterkrankungen', 'N07B');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur embolisation', 'V03AM');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur gallentherapie und lipotrope substanzen in kombination', 'A05C');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel zur kariesprophylaxe', 'A01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel, die den lipidstoffwechsel beeinflussen', 'C10');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittel, die den lipidstoffwechsel beeinflussen, rein', 'C10A');
INSERT INTO staging.atc (description, atc_code) VALUES ('mittellang wirkende sulfonamide', 'J01EC');
INSERT INTO staging.atc (description, atc_code) VALUES ('mivacuriumchlorid', 'M03AC10');
INSERT INTO staging.atc (description, atc_code) VALUES ('mizolastin', 'R06AX25');
INSERT INTO staging.atc (description, atc_code) VALUES ('moclobemid', 'N06AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('modafinil', 'N06BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('moexipril', 'C09AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('moexipril und diuretika', 'C09BA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('mofebutazon', 'M02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mofebutazon', 'M01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('molgramostim', 'L03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('molindon', 'N05AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('molsidomin', 'C01DX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('mometason', 'R03BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('mometason', 'D07XC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('mometason', 'R01AD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('mometason', 'D07AC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('monoaminoxidase-a-hemmer', 'N06AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('monoaminoxidase-b-hemmer', 'N04BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('monoaminoxidasehemmer, nichtselektiv', 'N06AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('monobactame', 'J01DF');
INSERT INTO staging.atc (description, atc_code) VALUES ('monobenzon', 'D11AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('monoethanolaminoleat', 'C05BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('monoklonale antikörper', 'L01XC');
INSERT INTO staging.atc (description, atc_code) VALUES ('monoxerutin', 'C05CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('montelukast', 'R03DC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('moperon', 'N05AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('moracizin', 'C01BG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('morclofon', 'R05DB25');
INSERT INTO staging.atc (description, atc_code) VALUES ('morinamid', 'J04AK04');
INSERT INTO staging.atc (description, atc_code) VALUES ('morniflumat', 'M01AX22');
INSERT INTO staging.atc (description, atc_code) VALUES ('moroxydin', 'J05AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphin', 'N02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphin mit spasmolytika', 'N02AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphin, kombinationen', 'N02AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphin, kombinationen', 'A07DA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('morphinan-derivate', 'N02AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('morpholinsalicylat', 'N02BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('mosapramin', 'N05AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('motilitätshemmer', 'A07DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('motilitätshemmer', 'A07D');
INSERT INTO staging.atc (description, atc_code) VALUES ('motretinid', 'D10AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxaverin', 'A03AD30');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxestrol', 'G03CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxifloxacin', 'J01MA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxisylyt', 'G04BE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxisylyt', 'C04AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxonidin', 'C02AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('moxonidin und diuretika', 'C02LC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('mukolytika', 'R05CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('multienzyme (lipase, protease etc.)', 'A09AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('multienzyme und säure-haltige zubereitungen', 'A09AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamine mit mineralstoffen', 'A11AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamine und andere mineralstoffe, inkl. kombinationen', 'A11AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamine und calcium', 'A11AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamine und eisen', 'A11AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamine und spurenelemente', 'A11AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamine, andere kombinationen', 'A11AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamine, kombinationen', 'A11A');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamine, rein', 'A11B');
INSERT INTO staging.atc (description, atc_code) VALUES ('multivitamine, rein', 'A11BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('mumps, lebend abgeschwächt', 'J07BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mumps-immunglobulin', 'J06BB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('mumps-impfstoffe', 'J07BE');
INSERT INTO staging.atc (description, atc_code) VALUES ('mupirocin', 'D06AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('mupirocin', 'R01AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('muromonab-cd3', 'L04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('muskel- und skelettsystem', 'M');
INSERT INTO staging.atc (description, atc_code) VALUES ('muskelrelaxantien', 'C05AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('muskelrelaxanzien', 'M03');
INSERT INTO staging.atc (description, atc_code) VALUES ('muskelrelaxanzien, direkt wirkende mittel', 'M03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('muskelrelaxanzien, peripher wirkende mittel', 'M03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('muskelrelaxanzien, zentral wirkende mittel', 'M03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('mutterkorn-alkaloide', 'G02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('mutterkorn-alkaloide', 'C04AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('mutterkorn-alkaloide', 'G02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('mutterkorn-alkaloide', 'N02CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('mutterkorn-alkaloide und oxytocin inkl. derivate, in kombination', 'G02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('muzolimin', 'C03CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('mycophenolsäure', 'L04AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('mydriatika und zykloplegika', 'S01F');
INSERT INTO staging.atc (description, atc_code) VALUES ('myristylbenzalkonium', 'R02AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('n-(hydroxymethyl)nicotinamid', 'A05AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nabilon', 'A04AD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('nabiximols', 'N02BG10');
INSERT INTO staging.atc (description, atc_code) VALUES ('nabumeton', 'M01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nadolol', 'C07AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('nadolol und thiazide', 'C07BA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('nadroparin', 'B01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nafarelin', 'H01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naftidrofuryl', 'C04AX21');
INSERT INTO staging.atc (description, atc_code) VALUES ('naftifin', 'D01AE22');
INSERT INTO staging.atc (description, atc_code) VALUES ('nahrungsmittel', 'V01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('nalbufin', 'N02AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nalidixinsäure', 'J01MB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nalorphin', 'V03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naloxon', 'V03AB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('naltrexon', 'N07BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nandrolon', 'S01XA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('nandrolon', 'A14AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('naphazolin', 'R01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('naphazolin', 'S01GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('naphazolin', 'R01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naphazolin, kombinationen', 'S01GA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('naproxen', 'G02CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naproxen', 'M01AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('naproxen', 'M02AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('naratriptan', 'N02CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('narcobarbital', 'N01AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nasale dekongestiva zur systemischen anwendung', 'R01B');
INSERT INTO staging.atc (description, atc_code) VALUES ('natalizumab', 'L04AA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('natamycin', 'G01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natamycin', 'A07AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('natamycin', 'S01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('natamycin', 'D01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natamycin', 'A01AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('nateglinid', 'A10BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('natrium', 'A12CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('natrium aurothiosulfat', 'M01CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natrium-iodid (124i)', 'V09FX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('natrium-oxybat', 'N07XX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumacetat', 'B05XA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumaminosalicylat', 'J04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumapolat', 'C05BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumaurothiomalat', 'M01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumbicarbonat', 'B05CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumbicarbonat', 'B05XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumbituminosulfonat', 'D10BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumborat', 'S01AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumcellulosephosphat', 'V03AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumchlorid', 'B05XA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumchlorid', 'A12CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumchlorid', 'B05CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumchlorid, hyperton', 'S01XA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumcitrat', 'B05XA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumcitrat', 'B05CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumedetat', 'S01XA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumferedetat', 'B03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumfluorid', 'A01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumfluorid', 'A12CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumfluorid, kombinationen', 'A01AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumfluorid, kombinationen', 'A12CD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumfolinat', 'V03AF06');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumhypochlorit', 'D08AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumiopodat', 'V08AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumlevofolinat', 'V03AF10');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriummonofluorphosphat', 'A01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriummonofluorphosphat', 'A12CD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumnitrit', 'V03AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumpentosanpolysulfat', 'C05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumperborat', 'A01AB19');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumphenylbutyrat', 'A16AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumphosphat', 'B05XA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumphosphat', 'A06AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumphosphat', 'A06AD17');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumpicosulfat', 'A06AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumpicosulfat, kombinationen', 'A06AB58');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumpropionat', 'S01AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumsalicylat', 'N02BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumselenat', 'A12CE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumselenit', 'A12CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumstibogluconat', 'P01CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumsulfat', 'A06AD13');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumsulfat', 'A12CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumtartrat', 'A06AD21');
INSERT INTO staging.atc (description, atc_code) VALUES ('natriumtetradecylsulfat', 'C05BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('natürliche opium-alkaloide', 'N02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('natürliche phospholipide', 'R07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('natürliche und halbsynthetische estrogene, rein', 'G03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('nebacumab', 'J06BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nebennierenhemmstoffe', 'H02C');
INSERT INTO staging.atc (description, atc_code) VALUES ('nebenschilddrüsen-antagonisten', 'H05B');
INSERT INTO staging.atc (description, atc_code) VALUES ('nebenschilddrüsenextrakt', 'H05AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nebenschilddrüsenhormone und analoga', 'H05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('nebenschilddrüsenhormone und analoga', 'H05A');
INSERT INTO staging.atc (description, atc_code) VALUES ('nebivolol', 'C07AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('nedocromil', 'S01GX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nedocromil', 'R03BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('nedocromil', 'R01AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('nefazodon', 'N06AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nefopam', 'N02BG06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nelfinavir', 'J05AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('neltenexin', 'R05CB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('nematodenmittel', 'P02C');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'B05CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'D06AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'J01GB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'R02AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'A07AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'S02AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'A01AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'S03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin', 'S01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('neomycin, kombinationen', 'A07AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('neostigmin', 'N07AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('neostigmin', 'S01EB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('neostigmin, kombinationen', 'N07AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('nepinalon', 'R05DB26');
INSERT INTO staging.atc (description, atc_code) VALUES ('nerven dämpfende mittel', 'V03AZ');
INSERT INTO staging.atc (description, atc_code) VALUES ('nervensystem', 'N');
INSERT INTO staging.atc (description, atc_code) VALUES ('nesiritid', 'C01DX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('netilmicin', 'J01GB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('netilmicin', 'S01AA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('neuraminidasehemmer', 'J05AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('neuroleptika bei spätdyskinesien', 'N05AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('nevirapin', 'J05AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nialamid', 'N06AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('niaprazin', 'N05CM16');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicardipin', 'C08CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicergolin', 'C04AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('niceritrol', 'C10AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicht-nukleosidale inhibitoren der reversen transkriptase', 'J05AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('nichtselektive beta-adrenorezeptor-agonisten', 'R03CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('nichtselektive beta-adrenorezeptor-agonisten', 'R03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('nichtselektive calciumkanalblocker', 'C08E');
INSERT INTO staging.atc (description, atc_code) VALUES ('nichtselektive monoamin-wiederaufnahmehemmer', 'N06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('nichtsteroidale antiphlogistika', 'S01BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('nichtsteroidale antiphlogistika und antiinfektiva in kombination', 'S01CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('nichtsteroidale antiphlogistika und antirheumatika', 'M01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('nichtsteroidale antiphlogistika zur topischen anwendung', 'M02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('niclosamid', 'P02DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicofetamid', 'A03AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicofuranose', 'C10AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicomorphin', 'N02AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicorandil', 'C01DX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotin', 'N07BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinamid', 'A11HA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinsäure', 'C04AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinsäure', 'C10AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinsäure und derivate', 'C04AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinsäure und derivate', 'C10AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinylalkohol (pyridylcarbinol)', 'C04AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nicotinylalkohol (pyridylcarbinol)', 'C10AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('niedrigkalorische diäten', 'V06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('nierenfunktions-tests', 'V04CH');
INSERT INTO staging.atc (description, atc_code) VALUES ('nierensystem', 'V09C');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifedipin', 'C08CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifedipin und diuretika', 'C08GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifedipin, kombinationen', 'C08CA55');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifenazon', 'M02AA24');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifenazon', 'N02BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifluminsäure', 'M02AA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifluminsäure', 'M01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifuratel', 'G01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifuroxazid', 'A07AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifurtimox', 'P01CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifurtoinol', 'J01XE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nifurzid', 'A07AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nikethamid', 'R07AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nikethamid, kombinationen', 'R07AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('nilotinib', 'L01XE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('nilutamid', 'L02BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nilvadipin', 'C08CA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('nimesulid', 'M01AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('nimodipin', 'C08CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nimorazol', 'P01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nimustin', 'L01AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('niperotidin', 'A02BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('niridazol', 'P02BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nisoldipin', 'C08CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitisinon', 'A16AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrazepam', 'N05CD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrendipin', 'C08CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitroferrocyanid-derivate', 'C02DD');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofural', 'B05CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofural', 'S02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofural', 'D08AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofural', 'S01AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofural', 'P01CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofural', 'D09AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofuran-derivate', 'J01XE');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofuran-derivate', 'P01CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofuran-derivate', 'D08AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrofurantoin', 'J01XE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitroimidazol-derivate', 'P01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitroimidazol-derivate', 'P01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitroprussid', 'C02DD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitrosoharnstoffe', 'L01AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('nitroxolin', 'J01XX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('nizatidin', 'A02BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nizofenon', 'N06BX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('nomegestrol', 'G03DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nomegestrol und östrogen', 'G03AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('nomifensin', 'N06AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('nonacog alfa', 'B02BD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('nordazepam', 'N05BA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('norelgestromin und estrogen', 'G03AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('norepinephrin', 'C01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethandrolon', 'A14AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethisteron', 'G03DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethisteron', 'G03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethisteron und estrogen', 'G03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethisteron und estrogen', 'G03FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethisteron und estrogen', 'G03FB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('norethisteron und estrogen', 'G03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('noretynodrel und estrogen', 'G03FA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('norfenefrin', 'C01CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('norfloxacin', 'J01MA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('norfloxacin', 'S01AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('norgestimat und estrogen', 'G03AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('norgestimat und estrogen', 'G03FA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('norgestrel und estrogen', 'G03FB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('norgestrel und estrogen', 'G03AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('norgestrel und estrogen', 'G03FA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('norgestrienon', 'G03AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('normethadon', 'R05DA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('nortriptylin', 'N06AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('noscapin', 'R05DA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('noxytiolin', 'B05CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('nukleosidale und nukleotidale inhibitoren der reversen transkriptase', 'J05AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('nukleoside und nukleotide, exkl. inhibitoren der reversen transkriptase', 'J05AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('nystatin', 'A07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('nystatin', 'D01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nystatin', 'G01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('nystatin, kombinationen', 'G01AA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('obidoxim', 'V03AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('oblimersen', 'L01XX36');
INSERT INTO staging.atc (description, atc_code) VALUES ('octenidin, kombinationen', 'D08AJ57');
INSERT INTO staging.atc (description, atc_code) VALUES ('octenidin, kombinationen', 'G01AX66');
INSERT INTO staging.atc (description, atc_code) VALUES ('octinoxat', 'D02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('octopamin', 'C01CA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('octreotid', 'H01CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ofloxacin', 'S02AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('ofloxacin', 'S01AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('ofloxacin', 'J01MA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('olaflur', 'A01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('olanzapin', 'N05AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oleandomycin', 'J01FA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('olmesartan medoxomil', 'C09CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('olmesartan medoxomil und amlodipin', 'C09DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('olopatadin', 'S01GX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('olsalazin', 'A07EC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('omalizumab', 'R03DX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('omapatrilat', 'C09EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('omega-3-fettsäuren inkl. andere ester und säuren', 'C10AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('omeprazol', 'A02BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('omeprazol, amoxicillin und clarithromycin', 'A02BD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('omeprazol, amoxicillin und metronidazol', 'A02BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('omoconazol', 'D01AC13');
INSERT INTO staging.atc (description, atc_code) VALUES ('omoconazol', 'G01AF16');
INSERT INTO staging.atc (description, atc_code) VALUES ('ondansetron', 'A04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ophthalmika**', 'S01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ophthalmologische und otologische zubereitungen', 'S03');
INSERT INTO staging.atc (description, atc_code) VALUES ('opioidanästhetika', 'N01AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('opioide', 'N02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('opioide in kombination mit spasmolytika', 'N02AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('opipramol', 'N06AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium', 'A07DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium', 'N02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium-alkaloide mit morphin', 'R05DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium-alkaloide und derivate', 'R05DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium-derivate und expektoranzien', 'R05FA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium-derivate und expektoranzien', 'R05FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('opium-derivate und mukolytika', 'R05FA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('oprelvekin', 'L03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('orciprenalin', 'R03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('orciprenalin', 'R03CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('orciprenalin, kombinationen', 'R03CB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('organische nitrate', 'C01DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('organische nitrate in kombination', 'C01DA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('organische nitrate in kombination mit psycholeptika', 'C01DA70');
INSERT INTO staging.atc (description, atc_code) VALUES ('organische säuren', 'G01AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('organophosphat-verbindungen', 'P02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('orgotein', 'M01AX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('oripavin-derivate', 'N02AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('oritavancin', 'J01XA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('orlistat', 'A08AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ornidazol', 'J01XD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ornidazol', 'P01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ornidazol', 'G01AF06');
INSERT INTO staging.atc (description, atc_code) VALUES ('ornipressin', 'H01BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ornithinoxoglurat', 'A05BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('orphenadrin(chlorid)', 'N04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('orphenadrin(citrat)', 'M03BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('orphenadrin, kombinationen', 'M03BC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('oseltamivir', 'J05AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('osmodiuretika', 'B05BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('osmotisch wirkende laxanzien', 'A06AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('otiloniumbromid', 'A03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('otiloniumbromid und psycholeptika', 'A03CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('otologika', 'S02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ovulationsauslöser, synthetisch', 'G03GB');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxaboloncipionat', 'A14AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxaceprol', 'D11AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxaceprol', 'M01AX24');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxacillin', 'J01CF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxaflozan', 'N06AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxaliplatin', 'L01XA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxametacin', 'M01AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxamniquin', 'P02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxandrolon', 'A14AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxantel', 'P02CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxaprozin', 'M01AE12');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxatomid', 'R06AE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxazepam', 'N05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxazol-, thiazin- und triazin-derivate', 'M03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxazolidin-derivate', 'N03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxcarbazepin', 'N03AF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxedrin', 'S01GA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxedrin', 'C01CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxedrin, kombinationen', 'S01GA56');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxeladin', 'R05DB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxetacain', 'C05AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxetoron', 'N02CX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxicame', 'M01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxichinolin', 'D08AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxiconazol', 'D01AC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxiconazol', 'G01AF17');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxidierte zellulose', 'B02BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxiracetam', 'N06BX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxitriptan', 'N06AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxitropiumbromid', 'R03BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxolamin', 'R05DB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxolinsäure', 'J01MB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxomemazin', 'R06AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxprenolol', 'C07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxprenolol und andere diuretika', 'C07CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxprenolol und thiazide', 'C07BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxybuprocain', 'S01HA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxybuprocain', 'D04AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxybutynin', 'G04BD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxychinolin', 'A01AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxychinolin', 'R02AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxychinolin', 'G01AC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxycinchophen', 'M01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxycodon', 'N02AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyfedrin', 'C01DX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyfedrin, kombinationen', 'C01DX53');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxymetazolin', 'R01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxymetazolin', 'S01GA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxymetazolin', 'R01AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxymetholon', 'A14AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxypertin', 'N05AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphenbutazon', 'S01BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphenbutazon', 'M01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphenbutazon', 'M02AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphencyclimin', 'A03AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphencyclimin und psycholeptika', 'A03CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphenisatin', 'A06AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphenonium', 'A03AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxyphenonium, kombinationen', 'A03AB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytetracyclin', 'J01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytetracyclin', 'S01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytetracyclin', 'G01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytetracyclin', 'D06AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytetracyclin, kombinationen', 'J01AA56');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytocin', 'H01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('oxytocin und analoga', 'H01BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('paclitaxel', 'L01CD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('palivizumab', 'J06BB16');
INSERT INTO staging.atc (description, atc_code) VALUES ('paltitrexid', 'L01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pamidronsäure', 'M05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pancuronium', 'M03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('panipenem und betamipron', 'J01DH55');
INSERT INTO staging.atc (description, atc_code) VALUES ('panitumumab', 'L01XC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pankreasfunktions-tests', 'V04CK');
INSERT INTO staging.atc (description, atc_code) VALUES ('pankreashormone', 'H04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pankreozymin (cholecystokinin)', 'V04CK02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pantethin', 'A11HA32');
INSERT INTO staging.atc (description, atc_code) VALUES ('pantoprazol', 'A02BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pantoprazol, amoxicillin und clarithromycin', 'A02BD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaveretum', 'N02AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaverin', 'A03AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaverin', 'G04BE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaverin und derivate', 'A03AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaverin, kombinationen', 'A03AD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('papaverin, kombinationen', 'G04BE52');
INSERT INTO staging.atc (description, atc_code) VALUES ('paracetamol', 'N02BE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('paracetamol, kombinationen exkl. psycholeptika', 'N02BE51');
INSERT INTO staging.atc (description, atc_code) VALUES ('paracetamol, kombinationen mit psycholeptika', 'N02BE71');
INSERT INTO staging.atc (description, atc_code) VALUES ('paraldehyd', 'N05CC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('paramagnetische kontrastmittel', 'V08CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('paramethadion', 'N03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('paramethason', 'H02AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('paraoxon', 'S01EB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('parasympathomimetika', 'S01EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('parasympathomimetika', 'N07A');
INSERT INTO staging.atc (description, atc_code) VALUES ('parecoxib', 'M01AH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pargylin', 'C02KC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pargylin und diuretika', 'C02LL01');
INSERT INTO staging.atc (description, atc_code) VALUES ('paricalcitol', 'H05BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('parnaparin', 'B01AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('paromomycin', 'A07AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('paroxetin', 'N06AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pazopanib', 'L01XE11');
INSERT INTO staging.atc (description, atc_code) VALUES ('pecilocin', 'D01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pefloxacin', 'J01MA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pegademase', 'L03AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pegaptanib', 'S01LA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pegaspargase', 'L01XX24');
INSERT INTO staging.atc (description, atc_code) VALUES ('pegfilgrastim', 'L03AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('peginterferon alfa-2a', 'L03AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('peginterferon alfa-2b', 'L03AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('pegloticas', 'M04AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pegvisomant', 'H01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pektin', 'A07BC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pemetrexed', 'L01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pemolin', 'N06BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('penamecillin', 'J01CE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('penbutolol', 'C07AA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('penbutolol und andere diuretika', 'C07CA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('penciclovir', 'D06BB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('penciclovir', 'J05AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('penfluridol', 'N05AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillamin', 'M01CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicillamin und ähnliche mittel', 'M01CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicilline mit erweitertem wirkungsspektrum', 'J01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('penicilline, kombination mit anderen antibiotika', 'J01RA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('penimepicyclin', 'J01AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentaerythrityl', 'A06AD14');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentaerythrityltetranitrat', 'C01DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentaerythrityltetranitrat, kombinationen', 'C01DA55');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentagastrin', 'V04CG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentamidindiisetionat', 'P01CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentamycin', 'G01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentazocin', 'N02AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentetrazol', 'R07AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentetrazol, kombinationen', 'R07AB53');
INSERT INTO staging.atc (description, atc_code) VALUES ('penthienat', 'A03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentifyllin', 'C04AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentobarbital', 'N05CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentostatin', 'L01XX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentoxifyllin', 'C04AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pentoxyverin', 'R05DB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pepsin', 'A09AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pepsin- und säure-haltige zubereitungen', 'A09AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('perazin', 'N05AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('perchlorate', 'H03BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('perflenapent', 'V08DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('perflubron', 'V08CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pergolid', 'N04BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('perhexilin', 'C08EX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('periciazin', 'N05AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('perindopril', 'C09AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('perindopril und amlodipin', 'C09BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('perindopril und diuretika', 'C09BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('peripher wirkende antiadiposita', 'A08AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('periphere opioidrezeptor-antagonisten', 'A06AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('periphere vasodilatatoren', 'C04');
INSERT INTO staging.atc (description, atc_code) VALUES ('periphere vasodilatatoren', 'C04A');
INSERT INTO staging.atc (description, atc_code) VALUES ('permethrin', 'P03AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('permethrin, kombinationen', 'P03AC54');
INSERT INTO staging.atc (description, atc_code) VALUES ('peroxide', 'D10AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('perphenazin', 'N05AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pertussis, gereinigtes antigen', 'J07AJ02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pertussis, gereinigtes antigen, kombinationen mit toxoiden', 'J07AJ52');
INSERT INTO staging.atc (description, atc_code) VALUES ('pertussis, inaktiviert, ganze zelle', 'J07AJ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pertussis, inaktiviert, ganze zelle, kombinationen mit toxoiden', 'J07AJ51');
INSERT INTO staging.atc (description, atc_code) VALUES ('pertussis-immunglobulin', 'J06BB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('pertussis-impfstoffe', 'J07AJ');
INSERT INTO staging.atc (description, atc_code) VALUES ('peruvosid', 'C01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pest, inaktiviert, ganze zelle', 'J07AK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pest-impfstoffe', 'J07AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('pethidin', 'N02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pethidin mit spasmolytika', 'N02AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pethidin, kombinationen exkl. psycholeptika', 'N02AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('pethidin, kombinationen mit psycholeptika', 'N02AB72');
INSERT INTO staging.atc (description, atc_code) VALUES ('pflanzliche alkaloide und andere natürliche mittel', 'L01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('pflaster', 'V07AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('phanquinon', 'P01AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenacemid', 'N03AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenacetin', 'N02BE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenacetin, kombinationen exkl. psycholeptika', 'N02BE53');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenacetin, kombinationen mit psycholeptika', 'N02BE73');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenazocin', 'N02AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenazon', 'N02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenazon, kombinationen exkl. psycholeptika', 'N02BB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenazon, kombinationen mit psycholeptika', 'N02BB71');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenazopyridin', 'G04BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenelzin', 'N06AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pheneticillin', 'J01CE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pheneturid', 'N03AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenformin', 'A10BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenformin und sulfonamide', 'A10BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenglutarimid', 'N04AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenindamin', 'R06AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenindion', 'B01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pheniramin', 'R06AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenobarbital', 'N03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol', 'C05BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol', 'R02AA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol', 'N01BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol', 'D08AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenol und derivate', 'D08AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenolphthalein', 'A06AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenolsulfonphthalein', 'V04CH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenoperidin', 'N01AH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothiazin-derivate', 'R06AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothiazine mit aliphatischer seitenkette', 'N05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothiazine mit piperazinstruktur', 'N05AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothiazine mit piperidinstruktur', 'N05AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothrin', 'P03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenothrin, kombinationen', 'P03AC53');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenoxybenzamin', 'C04AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenoxymethylpenicillin', 'J01CE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenoxymethylpenicillin-benzathin', 'J01CE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenprobamat', 'M03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenprobamat, kombinationen exkl. psycholeptika', 'M03BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenprobamat, kombinationen mit psycholeptika', 'M03BA71');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenprocoumon', 'B01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phensuximid', 'N03AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phentermin', 'A08AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phentolamin', 'C04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phentolamin', 'G04BE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylalkylamin-derivate', 'C08DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylalkylamin-derivate', 'C08EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylbutazon', 'M02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylbutazon', 'M01AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylbutazon und corticosteroide', 'M01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrin', 'R01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrin', 'R01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrin', 'S01FB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrin', 'R01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrin', 'S01GA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrin', 'C01CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrin, kombinationen', 'R01BA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylephrin, kombinationen', 'S01GA55');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylmercuriborat', 'D08AK02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylpiperidin-derivate', 'N02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylpropanolamin', 'R01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylpropanolamin, kombinationen', 'R01BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylquecksilbernitrat', 'D09AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenylsalicylat', 'G04BX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenytoin', 'N03AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('phenytoin, kombinationen', 'N03AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('phloroglucinol', 'A03AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('pholcodin', 'R05DA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('phosphodiesterasehemmer', 'C01CE');
INSERT INTO staging.atc (description, atc_code) VALUES ('phospholipid-mikrosphären', 'V08DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('phosphonsäure-derivate', 'J05AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('phthalylsulfathiazol', 'A07AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('physostigmin', 'S01EB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('physostigmin', 'V03AB19');
INSERT INTO staging.atc (description, atc_code) VALUES ('phytomenadion', 'B02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('picloxydin', 'S01AX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('picodralazin und diuretika', 'C02LG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('picodralazin und diuretika, kombinationen mit psycholeptika', 'C02LG73');
INSERT INTO staging.atc (description, atc_code) VALUES ('picotamid', 'B01AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pidotimod', 'L03AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pilocarpin', 'N07AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pilocarpin', 'S01EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pilocarpin, kombinationen', 'S01EB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('pimecrolimus', 'D11AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pimethixen', 'R06AX23');
INSERT INTO staging.atc (description, atc_code) VALUES ('pimozid', 'N05AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pinacidil', 'C02DG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pinacidil und diuretika', 'C02LX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pinaverium', 'A03AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pinazepam', 'N05BA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('pindolol', 'C07AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pindolol und andere diuretika', 'C07CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pioglitazon', 'A10BG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pioglitazon und alogliptin', 'A10BD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipamperon', 'N05AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipazetat', 'R05DB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipecuroniumbromid', 'M03AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipemidsäure', 'J01MB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipenzolat', 'A03AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperacillin', 'J01CA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperacillin und enzym-inhibitoren', 'J01CR05');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperazin', 'P02CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperazin und derivate', 'P02CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperazin-derivate', 'R06AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperidindion-derivate', 'N05CE');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperidion', 'R05DB23');
INSERT INTO staging.atc (description, atc_code) VALUES ('piperidolat', 'A03AA30');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipobroman', 'L01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipotiazin', 'N05AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pipradrol', 'N06BX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('piprozolin', 'A05AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('piracetam', 'N06BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pirarubicin', 'L01DB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pirbuterol', 'R03CC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('pirbuterol', 'R03AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pirenzepin', 'A02BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('piretanid', 'C03CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('piribedil', 'N04BC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pirisudanol', 'N06BX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('piritramid', 'N02AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('piromidsäure', 'J01MB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('piroxicam', 'S01BC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('piroxicam', 'M02AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('piroxicam', 'M01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pirprofen', 'M01AE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pitofenon und analgetika', 'A03DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pivagabin', 'N06AX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('pivampicillin', 'J01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pivmecillinam', 'J01CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pizotifen', 'N02CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('plastik-iup', 'G02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('plastik-iup mit kupfer', 'G02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('plastik-iup mit progesteron', 'G02BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('platin-haltige verbindungen', 'L01XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('pleconaril', 'J05AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('plicamycin', 'L01DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumokokken, gereinigtes polysaccharid-antigen', 'J07AL01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumokokken, gereinigtes polysaccharid-antigen, konjugiert', 'J07AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pneumokokken-impfstoffe', 'J07AL');
INSERT INTO staging.atc (description, atc_code) VALUES ('podophyllotoxin', 'D06BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('podophyllotoxin-derivate', 'L01CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('poldin', 'A03AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('policosanol', 'C10AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('policresulen', 'G01AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('policresulen', 'D08AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('polidocanol', 'C05BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('polihexanid', 'D08AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('poliomyelitis, oral, monovalent, lebend abgeschwächt', 'J07BF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('poliomyelitis, oral, trivalent, lebend abgeschwächt', 'J07BF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('poliomyelitis, trivalent, inaktiviert, ganzes virus', 'J07BF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('poliomyelitis-impfstoffe', 'J07BF');
INSERT INTO staging.atc (description, atc_code) VALUES ('poly i:c', 'L03AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('poly iclc', 'L03AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('polycarbophil-calcium', 'A06AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('polyestradiolphosphat', 'L02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('polymyxin b', 'J01XB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('polymyxin b', 'S01AA18');
INSERT INTO staging.atc (description, atc_code) VALUES ('polymyxin b', 'A07AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('polymyxin b', 'S02AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('polymyxin b', 'S03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('polymyxine', 'J01XB');
INSERT INTO staging.atc (description, atc_code) VALUES ('polynoxylin', 'D01AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('polynoxylin', 'A01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('polystyrolsulfonat', 'V03AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('polythiazid', 'C03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('polythiazid und kalium', 'C03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('porfimer natrium', 'L01XD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('posaconazol', 'J02AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidon-iod', 'D11AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidon-iod', 'G01AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidon-iod', 'D09AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidon-iod', 'S01AX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidon-iod', 'D08AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('povidon-iod', 'R02AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('practolol', 'C07AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prajmalin', 'C01BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pralatrexat', 'L01BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pralidoxim', 'V03AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('pramipexol', 'N04BC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pramiracetam', 'N06BX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('pramlintid', 'A10BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('pramocain', 'C05AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('pramocain', 'D04AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('pranlukast', 'R03DC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pranoprofen', 'S01BC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('prasteron', 'A14AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('prasteron und estrogen', 'G03EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pravastatin', 'C10AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pravastatin und acetylsalizylsäure', 'C10BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pravastatin und fenofibrat', 'C10BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prazepam', 'N05BA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('praziquantel', 'P02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prazosin', 'C02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prazosin und diuretika', 'C02LE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednicarbat', 'D07AC18');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednimustin', 'L01AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon', 'H02AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon', 'S01CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon', 'C05AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon', 'R01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon', 'D07AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon', 'A07EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon', 'S03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon', 'S02BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon', 'S01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon', 'D07XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon und antibiotika', 'D07CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon und antiinfektiva', 'S02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon und antiinfektiva', 'S01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon und antiinfektiva', 'S03CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon und antiseptika', 'D07BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon und mydriatika', 'S01BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon und promethazin', 'V03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon, kombinationen', 'R01AD52');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednisolon, kombinationen', 'A01AC54');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednison', 'H02AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednison', 'A07EA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prednyliden', 'H02AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('pregabalin', 'N03AX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('pregnadien-derivate', 'G03DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('pregnen-4-derivate', 'G03DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('prenalterol', 'C01CA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('prenoxdiazin', 'R05DB18');
INSERT INTO staging.atc (description, atc_code) VALUES ('prenylamin', 'C01DX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('prenylamin, kombinationen', 'C01DX52');
INSERT INTO staging.atc (description, atc_code) VALUES ('prethcamid', 'R07AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('pridinol', 'M03BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('prifiniumbromid', 'A03AB18');
INSERT INTO staging.atc (description, atc_code) VALUES ('prilocain', 'N01BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('prilocain, kombinationen', 'N01BB54');
INSERT INTO staging.atc (description, atc_code) VALUES ('primaquin', 'P01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('primidon', 'N03AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pristinamycin', 'J01FG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('probenecid', 'M04AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('probucol', 'C10AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('procain', 'N01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('procain', 'C05AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('procain', 'S01HA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('procain, kombinationen', 'N01BA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('procainamid', 'C01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('procarbazin', 'L01XB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('procaterol', 'R03AC16');
INSERT INTO staging.atc (description, atc_code) VALUES ('procaterol', 'R03CC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('prochlorperazin', 'N05AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('procyclidin', 'N04AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('profenamin', 'N04AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('progabid', 'N03AG05');
INSERT INTO staging.atc (description, atc_code) VALUES ('progesteron', 'G03DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('progesteron und estrogen', 'G03FA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('proglumetacin', 'M01AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('proglumid', 'A02BX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('proguanil', 'P01BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('proguanil, kombinationen', 'P01BB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('prokinetika', 'A03FA');
INSERT INTO staging.atc (description, atc_code) VALUES ('prokinetika', 'A03F');
INSERT INTO staging.atc (description, atc_code) VALUES ('prolactinhemmer', 'G02CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('prolintan', 'N06BX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('promazin', 'N05AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('promegeston', 'G03DB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('promestrien', 'G03CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('promethazin', 'R06AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('promethazin', 'D04AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('promethazin, kombinationen', 'R06AD52');
INSERT INTO staging.atc (description, atc_code) VALUES ('propacetamol', 'N02BE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propafenon', 'C01BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('propamidin', 'D08AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('propamidin', 'S01AX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('propanidid', 'N01AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('propanol', 'D08AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('propanol, kombinationen', 'D08AX53');
INSERT INTO staging.atc (description, atc_code) VALUES ('propanthelin', 'A03AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propanthelin und psycholeptika', 'A03CA34');
INSERT INTO staging.atc (description, atc_code) VALUES ('propatylnitrat', 'C01DA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('propatylnitrat, kombinationen', 'C01DA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('propenidazol', 'G01AF14');
INSERT INTO staging.atc (description, atc_code) VALUES ('propenidazol', 'P01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propentofyllin', 'N06BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('propicillin', 'J01CE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('propiomazin', 'N05CM06');
INSERT INTO staging.atc (description, atc_code) VALUES ('propionsäure-derivate', 'M01AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('propiverin', 'G04BD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('propofol', 'N01AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('propranolol', 'C07AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propranolol und andere antihypertonika', 'C07FA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propranolol und thiazide', 'C07BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('propyliodon', 'V08AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('propylthiouracil', 'H03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('propyphenazon', 'N02BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('propyphenazon, kombinationen exkl. psycholeptika*', 'N02BB54');
INSERT INTO staging.atc (description, atc_code) VALUES ('propyphenazon, kombinationen mit psycholeptika', 'N02BB74');
INSERT INTO staging.atc (description, atc_code) VALUES ('proquazon', 'M01AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('proscillaridin', 'C01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('proscillaridin, kombinationen', 'C01AB51');
INSERT INTO staging.atc (description, atc_code) VALUES ('prostaglandin-analoga', 'S01EE');
INSERT INTO staging.atc (description, atc_code) VALUES ('prostaglandine', 'G02AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('prostaglandine', 'C01EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('prostaglandine', 'A02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('protamin', 'V03AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('proteasehemmer', 'J05AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('protein c', 'B01AD12');
INSERT INTO staging.atc (description, atc_code) VALUES ('proteinasehemmer', 'B02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('proteinhydrolysate', 'B05BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('proteinkinase-inhibitoren', 'L01XE');
INSERT INTO staging.atc (description, atc_code) VALUES ('proteinzusatznahrung', 'V06B');
INSERT INTO staging.atc (description, atc_code) VALUES ('protektiva gegen uv-strahlung', 'D02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('protektiva gegen uv-strahlung zur systemischen anwendung', 'D02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('protektiva gegen uv-strahlung zur topischen anwendung', 'D02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('proteolytische enzyme', 'D03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('prothipendyl', 'N05AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('protiofat', 'G01AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('protionamid', 'J04AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('protirelin', 'V04CJ02');
INSERT INTO staging.atc (description, atc_code) VALUES ('protonenpumpenhemmer', 'A02BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('protriptylin', 'N06AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('proxazol', 'A03AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('proxibarbal', 'N05CA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('proxymetacain', 'S01HA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('proxyphyllin', 'R03DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('proxyphyllin und sympathomimetika', 'R03DB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pseudoephedrin', 'R01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pseudoephedrin, kombinationen', 'R01BA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('psoralene zur systemischen anwendung', 'D05BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('psoralene zur topischen anwendung', 'D05AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('psychoanaleptika', 'N06');
INSERT INTO staging.atc (description, atc_code) VALUES ('psycholeptika', 'N05');
INSERT INTO staging.atc (description, atc_code) VALUES ('psycholeptika und psychoanaleptika in kombination', 'N06C');
INSERT INTO staging.atc (description, atc_code) VALUES ('psychostimulanzien in kombination mit psycholeptika', 'N06CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('psychostimulanzien, mittel für die adhd und nootropika', 'N06B');
INSERT INTO staging.atc (description, atc_code) VALUES ('purin-analoga', 'L01BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('purin-derivate', 'C04AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('pygeum africanum', 'G04CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrantel', 'P02CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrazinamid', 'J04AK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrazolon-derivate', 'C03CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrazolone', 'N02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrethrine', 'P03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrethrine, inkl. synthetische verbindungen', 'P03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrethrum', 'P03AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrethrum, kombinationen', 'P03AC51');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyridostigmin', 'N07AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyridoxalphosphat', 'A11HA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyridoxin (vitamin b6)', 'A11HA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrimethamin', 'P01BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrimethamin, kombinationen', 'P01BD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrimidin-analoga', 'L01BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrimidin-derivate', 'C02DC');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrithion zink', 'D11AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrithyldion', 'N05CE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyritinol', 'N06BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrrobutamin', 'R06AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrrobutamin, kombinationen', 'R06AX58');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrrolnitrin', 'D01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('pyrvinium', 'P02CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('quartäre ammonium-verbindungen', 'D08AJ');
INSERT INTO staging.atc (description, atc_code) VALUES ('quassia', 'P03AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('quazepam', 'N05CD10');
INSERT INTO staging.atc (description, atc_code) VALUES ('quecksilber-haltige diuretika', 'C03BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('quecksilber-haltige mittel', 'D08AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('quecksilber-haltige verbindungen', 'S01AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('quecksilberamidochlorid', 'D08AK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('quecksilberchlorid', 'D08AK03');
INSERT INTO staging.atc (description, atc_code) VALUES ('quecksilberiodid', 'D08AK30');
INSERT INTO staging.atc (description, atc_code) VALUES ('quellmittel', 'A06AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('quetiapin', 'N05AH04');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinagolid', 'G02CB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinapril', 'C09AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinapril und diuretika', 'C09BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinbolon', 'A14AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinethazon', 'C03BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinethazon und kalium', 'C03BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('quingestanol', 'G03AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('quingestanol und estrogen', 'G03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinupramin', 'N06AA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('quinupristin/dalfopristin', 'J01FG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rabeprazol', 'A02BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('racecadotril', 'A07XA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('radiodiagnostika', 'V09');
INSERT INTO staging.atc (description, atc_code) VALUES ('radiotherapeutika', 'V10');
INSERT INTO staging.atc (description, atc_code) VALUES ('raloxifen', 'G03XC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('raltegravir', 'J05AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('raltitrexed', 'L01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ramelteon', 'N05CH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ramipril', 'C09AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ramipril und diuretika', 'C09BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ramipril und felodipin', 'C09BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ranibizumab', 'S01LA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ranimustin', 'L01AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ranitidin', 'A02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ranitidinbismutcitrat', 'A02BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ranolazin', 'C01EB18');
INSERT INTO staging.atc (description, atc_code) VALUES ('rasagilin', 'N04BD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rasburicase', 'V03AF07');
INSERT INTO staging.atc (description, atc_code) VALUES ('rauwolfia-alkaloide', 'C02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('rauwolfia-alkaloide und diuretika in kombination', 'C02LA');
INSERT INTO staging.atc (description, atc_code) VALUES ('rauwolfia-alkaloide, ganze wurzel', 'C02AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('rauwolfia-alkaloide, ganze wurzel und diuretika', 'C02LA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('reboxetin', 'N06AX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('remifentanil', 'N01AH06');
INSERT INTO staging.atc (description, atc_code) VALUES ('remikiren', 'C09XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('remoxiprid', 'N05AL04');
INSERT INTO staging.atc (description, atc_code) VALUES ('renin-inhibitoren', 'C09XA');
INSERT INTO staging.atc (description, atc_code) VALUES ('repaglinid', 'A10BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('reposal', 'N05CA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('reproterol', 'R03CC14');
INSERT INTO staging.atc (description, atc_code) VALUES ('reproterol', 'R03AC15');
INSERT INTO staging.atc (description, atc_code) VALUES ('reproterol und andere mittel bei obstruktiven atemwegserkrankungen', 'R03AK05');
INSERT INTO staging.atc (description, atc_code) VALUES ('rescinnamin', 'C02AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('rescinnamin und diuretika', 'C02LA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rescinnamin und diuretika, kombinationen mit anderen mitteln', 'C02LA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('reserpin', 'C02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('reserpin und diuretika', 'C02LA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('reserpin und diuretika, kombinationen mit anderen mitteln', 'C02LA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('reserpin und diuretika, kombinationen mit psycholeptika', 'C02LA71');
INSERT INTO staging.atc (description, atc_code) VALUES ('reserpin, kombinationen', 'C02AA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('resorcin', 'S01AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('resorcin', 'D10AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('respirationstrakt', 'V09E');
INSERT INTO staging.atc (description, atc_code) VALUES ('respirationstrakt', 'R');
INSERT INTO staging.atc (description, atc_code) VALUES ('reteplase', 'B01AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinoide zur behandlung der akne', 'D10BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinoide zur behandlung der psoriasis', 'D05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinoide zur topischen anwendung bei akne', 'D10AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinol', 'D10AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinol', 'R01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinol', 'S01XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('retinol (vitamin a)', 'A11CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('reviparin', 'B01AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('rhinologika', 'R01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ribavarin, kombinationen', 'L03AB60');
INSERT INTO staging.atc (description, atc_code) VALUES ('ribavirin', 'J05AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('riboflavin (vitamin b2)', 'A11HA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ribostamycin', 'J01GB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifabutin', 'J04AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifampicin', 'J04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifampicin und isoniazid', 'J04AM02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifampicin, pyrazinamid und isoniazid', 'J04AM05');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifampicin, pyrazinamid, ethambutol und isoniazid', 'J04AM06');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifamycin', 'J04AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifamycin', 'S01AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifamycin', 'S02AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifapentin', 'J04AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifaximin', 'A07AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('rifaximin', 'D06AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('rilmenidin', 'C02AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('rilonacept', 'L04AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('riluzol', 'N07XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rimantadin', 'J05AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rimazolium', 'N02BG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rimexolon', 'H02AB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('rimexolon', 'S01BA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('rimiterol', 'R03AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('risedronsäure', 'M05BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('risperidon', 'N05AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ritiometan', 'R01AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('ritodrin', 'G02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ritonavir', 'J05AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('rituximab', 'L01XC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rivaroxaban', 'B01AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('rivastigmin', 'N06DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('rizatriptan', 'N02CC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('rizinusöl', 'A06AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('rociverin', 'A03AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('rocuroniumbromid', 'M03AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('rofecoxib', 'M01AH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rokitamycin', 'J01FA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('rolitetracyclin', 'J01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('romidepsin', 'L01XX39');
INSERT INTO staging.atc (description, atc_code) VALUES ('romiplostim', 'B02BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ronifibrat', 'C10AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('ropinirol', 'N04BC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('ropivacain', 'N01BB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('roquinimex', 'L03AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rosiglitazon', 'A10BG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('rosoxacin', 'J01MB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('rosuvastatin', 'C10AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('rotavirus, lebend abgeschwächt', 'J07BH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('rotavirus-diarrhoe-impfstoffe', 'J07BH');
INSERT INTO staging.atc (description, atc_code) VALUES ('roxatidin', 'A02BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('roxithromycin', 'J01FA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('rufloxacin', 'J01MA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('rupatadin', 'R06AX28');
INSERT INTO staging.atc (description, atc_code) VALUES ('rutosid, kombinationen', 'C05CA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('rutoside', 'C05CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('röntgenkontrastmittel, iod-haltig', 'V08A');
INSERT INTO staging.atc (description, atc_code) VALUES ('röntgenkontrastmittel, nicht iod-haltig', 'V08B');
INSERT INTO staging.atc (description, atc_code) VALUES ('röteln, kombinationen mit mumps, lebend abgeschwächt', 'J07BJ51');
INSERT INTO staging.atc (description, atc_code) VALUES ('röteln, lebend abgeschwächt', 'J07BJ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('röteln-immunglobulin', 'J06BB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('röteln-impfstoffe', 'J07BJ');
INSERT INTO staging.atc (description, atc_code) VALUES ('s-atenolol', 'C07AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('saccharomyces boulardii', 'A07FA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sacrosidase', 'A16AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('salbutamol', 'R03CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('salbutamol', 'R03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('salbutamol und andere mittel bei obstruktiven atemwegserkrankungen', 'R03AK04');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylamid', 'N02BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylamid, kombinationen exkl. psycholeptika', 'N02BA55');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylamid, kombinationen mit psycholeptika', 'N02BA75');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylate', 'S02DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylsäure', 'S01BC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylsäure', 'D01AE12');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylsäure und derivate', 'N02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylsäure-derivate', 'P02DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('salicylsäure-haltige zubereitungen', 'D02AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('salmeterol', 'R03AC12');
INSERT INTO staging.atc (description, atc_code) VALUES ('salmeterol und andere mittel bei obstruktiven atemwegserkrankungen', 'R03AK06');
INSERT INTO staging.atc (description, atc_code) VALUES ('salsalat', 'N02BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('salzlösungen', 'B05CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('salzsäure', 'B05XA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('salzsäure', 'A09AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sapropterin', 'A16AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('saquinavir', 'J05AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sargramostim', 'L03AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('saruplase', 'B01AD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('satraplatin', 'L01XA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sauerstoff', 'V03AN01');
INSERT INTO staging.atc (description, atc_code) VALUES ('saxagliptin', 'A10BH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('schilddrüse', 'V09F');
INSERT INTO staging.atc (description, atc_code) VALUES ('schilddrüsenfunktions-tests', 'V04CJ');
INSERT INTO staging.atc (description, atc_code) VALUES ('schilddrüsenhormone', 'H03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('schilddrüsenpräparate', 'H03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('schilddrüsentherapie', 'H03');
INSERT INTO staging.atc (description, atc_code) VALUES ('schimmel- und hefepilze', 'V01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('schlangengift-antiserum', 'J06AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('schmerzlinderung (knochenmetastasen)', 'V10B');
INSERT INTO staging.atc (description, atc_code) VALUES ('schwefel', 'D10AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('schwefel-haltige imidazol-derivate', 'H03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('schwefel-haltige mittel', 'D10AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('schwefel-haltige mittel', 'P03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('schwefel-haltige verbindungen', 'D11AC08');
INSERT INTO staging.atc (description, atc_code) VALUES ('schwefelhexafluorid', 'V08DA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('scillaglykoside', 'C01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('scopolamin', 'A04AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('scopolamin', 'S01FA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('scopolamin', 'N05CM05');
INSERT INTO staging.atc (description, atc_code) VALUES ('scopolamin, kombinationen', 'A04AD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('secnidazol', 'P01AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('secobarbital', 'N05CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sekretin', 'V04CK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sekundäre und tertiäre amine', 'C02BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('selegilin', 'N04BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('selektive beta2-adrenorezeptor-agonisten', 'R03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('selektive beta2-adrenorezeptor-agonisten', 'R03CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('selektive calciumkanalblocker mit vorwiegender gefässwirkung', 'C08C');
INSERT INTO staging.atc (description, atc_code) VALUES ('selektive calciumkanalblocker mit vorwiegender herzwirkung', 'C08D');
INSERT INTO staging.atc (description, atc_code) VALUES ('selektive estrogenrezeptor-modulatoren', 'G03XC');
INSERT INTO staging.atc (description, atc_code) VALUES ('selektive immunsuppressiva', 'L04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('selektive serotonin-5ht1-agonisten', 'N02CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('selektive serotonin-wiederaufnahmehemmer', 'N06AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('selen', 'A12CE');
INSERT INTO staging.atc (description, atc_code) VALUES ('selen-haltige verbindungen', 'D11AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('selendisulfid', 'D01AE13');
INSERT INTO staging.atc (description, atc_code) VALUES ('semustin', 'L01AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('senega', 'R05CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sennoside', 'A06AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sennoside, kombinationen', 'A06AB56');
INSERT INTO staging.atc (description, atc_code) VALUES ('sensibilisatoren für die photodynamische/radio-therapie', 'L01XD');
INSERT INTO staging.atc (description, atc_code) VALUES ('sensitivitäts-tests, plättchen und tabletten', 'V07AR');
INSERT INTO staging.atc (description, atc_code) VALUES ('seratrodast', 'R03DX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('serenoa repens', 'G04CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sermorelin', 'H01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sermorelin', 'V04CD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('serotonin-5ht3-antagonisten', 'A04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('serotonin-antagonisten', 'C02KD');
INSERT INTO staging.atc (description, atc_code) VALUES ('serotonin-antagonisten und diuretika', 'C02LN');
INSERT INTO staging.atc (description, atc_code) VALUES ('sertaconazol', 'D01AC14');
INSERT INTO staging.atc (description, atc_code) VALUES ('sertindol', 'N05AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sertralin', 'N06AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('serumgonadotrophin', 'G03GA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sevelamer', 'V03AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sevofluran', 'N01AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sexualhormone und modulatoren des genitalsystems', 'G03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sibutramin', 'A08AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('silber', 'D08AL30');
INSERT INTO staging.atc (description, atc_code) VALUES ('silber-haltige verbindungen', 'D08AL');
INSERT INTO staging.atc (description, atc_code) VALUES ('silber-haltige verbindungen', 'S01AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('silbernitrat', 'D08AL01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sildenafil', 'G04BE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('silikon-haltige mittel', 'D02AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('silikone', 'A03AX13');
INSERT INTO staging.atc (description, atc_code) VALUES ('silodosin', 'G04CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('silymarin', 'A05BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('simfibrat', 'C10AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('simvastatin', 'C10AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('simvastatin und acetylsalizylsäure', 'C10BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('simvastatin und ezetimid', 'C10BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sincalid', 'V04CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sinnesorgane', 'S');
INSERT INTO staging.atc (description, atc_code) VALUES ('sirolimus', 'L04AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('sisomicin', 'J01GB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sitagliptin', 'A10BH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sitimagen ceradenovec', 'L01XX37');
INSERT INTO staging.atc (description, atc_code) VALUES ('skelett', 'V09B');
INSERT INTO staging.atc (description, atc_code) VALUES ('sklerosierende mittel zur lokalen injektion', 'C05BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sobrerol', 'R05CB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('solifenacin', 'G04BD08');
INSERT INTO staging.atc (description, atc_code) VALUES ('somatorelin', 'V04CD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('somatostatin', 'H01CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('somatrem', 'H01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('somatropin', 'H01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('somatropin und somatropin-agonisten', 'H01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('sonstige mittel für das alimentäre system und den stoffwechsel', 'A16AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('sorafenib', 'L01XE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sorbitol', 'V04CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sorbitol', 'B05CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sorbitol', 'A06AD18');
INSERT INTO staging.atc (description, atc_code) VALUES ('sorbitol', 'A06AG07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sotalol', 'C07AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sotalol und thiazide', 'C07BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sotalol, kombinationspackungen', 'C07AA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('spagluminsäure', 'S01GX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('spagluminsäure', 'R01AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sparfloxacin', 'J01MA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('spartein', 'C01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('spasmolytika in kombination mit analgetika', 'A03D');
INSERT INTO staging.atc (description, atc_code) VALUES ('spasmolytika in kombination mit anderen mitteln', 'A03ED');
INSERT INTO staging.atc (description, atc_code) VALUES ('spasmolytika in kombination mit psycholeptika', 'A03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('spasmolytika und anticholinergika in kombination mit anderen mitteln', 'A03E');
INSERT INTO staging.atc (description, atc_code) VALUES ('spasmolytika, psycholeptika und analgetika in kombination', 'A03EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('spectinomycin', 'J01XX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('spezifische antirheumatika', 'M01C');
INSERT INTO staging.atc (description, atc_code) VALUES ('spezifische immunglobuline', 'J06BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('spiramycin', 'J01FA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('spirapril', 'C09AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('spironolacton', 'C03DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('spüllösungen', 'B05C');
INSERT INTO staging.atc (description, atc_code) VALUES ('stammzellen aus nabelschnurblut', 'B05AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('stanozolol', 'A14AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('staphylococcus-immunglobulin', 'J06BB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('stavudin', 'J05AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('stavudin, lamivudin und neviparin', 'J05AR07');
INSERT INTO staging.atc (description, atc_code) VALUES ('stechapfel-haltige zubereitungen', 'R03BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('stepronin', 'R05CB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('sterculia', 'A06AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sterculia, kombinationen', 'A06AC53');
INSERT INTO staging.atc (description, atc_code) VALUES ('steroid-antibiotika', 'J01XC');
INSERT INTO staging.atc (description, atc_code) VALUES ('stibophen', 'P02BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('stickoxid', 'R07AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('stickstoff', 'V03AN04');
INSERT INTO staging.atc (description, atc_code) VALUES ('stickstofflost-analoga', 'L01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('stiripentol', 'N03AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('stoma-artikel', 'V07AS');
INSERT INTO staging.atc (description, atc_code) VALUES ('stomatologika', 'A01');
INSERT INTO staging.atc (description, atc_code) VALUES ('stomatologika', 'A01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptoduocin', 'J01GA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptogramine', 'J01FG');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptokinase', 'B01AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptokinase, kombinationen', 'B06AA55');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptomycin', 'J01GA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptomycin', 'A07AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptomycin und isoniazid', 'J04AM01');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptomycin, kombinationen', 'A07AA54');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptomycine', 'J01GA');
INSERT INTO staging.atc (description, atc_code) VALUES ('streptozocin', 'L01AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('strontium ranelat', 'M05BX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('strophanthusglykoside', 'C01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('styramat', 'M03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('substituierte alkylamine', 'R06AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('substituierte ethylendiamine', 'R06AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('succinimid', 'G04BX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('succinimid-derivate', 'N03AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('succinylsulfathiazol', 'A07AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sucralfat', 'A02BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sufentanil', 'N01AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulbactam', 'J01CG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulbenicillin', 'J01CA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulbentin', 'D01AE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulbutiamin', 'A11DA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulconazol', 'D01AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfacetamid', 'S01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadiazin', 'J01EC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadiazin und tetroxoprim', 'J01EE06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadiazin und trimethoprim', 'J01EE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadiazin-silber', 'D06BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadiazin-silber, kombinationen', 'D06BA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadicramid', 'S01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadimethoxin', 'J01ED01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadimidin', 'J01EB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfadimidin und trimethoprim', 'J01EE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfafenazol', 'S01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfafurazol', 'J01EB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfafurazol', 'S01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfaguanidin', 'A07AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfaisodimidin', 'J01EB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfalen', 'J01ED02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamazon', 'J01ED09');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamerazin', 'J01ED07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethizol', 'D06BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethizol', 'J01EB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethizol', 'S01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethizol', 'B05CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethoxazol', 'J01EC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethoxazol und trimethoprim', 'J01EE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamethoxypyridazin', 'J01ED05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfametomidin', 'J01ED03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfametoxydiazin', 'J01ED04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfametrol und trimethoprim', 'J01EE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamoxol', 'J01EC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfamoxol und trimethoprim', 'J01EE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfanilamid', 'J01EB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfaperin', 'J01ED06');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfaphenazol', 'J01ED08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfapyridin', 'J01EB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfasalazin', 'A07EC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfathiazol', 'D06BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfathiazol', 'J01EB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfathiourea', 'J01EB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfatolamid', 'G01AE01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfinpyrazon', 'M04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide', 'S01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide', 'A07AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide', 'D06BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide', 'G01AE');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide (heterozyklisch)', 'A10BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide und corticosteroide', 'G01BE');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide und kalium in kombination', 'C03CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide und kalium in kombination', 'C03BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide und trimethoprim', 'J01E');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide, kombination mit anderen antibiotika (exkl. trimethoprim)', 'J01RA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide, kombinationen mit anderen mitteln', 'C03BK');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide, rein', 'C03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonamide, rein', 'C03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonium-derivate', 'C02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulfonylharnstoff-derivate', 'A10BB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulglicotid', 'A02BX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulindac', 'M01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('suloctidil', 'C04AX19');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulodexid', 'B01AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulpirid', 'N05AL01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sulproston', 'G02AD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('sultamicillin', 'J01CR04');
INSERT INTO staging.atc (description, atc_code) VALUES ('sultiam', 'N03AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('sultoprid', 'N05AL02');
INSERT INTO staging.atc (description, atc_code) VALUES ('sumatriptan', 'N02CC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('sunitinib', 'L01XE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('superparamagnetische kontrastmittel', 'V08CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('suprofen', 'M01AE07');
INSERT INTO staging.atc (description, atc_code) VALUES ('suramin natrium', 'P01CX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('surfactant-präparate', 'R07AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('suxamethonium', 'M03AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('suxibuzon', 'M02AA22');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetika', 'R01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetika als dekongestiva', 'S01GA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetika in der glaukomtherapie', 'S01EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetika und andere mittel bei obstruktiven atemwegserkrankungen', 'R03AK');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetika und andere mittel bei obstruktiven atemwegserkrankungen', 'R03CK');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetika zur systemischen anwendung', 'R03C');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetika, exkl. glaukommittel', 'S01FB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetika, kombinationen exkl. corticosteroide', 'R01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetika, rein', 'R01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('sympathomimetika, wehen hemmend', 'G02CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('synthetische anticholinergika in kombination mit analgetika', 'A03DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('synthetische anticholinergika in kombination mit psycholeptika', 'A03CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('synthetische anticholinergika, ester mit tertiären aminogruppen', 'A03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('synthetische anticholinergika, quartäre ammonium-verbindungen', 'A03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('synthetische estrogene, rein', 'G03CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('synthetische spasmolytika, amide mit tertiären aminen', 'A03AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('syrosingopin und diuretika', 'C02LA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('systemische hormonpräparate, exkl. sexualhormone und insuline', 'H');
INSERT INTO staging.atc (description, atc_code) VALUES ('säuglingsnahrung', 'V06C');
INSERT INTO staging.atc (description, atc_code) VALUES ('säure-haltige zubereitungen', 'A09AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('tacalcitol', 'D05AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tacrin', 'N06DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tacrolimus', 'L04AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tacrolimus', 'D11AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tadalafil', 'G04BE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('talampicillin', 'J01CA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('talastin', 'R06AB07');
INSERT INTO staging.atc (description, atc_code) VALUES ('talbutal', 'N05CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('talinolol', 'C07AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('tamoxifen', 'L02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tamsulosin', 'G04CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tamsulosin und dutasterid', 'G04CA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('tapentadol', 'N02AX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tasonermin', 'L03AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tasosartan', 'C09CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('taurolidin', 'B05CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('taxane', 'L01CD');
INSERT INTO staging.atc (description, atc_code) VALUES ('tazaroten', 'D05AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tazobactam', 'J01CG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('technische desinfektionsmittel', 'V07AV');
INSERT INTO staging.atc (description, atc_code) VALUES ('teclosan', 'P01AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tedisamil', 'C01BD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('teere', 'D05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('tegafur', 'L01BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tegafur, kombinationen', 'L01BC53');
INSERT INTO staging.atc (description, atc_code) VALUES ('tegaserod', 'A03AE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('teicoplanin', 'J01XA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('telbivudin', 'J05AF11');
INSERT INTO staging.atc (description, atc_code) VALUES ('telithromycin', 'J01FA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('telmisartan', 'C09CA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('telmisartan und amlodipin', 'C09DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('telmisartan und diuretika', 'C09DA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('temafloxacin', 'J01MA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('temazepam', 'N05CD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('temocapril', 'C09AA14');
INSERT INTO staging.atc (description, atc_code) VALUES ('temocillin', 'J01CA17');
INSERT INTO staging.atc (description, atc_code) VALUES ('temoporfin', 'L01XD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('temozolomid', 'L01AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('temsirolimus', 'L01XE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('tenecteplase', 'B01AD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tenidap', 'M01AX23');
INSERT INTO staging.atc (description, atc_code) VALUES ('teniposid', 'L01CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tenitramin', 'C01DA38');
INSERT INTO staging.atc (description, atc_code) VALUES ('tenofovir disoproxil', 'J05AF07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tenonitrozol', 'P01AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tenoxicam', 'M01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('terazosin', 'G04CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbinafin', 'D01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbinafin', 'D01AE15');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbutalin', 'R03CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbutalin', 'R03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('terbutalin, kombinationen', 'R03CC53');
INSERT INTO staging.atc (description, atc_code) VALUES ('terconazol', 'G01AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('terfenadin', 'R06AX12');
INSERT INTO staging.atc (description, atc_code) VALUES ('teriparatid', 'H05AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('terizidon', 'J04AK03');
INSERT INTO staging.atc (description, atc_code) VALUES ('terlipressin', 'H01BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('terodilin', 'G04BD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tertatolol', 'C07AA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('tertiäre amine', 'N04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('testosteron', 'G03BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('testosteron und estrogen', 'G03EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('testosteron-5-alpha-reduktasehemmer', 'G04CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus-antitoxin', 'J06AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus-immunglobulin', 'J06BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus-impfstoffe', 'J07AM');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus-toxoid', 'J07AM01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus-toxoid, kombinationen mit diphtherie-toxoid', 'J07AM51');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetanus-toxoid, kombinationen mit tetanus-immunglobulin', 'J07AM52');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetrabenazin', 'N07XX06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracain', 'N01BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracain', 'S01HA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracain', 'D04AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracain', 'C05AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracosactid', 'H01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracyclin', 'S03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracyclin', 'D06AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracyclin', 'S02AA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracyclin', 'J01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracyclin', 'A01AB13');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracyclin', 'S01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracyclin und derivate', 'D06AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracycline', 'J01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetracycline', 'J01A');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetragalacturonsäurehydroxymethylester', 'B02BC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetrahydropyrimidin-derivate', 'P02CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetramethrin', 'P03BA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetrazepam', 'M03BX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetryzolin', 'S01GA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetryzolin', 'R01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetryzolin', 'R01AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tetryzolin, kombinationen', 'S01GA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('textilien', 'V01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('thalidomid', 'L04AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('thebacon', 'R05DA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('thenalidin', 'D04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('thenalidin', 'R06AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('thenalidin, kombinationen', 'R06AX53');
INSERT INTO staging.atc (description, atc_code) VALUES ('theobromin', 'C03BD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('theobromin', 'R03DA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('theobromin, kombinationen', 'R03DA57');
INSERT INTO staging.atc (description, atc_code) VALUES ('theodrenalin', 'C01CA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('theophyllin', 'R03DA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('theophyllin', 'C01EB21');
INSERT INTO staging.atc (description, atc_code) VALUES ('theophyllin und sympathomimetika', 'R03DB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('theophyllin, kombinationen exkl. psycholeptika', 'R03DA54');
INSERT INTO staging.atc (description, atc_code) VALUES ('theophyllin, kombinationen mit psycholeptika', 'R03DA74');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiamazol', 'H03BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiamazol, kombinationen', 'H03BB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiamin (vitamin b1)', 'A11DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiamphenicol', 'J01BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiamphenicol, kombinationen', 'J01BA52');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazid-derivate', 'C02DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazide und kalium in kombination', 'C03AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazide, kombinationen mit anderen mitteln', 'C03AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazide, kombinationen mit psycholeptika und/oder analgetika', 'C03AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazide, rein', 'C03AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazinam', 'R06AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiazolidindione', 'A10BG');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiethylperazin', 'R06AD03');
INSERT INTO staging.atc (description, atc_code) VALUES ('thioacetazon und isoniazid', 'J04AM04');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiocarbamid-derivate', 'J04AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiocolchicosid', 'M03BX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiomersal', 'D08AK06');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiopental', 'N05CA19');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiopental', 'N01AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiopropazat', 'N05AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('thioproperazin', 'N05AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('thioridazin', 'N05AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiosemicarbazone', 'J05AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiosulfat', 'V03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiotepa', 'L01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiouracile', 'H03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('thioxanthen-derivate', 'N05AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('thiram', 'P03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('thonzylamin', 'R06AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('thonzylamin', 'R01AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('thonzylamin', 'D04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('thrombin', 'B02BD30');
INSERT INTO staging.atc (description, atc_code) VALUES ('thrombin', 'B02BC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('thrombozyten', 'B05AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('thrombozytenaggregationshemmer, exkl. heparin', 'B01AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('thymopentin', 'L03AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyreostatika', 'H03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyrotropin', 'V04CJ01');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyrotropin', 'H01AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('thyrotropin', 'H01AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiabendazol', 'D01AC06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiabendazol', 'P02CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiadenol', 'C10AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiagabin', 'N03AG06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tianeptin', 'N06AX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiaprid', 'N05AL03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiaprofensäure', 'M01AE11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiazofurin', 'L01XX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('tibezoniumiodid', 'A01AB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('tibolon', 'G03CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('ticarcillin', 'J01CA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('ticarcillin und enzym-inhibitoren', 'J01CR03');
INSERT INTO staging.atc (description, atc_code) VALUES ('ticlaton', 'D01AE08');
INSERT INTO staging.atc (description, atc_code) VALUES ('ticlopidin', 'B01AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tidiacicarginin', 'A05BA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiemoniumiodid', 'A03AB17');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiemoniumiodid und analgetika', 'A03DA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tienilinsäure', 'C03CC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiere', 'V01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tigecyclin', 'J01AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('tilactase', 'A09AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tilbroquinol', 'P01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tilidin', 'N02AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiludronsäure', 'M05BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('timepidiumbromid', 'A03AB19');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol', 'S01ED01');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol', 'C07AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol und thiazide', 'C07BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol, kombinationen', 'S01ED51');
INSERT INTO staging.atc (description, atc_code) VALUES ('timolol, thiazide und andere diuretika', 'C07DA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tinidazol', 'J01XD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tinidazol', 'P01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tinzaparin', 'B01AB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiocarlid', 'J04AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tioclomarol', 'B01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tioconazol', 'D01AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tioconazol', 'G01AF08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tioguanin', 'L01BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiopronin', 'R05CB12');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiotixen', 'N05AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiotropiumbromid', 'R03BB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tioxolon', 'D10AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tipepidin', 'R05DB24');
INSERT INTO staging.atc (description, atc_code) VALUES ('tipranavir', 'J05AE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiracizin', 'C01EB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiratricol', 'D11AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiratricol', 'H03AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tirilazad', 'N07XX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tirofiban', 'B01AC17');
INSERT INTO staging.atc (description, atc_code) VALUES ('tiropramid', 'A03AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tisopurin', 'M04AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tixocortol', 'A07EA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tixocortol', 'R01AD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tixocortol, kombinationen', 'R01AD57');
INSERT INTO staging.atc (description, atc_code) VALUES ('tizanidin', 'M03BC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tizanidin', 'M03BX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tobramycin', 'J01GB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tobramycin', 'S01AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('tocainid', 'C01BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tocilizumab', 'L04AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tocopherol (vitamin e)', 'A11HA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tofisopam', 'N05BA23');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolazamid', 'A10BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolazolin', 'M02AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolazolin', 'C04AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolbutamid', 'A10BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolbutamid', 'V04CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolcapon', 'N04BX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolciclat', 'D01AE19');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolfenaminsäure', 'M01AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tollwut, inaktiviert, ganzes virus', 'J07BG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tollwut-immunglobulin', 'J06BB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tollwut-impfstoffe', 'J07BG');
INSERT INTO staging.atc (description, atc_code) VALUES ('tollwut-serum', 'J06AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolmetin', 'M02AA21');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolmetin', 'M01AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolnaftat', 'D01AE18');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolonidin', 'C02AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('toloxaton', 'N06AG03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolperison', 'M03BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolpropamin', 'D04AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolrestat', 'A10XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tolterodin', 'G04BD07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tonika', 'A13');
INSERT INTO staging.atc (description, atc_code) VALUES ('tonika', 'A13A');
INSERT INTO staging.atc (description, atc_code) VALUES ('topiramat', 'N03AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('topische mittel gegen gelenk- und muskelschmerzen', 'M02');
INSERT INTO staging.atc (description, atc_code) VALUES ('topische mittel gegen gelenk- und muskelschmerzen', 'M02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('topotecan', 'L01XX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('torasemid', 'C03CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('toremifen', 'L02BA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tositumomab/[131i]iod-tositumomab', 'V10XA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('tosylchloramid-natrium', 'D08AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('trabectedin', 'L01CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tramadol', 'N02AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tramadol, kombinationen', 'N02AX52');
INSERT INTO staging.atc (description, atc_code) VALUES ('tramazolin', 'R01AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('trandolapril', 'C09AA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('trandolapril und verapamil', 'C09BB10');
INSERT INTO staging.atc (description, atc_code) VALUES ('tranexamsäure', 'B02AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tranylcypromin', 'N06AF04');
INSERT INTO staging.atc (description, atc_code) VALUES ('trapidil', 'C01DX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('trastuzumab', 'L01XC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('travoprost', 'S01EE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('trazodon', 'N06AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('trematodenmittel', 'P02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('treosulfan', 'L01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('trepibuton', 'A03AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('treprostinil', 'B01AC21');
INSERT INTO staging.atc (description, atc_code) VALUES ('tretinoin', 'L01XX14');
INSERT INTO staging.atc (description, atc_code) VALUES ('tretinoin', 'D10AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tretinoin, kombinationen', 'D10AD51');
INSERT INTO staging.atc (description, atc_code) VALUES ('tretoquinol', 'R03CC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('tretoquinol', 'R03AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolon', 'A01AC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolon', 'D07AB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolon', 'R03BA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolon', 'D07XB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolon', 'R01AD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolon', 'S01BA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolon', 'H02AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolon und antibiotika', 'D07CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolon und antiinfektiva', 'S02CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamcinolon und antiseptika', 'D07BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('triamteren', 'C03DB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('triaziquon', 'L01AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('triazol-derivate', 'J02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('triazol-derivate', 'G01AG');
INSERT INTO staging.atc (description, atc_code) VALUES ('triazolam', 'N05CD05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tribenosid', 'C05CX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tribenosid', 'C05AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tribrommetacresol', 'D01AE03');
INSERT INTO staging.atc (description, atc_code) VALUES ('trichlorethylen', 'N01AB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('trichlormethiazid', 'C03AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trichlormethiazid und kalium', 'C03AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trichlormethiazid und kalium sparende mittel', 'C03EA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('triclabendazol', 'P02BX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('triclofos', 'N05CM07');
INSERT INTO staging.atc (description, atc_code) VALUES ('triclosan', 'D09AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('triclosan', 'D08AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tridihexethyl', 'A03AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('trifluoperazin', 'N05AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trifluperidol', 'N05AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('triflupromazin', 'N05AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('trifluridin', 'S01AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('triflusal', 'B01AC18');
INSERT INTO staging.atc (description, atc_code) VALUES ('trihexyphenidyl', 'N04AA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trilostan', 'H02CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimazosin', 'C02CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimebutin', 'A03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimegeston und estrogen', 'G03FA16');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimetaphan', 'C02BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimetazidin', 'C01EB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimethadion', 'N03AC02');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimethoprim', 'J01EA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimethoprim und derivate', 'J01EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimethyldiphenylpropylamin', 'A03AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimetrexat', 'P01AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('trimipramin', 'N06AA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trioxysalen', 'D05BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trioxysalen', 'D05AD01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tripelennamin', 'D04AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('tripelennamin', 'R06AC04');
INSERT INTO staging.atc (description, atc_code) VALUES ('triprolidin', 'R06AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('triptorelin', 'L02AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('triticum (weizenkleie)', 'A06AC07');
INSERT INTO staging.atc (description, atc_code) VALUES ('tritoqualin', 'R06AX21');
INSERT INTO staging.atc (description, atc_code) VALUES ('trofosfamid', 'L01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('troglitazon', 'A10BG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('troleandomycin', 'J01FA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('trolnitrat', 'C01DA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('trolnitrat, kombinationen', 'C01DA59');
INSERT INTO staging.atc (description, atc_code) VALUES ('tromantadin', 'J05AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('tromantadin', 'D06BB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('trometamol', 'B05BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('trometamol', 'B05XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tropatepin', 'N04AA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('tropenzilon und analgetika', 'A03DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tropicamid', 'S01FA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('tropicamid, kombinationen', 'S01FA56');
INSERT INTO staging.atc (description, atc_code) VALUES ('tropinether oder tropin-derivate', 'N04AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('tropisetron', 'A04AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('trospium', 'G04BD09');
INSERT INTO staging.atc (description, atc_code) VALUES ('trospium und analgetika', 'A03DA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('trovafloxacin', 'J01MA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('troxerutin', 'C05CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('troxerutin, kombinationen', 'C05CA54');
INSERT INTO staging.atc (description, atc_code) VALUES ('troxipid', 'A02BX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('trypsin', 'B06AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('trypsin', 'D03BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('trypsin, kombinationen', 'M09AB52');
INSERT INTO staging.atc (description, atc_code) VALUES ('tryptophan', 'N06AX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tuaminoheptan', 'R01AA11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tuaminoheptan', 'R01AB08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tuberkulin', 'V04CF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tuberkulose, lebend abgeschwächt', 'J07AN01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tuberkulose-diagnostika', 'V04CF');
INSERT INTO staging.atc (description, atc_code) VALUES ('tuberkulose-impfstoffe', 'J07AN');
INSERT INTO staging.atc (description, atc_code) VALUES ('tubocurarin', 'M03AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('tulobuterol', 'R03CC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tulobuterol', 'R03AC11');
INSERT INTO staging.atc (description, atc_code) VALUES ('tumorerkennung', 'V09I');
INSERT INTO staging.atc (description, atc_code) VALUES ('tumornekrosefaktor-alpha-inhibitoren (tnf-α)', 'L04AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyloxapol', 'R05CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('tymazolin', 'R01AA13');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhus (exanthematicus)-impfstoffe', 'J07AR');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhus exanthematicus, inaktiviert, ganze zelle', 'J07AR01');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhus, gereinigtes polysaccharid-antigen', 'J07AP03');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhus, inaktiviert, ganze zelle', 'J07AP02');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhus, kombinationen mit paratyphustypen', 'J07AP10');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhus, oral, lebend abgeschwächt', 'J07AP01');
INSERT INTO staging.atc (description, atc_code) VALUES ('typhus-impfstoffe', 'J07AP');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyropansäure', 'V08AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyrosinhydroxylasehemmer', 'C02KB');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyrothricin', 'D06AX08');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyrothricin', 'S01AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('tyrothricin', 'R02AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ubidecarenon', 'C01EB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('ulipristal', 'G03AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ulobetasol', 'D07AC21');
INSERT INTO staging.atc (description, atc_code) VALUES ('ultraschall-kontrastmittel', 'V08D');
INSERT INTO staging.atc (description, atc_code) VALUES ('ultraschall-kontrastmittel', 'V08DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('undecylensäure', 'D01AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('undecylensäure, kombinationen', 'D01AE54');
INSERT INTO staging.atc (description, atc_code) VALUES ('unoproston', 'S01EE02');
INSERT INTO staging.atc (description, atc_code) VALUES ('urapidil', 'C02CA06');
INSERT INTO staging.atc (description, atc_code) VALUES ('uratoxidase', 'M04AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('urikostatika', 'M04AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('urikosurika', 'M04AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('urin-tests', 'V04B');
INSERT INTO staging.atc (description, atc_code) VALUES ('urofollitropin', 'G03GA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('urogenitalsystem und sexualhormone', 'G');
INSERT INTO staging.atc (description, atc_code) VALUES ('urokinase', 'B01AD04');
INSERT INTO staging.atc (description, atc_code) VALUES ('urologika', 'G04');
INSERT INTO staging.atc (description, atc_code) VALUES ('urologische spasmolytika', 'G04BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('ursodeoxycholsäure', 'A05AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ustekinumab', 'L04AC05');
INSERT INTO staging.atc (description, atc_code) VALUES ('vaginalring mit gestagenen und estrogenen', 'G02BB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('valaciclovir', 'J05AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('valdecoxib', 'M01AH03');
INSERT INTO staging.atc (description, atc_code) VALUES ('valganciclovir', 'J05AB14');
INSERT INTO staging.atc (description, atc_code) VALUES ('valnoctamid', 'N05CM13');
INSERT INTO staging.atc (description, atc_code) VALUES ('valproinsäure', 'N03AG01');
INSERT INTO staging.atc (description, atc_code) VALUES ('valpromid', 'N03AG02');
INSERT INTO staging.atc (description, atc_code) VALUES ('valrubicin', 'L01DB09');
INSERT INTO staging.atc (description, atc_code) VALUES ('valsartan', 'C09CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('valsartan und aliskiren', 'C09DX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('valsartan und amlodipin', 'C09DB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('valsartan und diuretika', 'C09DA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('valsarten, amlodipin und hydrochlorothiazid', 'C09DX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vancomycin', 'J01XA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vancomycin', 'A07AA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('vardenafil', 'G04BE09');
INSERT INTO staging.atc (description, atc_code) VALUES ('varenicline', 'N07BA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('varia', 'V');
INSERT INTO staging.atc (description, atc_code) VALUES ('varicella zoster impfstoffe', 'J07BK');
INSERT INTO staging.atc (description, atc_code) VALUES ('varicella, lebend abgeschwächt', 'J07BK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('varicella/zoster-immunglobulin', 'J06BB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('vaselin-haltige verbände', 'D09AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('vaseline und fett-haltige mittel', 'D02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasopeptidase-inhibitoren, monopräparate', 'C09EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasopeptidase-inhibitoren, monopräparate', 'C09E');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasopressin', 'H01BA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasopressin und analoga', 'H01BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vasoprotektoren', 'C05');
INSERT INTO staging.atc (description, atc_code) VALUES ('vecuronium', 'M03AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('venlafaxin', 'N06AX16');
INSERT INTO staging.atc (description, atc_code) VALUES ('veraliprid', 'N05AL06');
INSERT INTO staging.atc (description, atc_code) VALUES ('verapamil', 'C08DA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('verapamil, kombinationen', 'C08DA51');
INSERT INTO staging.atc (description, atc_code) VALUES ('veratrum', 'C02KA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('veratrum und diuretika', 'C02LK01');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene', 'R02AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene', 'A01AD11');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene', 'A01AB11');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene', 'V01AA20');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene', 'M02AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene', 'D11AC30');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene', 'R01AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene kombinationen', 'B03AE10');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene kombinationen', 'D10AX30');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene radiodiagnostika', 'V09XX');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene radiodiagnostika für die schilddrüse', 'V09FX');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene radiopharmaka zur schmerzlinderung', 'V10BX');
INSERT INTO staging.atc (description, atc_code) VALUES ('verschiedene radiotherapeutika', 'V10XX');
INSERT INTO staging.atc (description, atc_code) VALUES ('verteporfin', 'S01LA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vidarabin', 'S01AD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('vidarabin', 'J05AB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('vigabatrin', 'N03AG04');
INSERT INTO staging.atc (description, atc_code) VALUES ('vildagliptin', 'A10BH02');
INSERT INTO staging.atc (description, atc_code) VALUES ('viloxazin', 'N06AX09');
INSERT INTO staging.atc (description, atc_code) VALUES ('viminol', 'N02BG05');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinbarbital', 'N05CA09');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinblastin', 'L01CA01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinburnin', 'C04AX17');
INSERT INTO staging.atc (description, atc_code) VALUES ('vincamin', 'C04AX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('vincristin', 'L01CA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('vindesin', 'L01CA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinflunin', 'L01CA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinka-alkaloide und analoga', 'L01CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinorelbin', 'L01CA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinpocetin', 'N06BX18');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinylbital', 'N05CA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('vinylether', 'N01AA02');
INSERT INTO staging.atc (description, atc_code) VALUES ('virale impfstoffe', 'J07B');
INSERT INTO staging.atc (description, atc_code) VALUES ('virginiamycin', 'D06AX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('viskoelastische substanzen', 'S01KA');
INSERT INTO staging.atc (description, atc_code) VALUES ('visnadin', 'C04AX24');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin a und d in kombination', 'A11CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin a und d, inkl. deren kombinationen', 'A11C');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin a, rein', 'A11CA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b1 in kombination mit vitamin b6 und/oder vitamin b12', 'A11DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b1, rein', 'A11DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b1, rein und in kombination mit vitamin b6 und vitamin b12', 'A11D');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b12 (cyanocobalamin und analoga)', 'B03BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin b12 und folsäure', 'B03B');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin d und analoga', 'A11CC');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin k', 'B02BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin k und andere hämostatika', 'B02B');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin-a-konzentrate', 'V04CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin-b-komplex mit anabolen steroiden', 'A11ED');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin-b-komplex mit mineralstoffen', 'A11EC');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin-b-komplex mit vitamin c', 'A11EB');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin-b-komplex, andere kombinationen', 'A11EX');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin-b-komplex, inkl. kombinationen', 'A11E');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin-b-komplex, rein', 'A11EA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamin-k-antagonisten', 'B01AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamine', 'B05XC');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamine', 'A11');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamine mit mineralstoffen', 'A11JB');
INSERT INTO staging.atc (description, atc_code) VALUES ('vitamine, andere kombinationen', 'A11JC');
INSERT INTO staging.atc (description, atc_code) VALUES ('voglibose', 'A10BF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('von-willebrand-faktor und gerinnungsfaktor viii in kombination', 'B02BD06');
INSERT INTO staging.atc (description, atc_code) VALUES ('voriconazol', 'J02AC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('vorinostat', 'L01XX38');
INSERT INTO staging.atc (description, atc_code) VALUES ('vorozol', 'L02BG05');
INSERT INTO staging.atc (description, atc_code) VALUES ('warfarin', 'B01AA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('warzenmittel und keratolytika', 'D11AF');
INSERT INTO staging.atc (description, atc_code) VALUES ('waschsubstanzen etc.', 'V07AX');
INSERT INTO staging.atc (description, atc_code) VALUES ('wasserlösliche hepatotrope röntgenkontrastmittel', 'V08AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('wasserlösliche nephrotrope hochosmolare röntgenkontrastmittel', 'V08AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('wasserlösliche nephrotrope niederosmolare röntgenkontrastmittel', 'V08AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('wasserstoffperoxid', 'A01AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('wasserstoffperoxid', 'D08AX01');
INSERT INTO staging.atc (description, atc_code) VALUES ('wasserunlösliche röntgenkontrastmittel', 'V08AD');
INSERT INTO staging.atc (description, atc_code) VALUES ('wehen fördernde mittel', 'G02A');
INSERT INTO staging.atc (description, atc_code) VALUES ('wirkstoffe gegen atopische dermatitis, ausser kortikosteroide', 'D11AH');
INSERT INTO staging.atc (description, atc_code) VALUES ('wirkstoffe gegen gefässerkrankungen der augen', 'S01L');
INSERT INTO staging.atc (description, atc_code) VALUES ('wirkstoffe gegen neovaskularisation', 'S01LA');
INSERT INTO staging.atc (description, atc_code) VALUES ('wundbehandlungsmittel', 'D03A');
INSERT INTO staging.atc (description, atc_code) VALUES ('wundverbände', 'V20');
INSERT INTO staging.atc (description, atc_code) VALUES ('xaliproden', 'N07XX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('xamoterol', 'C01CX07');
INSERT INTO staging.atc (description, atc_code) VALUES ('xanthin-derivate', 'N06BC');
INSERT INTO staging.atc (description, atc_code) VALUES ('xanthin-derivate', 'C03BD');
INSERT INTO staging.atc (description, atc_code) VALUES ('xanthine', 'R03DA');
INSERT INTO staging.atc (description, atc_code) VALUES ('xanthine und sympathomimetika', 'R03DB');
INSERT INTO staging.atc (description, atc_code) VALUES ('xantinolnicotinat', 'C04AD02');
INSERT INTO staging.atc (description, atc_code) VALUES ('xenysalat', 'D11AC09');
INSERT INTO staging.atc (description, atc_code) VALUES ('xibornol', 'J01XX02');
INSERT INTO staging.atc (description, atc_code) VALUES ('ximelagatran', 'B01AE05');
INSERT INTO staging.atc (description, atc_code) VALUES ('xipamid', 'C03BA10');
INSERT INTO staging.atc (description, atc_code) VALUES ('xylometazolin', 'R01AA07');
INSERT INTO staging.atc (description, atc_code) VALUES ('xylometazolin', 'S01GA03');
INSERT INTO staging.atc (description, atc_code) VALUES ('xylometazolin', 'R01AB06');
INSERT INTO staging.atc (description, atc_code) VALUES ('xylometazolin, kombinationen', 'S01GA53');
INSERT INTO staging.atc (description, atc_code) VALUES ('yohimbin', 'G04BE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('zafirlukast', 'R03DC01');
INSERT INTO staging.atc (description, atc_code) VALUES ('zalcitabin', 'J05AF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('zaleplon', 'N05CF03');
INSERT INTO staging.atc (description, atc_code) VALUES ('zanamivir', 'J05AH01');
INSERT INTO staging.atc (description, atc_code) VALUES ('zentral wirkende antiadiposita', 'A08AA');
INSERT INTO staging.atc (description, atc_code) VALUES ('zentral wirkende sympathomimetika', 'N06BA');
INSERT INTO staging.atc (description, atc_code) VALUES ('zentrales nervensystem', 'V09A');
INSERT INTO staging.atc (description, atc_code) VALUES ('ziconotide', 'N02BG08');
INSERT INTO staging.atc (description, atc_code) VALUES ('zidovudin', 'J05AF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('zimeldin', 'N06AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('zink', 'A12CB');
INSERT INTO staging.atc (description, atc_code) VALUES ('zink-haltige mittel', 'D02AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('zink-haltige verbindungen', 'S01AX03');
INSERT INTO staging.atc (description, atc_code) VALUES ('zink-haltige verbände', 'D09AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('zink-haltige verbände mit zusätzen', 'D09AB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('zink-haltige verbände ohne zusätze', 'D09AB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinkacetat', 'A16AX05');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinkchlorid', 'B05XA12');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinkgluconat', 'A12CB02');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinkprotein-komplex', 'A12CB03');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinkpräparate', 'C05AX04');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinksulfat', 'A12CB01');
INSERT INTO staging.atc (description, atc_code) VALUES ('zinn(ii)-fluorid', 'A01AA04');
INSERT INTO staging.atc (description, atc_code) VALUES ('zipeprol', 'R05DB15');
INSERT INTO staging.atc (description, atc_code) VALUES ('ziprasidon', 'N05AE04');
INSERT INTO staging.atc (description, atc_code) VALUES ('zitronensäure', 'A09AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('zofenopril', 'C09AA15');
INSERT INTO staging.atc (description, atc_code) VALUES ('zoledronsäure', 'M05BA08');
INSERT INTO staging.atc (description, atc_code) VALUES ('zolimidin', 'A02BX10');
INSERT INTO staging.atc (description, atc_code) VALUES ('zolmitriptan', 'N02CC03');
INSERT INTO staging.atc (description, atc_code) VALUES ('zolpidem', 'N05CF02');
INSERT INTO staging.atc (description, atc_code) VALUES ('zomepirac', 'M01AB04');
INSERT INTO staging.atc (description, atc_code) VALUES ('zonisamid', 'N03AX15');
INSERT INTO staging.atc (description, atc_code) VALUES ('zopiclon', 'N05CF01');
INSERT INTO staging.atc (description, atc_code) VALUES ('zorubicin', 'L01DB05');
INSERT INTO staging.atc (description, atc_code) VALUES ('zotepin', 'N05AX11');
INSERT INTO staging.atc (description, atc_code) VALUES ('zubereitungen aus schilddrüsengewebe', 'H03AA05');
INSERT INTO staging.atc (description, atc_code) VALUES ('zubereitungen mit salicylsäure-derivaten', 'M02AC');
INSERT INTO staging.atc (description, atc_code) VALUES ('zubereitungen zur behandlung von wunden und geschwüren', 'D03');
INSERT INTO staging.atc (description, atc_code) VALUES ('zubereitungen zur gallentherapie', 'A05AB');
INSERT INTO staging.atc (description, atc_code) VALUES ('zuclopenthixol', 'N05AF05');
INSERT INTO staging.atc (description, atc_code) VALUES ('zytotoxische antibiotika und verwandte substanzen', 'L01D');
INSERT INTO staging.atc (description, atc_code) VALUES ('öl', 'A06AG06');


--
-- PostgreSQL database dump complete
--



-- ===========================================================
-- fill in ATC codes where missing among identifiable consumable substances (de)
-- ===========================================================

UPDATE ref.consumable_substance
SET atc_code = staging.atc.atc_code
FROM staging.atc
WHERE UPPER(ref.consumable_substance.description) = UPPER(staging.atc.description)
AND ref.consumable_substance.atc_code IS NULL
;

commit;

-- =================
-- cleanup and exit
-- =================

\unset ON_ERROR_STOP
DROP TABLE staging.atc CASCADE;
\set ON_ERROR_STOP 1

-- end